<?php
/**
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

// Create necessary object instances
$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);

// Settings for action include and as a path param
$adminPage = "?page={$GLOBALS['NRS_EXTENSION']}-booking-search-results";

// The include bellow has to be 'required', not 'required_once'. In that file there are no functions or constants
require("includes/include.search-params.php");
require("includes/include.booking-actions.php");

$objBookingsObserver = new NRSBookingsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
// Booking list: Start
if($fromTimestamp > 0 && $toTimestamp > 0 && in_array($searchBetween, array("booking_date", "pickup_date", "dropoff_date")))
{
	if($searchBetween == "booking_date")
	{
		$bookingTableTitle = "Reservations Period: ".$fromISODate.' - '.$toISODate;
		$html = $objBookingsObserver->getAdminBookingList("BOOKING_LIST", $fromTimestamp, $toTimestamp, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "pickup_date")
	{
		$bookingTableTitle = "Pickups Period: ".$fromISODate.' - '.$toISODate;
		$html = $objBookingsObserver->getAdminBookingList("PICKUP_LIST", $fromTimestamp, $toTimestamp, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "dropoff_date")
	{
		$bookingTableTitle = "Dropoffs Period: ".$fromISODate.' - '.$toISODate;
		$html = $objBookingsObserver->getAdminBookingList("DROPOFF_LIST", $fromTimestamp, $toTimestamp, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	}
} else if($listType == 1)
{
	// Active
	if($searchBetween == "booking_date")
	{
		$bookingTableTitle = "Active Reservations";
		$html = $objBookingsObserver->getAdminBookingList("ACTIVE_BOOKING_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "pickup_date")
	{
		$bookingTableTitle = "Upcoming Pickups";
		$html = $objBookingsObserver->getAdminBookingList("ACTIVE_PICKUP_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "dropoff_date")
	{
		$bookingTableTitle = "Upcoming Dropoffs";
		$html = $objBookingsObserver->getAdminBookingList("ACTIVE_DROPOFF_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	}
} else if($listType == 2)
{
	// Archived
	if($searchBetween == "booking_date")
	{
		$bookingTableTitle = "Reservation Archive";
		$html = $objBookingsObserver->getAdminBookingList("ARCHIVE_BOOKING_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "pickup_date")
	{
		$bookingTableTitle = "Pickup Archive";
		$html = $objBookingsObserver->getAdminBookingList("ARCHIVE_PICKUP_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "dropoff_date")
	{
		$bookingTableTitle = "Dropoff Archive";
		$html = $objBookingsObserver->getAdminBookingList("ARCHIVE_DROPOFF_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	}
} else if($validCustomerId > 0)
{
	$bookingTableTitle = "Customer Reservations";
	$objCustomer = new NRSCustomer($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], "", $validCustomerId);
	$customerDetails = $objCustomer->getCustomerDetails();
	if(!is_null($customerDetails))
	{
		$bookingTableTitle = "Reservations by ".$customerDetails['print_full_name'];
	}
	$html = $objBookingsObserver->getAdminCustomerBookingList($validCustomerId, $objCore->getConfig('currency_symbol'), $adminPage.$tab.$customerUrlPart.$searchUrlPart);
} else
{
	// All
	if($searchBetween == "pickup_date")
	{
		$bookingTableTitle = "All Pickups";
		$html = $objBookingsObserver->getAdminBookingList("ALL_PICKUP_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else if($searchBetween == "dropoff_date")
	{
		$bookingTableTitle = "All Dropoffs";
		$html = $objBookingsObserver->getAdminBookingList("ALL_DROPOFF_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	} else
	{
		// $searchBetween == "booking_date"
		$bookingTableTitle = "All Reservations";
		$html = $objBookingsObserver->getAdminBookingList("ALL_BOOKING_LIST", 0, 0, $objCore->getConfig('currency_symbol'), 0, $adminPage.$tab.$customerUrlPart.$searchUrlPart);
	}

}
// Booking list: End

wp_enqueue_script('custom_script11', $GLOBALS['NRS_ADMIN_URL'].'js/DataTables/jquery.dataTables.js');
wp_enqueue_style('custom-style9', $GLOBALS['NRS_ADMIN_URL'].'css/data.table.css');
wp_enqueue_style('custom-style10', $GLOBALS['NRS_ADMIN_URL'].'css/jqueryui.css');
// Load Nice Admin Tabs CSS
wp_enqueue_style('custom-style11', $GLOBALS['NRS_ADMIN_URL'].'css/font-awesome.css');
wp_enqueue_style('custom-style12', $GLOBALS['NRS_ADMIN_URL'].'css/nrs-admin-tabs.css');

// Load template
include($GLOBALS['NRS_EXTENSION_ADMIN_PATH'].'booking-manager-templates/template.booking-search-results.php');