<?php
/**
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objCustomersObserver = new NRSCustomersObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objBookingsObserver = new NRSBookingsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objItemsObserver = new NRSItemsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objItemsCalendar = new NRSItemsCalendar($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objExtrasCalendar = new NRSExtrasCalendar($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objAPILog = new NRSAPILog($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);


// Settings for action include and as a path param
$adminPage = "?page={$GLOBALS['NRS_EXTENSION']}-booking-manager";
$validCustomerId = 0;

// URL defaults
$tab = "";
$searchUrlPart = "";
$customerUrlPart = "";

// Print default
$html = "";
$bookingTableTitle = "";
$printNoonTime = date_i18n(get_option('time_format'), strtotime(date("Y-m-d")." ".$objCore->getConfig('noon_time')), TRUE);

// Default tabs setting
$pickupsTabChecked = ' checked="checked"';
$dropoffsTabChecked = '';
$bookingsTabChecked = '';
$customersTabChecked = '';
$itemsCalendarTabChecked = '';
$extrasCalendarTabChecked = '';
$apiLogTabChecked = '';

if(isset($_GET['tab']))
{
    $tab = "&tab=".sanitize_key($_GET['tab']);
    switch($_GET['tab'])
    {
        case "pickups":
            $pickupsTabChecked = ' checked="checked"';
            $dropoffsTabChecked = '';
            $bookingsTabChecked = '';
            $customersTabChecked = '';
            $itemsCalendarTabChecked = '';
            $extrasCalendarTabChecked = '';
            $apiLogTabChecked = '';
            break;

        case "dropoffs":
            $pickupsTabChecked = '';
            $dropoffsTabChecked = ' checked="checked"';
            $bookingsTabChecked = '';
            $customersTabChecked = '';
            $itemsCalendarTabChecked = '';
            $extrasCalendarTabChecked = '';
            $apiLogTabChecked = '';
            break;

        case "bookings":
            $pickupsTabChecked = '';
            $dropoffsTabChecked = '';
            $bookingsTabChecked = ' checked="checked"';
            $customersTabChecked = '';
            $itemsCalendarTabChecked = '';
            $extrasCalendarTabChecked = '';
            $apiLogTabChecked = '';
            break;

        case "customers":
            $pickupsTabChecked = '';
            $dropoffsTabChecked = '';
            $bookingsTabChecked = '';
            $customersTabChecked = ' checked="checked"';
            $itemsCalendarTabChecked = '';
            $extrasCalendarTabChecked = '';
            $apiLogTabChecked = '';
            break;

        case "items-calendar":
            $pickupsTabChecked = '';
            $dropoffsTabChecked = '';
            $bookingsTabChecked = '';
            $customersTabChecked = '';
            $itemsCalendarTabChecked = ' checked="checked"';
            $extrasCalendarTabChecked = '';
            $apiLogTabChecked = '';
            break;

        case "extras-calendar":
            $pickupsTabChecked = '';
            $dropoffsTabChecked = '';
            $bookingsTabChecked = '';
            $customersTabChecked = '';
            $itemsCalendarTabChecked = '';
            $extrasCalendarTabChecked = ' checked="checked"';
            $apiLogTabChecked = '';
            break;

        case "api-log":
            $pickupsTabChecked = '';
            $dropoffsTabChecked = '';
            $bookingsTabChecked = '';
            $customersTabChecked = '';
            $itemsCalendarTabChecked = '';
            $extrasCalendarTabChecked = '';
            $apiLogTabChecked = ' checked="checked"';
            break;
    }
}
//echo nl2br(print_r($_REQUEST, TRUE));
//die("TAB:$tab");

// The include bellow has to be 'required', not 'required_once'. In that file there are no functions or constants
require("includes/include.booking-actions.php");

// Booking lists: start
$pickupHtml = $objBookingsObserver->getAdminTodayPickupList($objCore->getConfig('currency_symbol'), "?page=".$GLOBALS['NRS_EXTENSION']."-booking-manager&tab=pickups");
$dropoffHtml = $objBookingsObserver->getAdminTodayDropoffList($objCore->getConfig('currency_symbol'), "?page=".$GLOBALS['NRS_EXTENSION']."-booking-manager&tab=dropoffs");
$bookingHtml = $objBookingsObserver->getAdminTodayBookingList($objCore->getConfig('currency_symbol'), "?page=".$GLOBALS['NRS_EXTENSION']."-booking-manager&tab=bookings");
// Booking lists: end

// Customer List: Start
$customerHtml = $objCustomersObserver->getAdminCustomerList("ALL_CUSTOMERS", 0, 0, "?page=".$GLOBALS['NRS_EXTENSION']."-booking-manager&tab=customers");
// Customer List: End

// Item Calendar table: Start
$arrItemCalendars = array();
for($monthDiff = 0; $monthDiff < 2; $monthDiff++)
{
    $selectedTimestamp = strtotime(date("Y-m-d")." + {$monthDiff} month");
    $selectedYear = date("Y", $selectedTimestamp);
    $selectedMonth = date("m", $selectedTimestamp);
    $arrItemCalendars[] = $objItemsCalendar->getCalendar($selectedYear, $selectedMonth);
}
// Item Calendar table: End

// Extra Calendar table: Start
$arrExtraCalendars = array();
for($monthDiff = 0; $monthDiff < 2; $monthDiff++)
{
    $selectedTimestamp = strtotime(date("Y-m-d")." + {$monthDiff} month");
    $selectedYear = date("Y", $selectedTimestamp);
    $selectedMonth = date("m", $selectedTimestamp);

    $arrExtraCalendars[] = $objExtrasCalendar->getCalendar($selectedYear, $selectedMonth);
}
// Extra Calendar table: End

// Load Javascript and CSS files
wp_enqueue_style('jquery-style', $GLOBALS['NRS_ADMIN_URL'].'css/datepicker.css');
wp_enqueue_script('custom_script11', $GLOBALS['NRS_ADMIN_URL'].'js/DataTables/jquery.dataTables.js');
wp_enqueue_style('custom-style9', $GLOBALS['NRS_ADMIN_URL'].'css/data.table.css');
wp_enqueue_style('custom-style10', $GLOBALS['NRS_ADMIN_URL'].'css/jqueryui.css');
// Load Nice Admin Tabs CSS
wp_enqueue_style('custom-style11', $GLOBALS['NRS_ADMIN_URL'].'css/font-awesome.css');
wp_enqueue_style('custom-style12', $GLOBALS['NRS_ADMIN_URL'].'css/nrs-admin-tabs.css');

// Load template
include($GLOBALS['NRS_EXTENSION_ADMIN_PATH'].'booking-manager-templates/template.booking-manager.php');