<?php
/**
 * Admin Ajax processor class for NRS plugin
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSAdminAjaxProcessor
{
	protected $internalWPDB = NULL;
	protected $nrsPrefix 	= "";
	protected $lang 		= NULL;

	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
	{
		$this->internalWPDB = $paramWPDB;
		$this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
		// Already sanitized before in it's constructor. Too much sanitation will kill the system speed
		$this->lang = $paramNRSLang;
	}

	public function concatReplyMessages(array $replyMessages)
	{
		$ret = array();
		if (sizeof($replyMessages) == 1 && is_array($replyMessages[0]))
		{
			$ret = $replyMessages[0];
		} else if (sizeof($replyMessages) > 1 && is_array($replyMessages[0]) && is_array($replyMessages[1]))
		{
			$firstMessageDataArray = $replyMessages[0];
			for($i = 1; $i < sizeof($replyMessages); $i++)
			{
				$firstMessageDataArray['message'.($i+1)] = $replyMessages[$i]['message'];
			}

			$ret = $firstMessageDataArray;
		}

		return $ret;
	}

	public function sendJSONResponse($JSONParams)
	{
		if(isset($JSONParams['error']) && isset($JSONParams['message']))
		{
			echo json_encode($JSONParams);
		} else
		{
			// Unknown Error, required JSON Response params are missing
			$JSONParams = $this->getErrorMessage();
			echo json_encode($JSONParams);
		}
	}

	public function getErrorMessage()
	{
		$JSONParams = array(
			"error" => 99,
			"message" => "Unknown error.",
		);

		return $JSONParams;
	}

	/**
	 * Secured function
	 * @return array
	 */
	public function updateClosedDates()
	{
		$errorCode = 0;
		$selectDates = sanitize_text_field($_GET['selected_dates']);
		$this->internalWPDB->query("TRUNCATE {$this->nrsPrefix}closed_dates");
		if($selectDates)
		{
			$arrSelectedDates = explode(',',$selectDates);

			foreach($arrSelectedDates as $key=>$nonVerifiedDate)
			{
				// Security verification
				$validDate = NRSValidator::getValidISODate($nonVerifiedDate, 'Y-m-d');
				$this->internalWPDB->query("INSERT INTO {$this->nrsPrefix}closed_dates VALUES ('".$validDate."')");
			}
		}

		$JSONParams = array(
			"error" => $errorCode,
			"message" => "OK"
		);

		return $JSONParams;
	}

	/**
	 * @param $paramItemId
	 * @param $paramPriceCalculationType
	 * @param $paramVATPercentage
	 * @param $paramCurrencySymbol
	 * @param array $weekDays
	 * @return array
	 */
	public function generatePricePlanList($paramItemId, $paramPriceCalculationType, $paramVATPercentage, $paramCurrencySymbol, array $weekDays)
	{
		$pricePlansHTML = '';
		$validItemId = NRSValidator::getValidInteger($paramItemId, 0);
		$validVATPercentage = floatval($paramVATPercentage);
		$sqlPriceType = '';
		if(in_array($paramPriceCalculationType, array(1, 2)))
		{
			$sqlPriceType = $paramPriceCalculationType == 1 ? "AND price_type='1'" : "AND price_type='2'";
		}

		$sqlQuery = "
			SELECT start_timestamp, end_timestamp, seasonal_price
			FROM {$this->nrsPrefix}price_plans
			WHERE item_id='{$validItemId}'
			GROUP BY start_timestamp, end_timestamp
		";
		$dateRange = $this->internalWPDB->get_results($sqlQuery, ARRAY_A);
		//echo($sqlQuery."<br /><br />");

		foreach($dateRange AS $dateRow)
		{
			$sqlQuery = "
				SELECT *
				FROM {$this->nrsPrefix}price_plans
				WHERE item_id='{$validItemId}' {$sqlPriceType}
				AND start_timestamp='".$dateRow['start_timestamp']."' AND end_timestamp='".$dateRow['end_timestamp']."'
			";
			$dateRangeData = $this->internalWPDB->get_results($sqlQuery, ARRAY_A);
			//echo($sqlQuery."<br /><br />");

			if($dateRow['seasonal_price'] == 0)
			{
				$periodLabel = $this->lang->getText('NRS_ADMIN_REGULAR_PRICE_TEXT');
			} else
			{
				$periodLabel = $this->lang->getText('NRS_PERIOD_TEXT').': ';
				$periodLabel .= date_i18n(get_option('date_format').' '.get_option('time_format'), $dateRow['start_timestamp'] + get_option( 'gmt_offset' ) * 3600, TRUE);
				$periodLabel .= ' - '.date_i18n(get_option('date_format').' '.get_option('time_format'), $dateRow['end_timestamp'] + get_option( 'gmt_offset' ) * 3600, TRUE);
			}

			$pricePlansHTML .= '<tr class="price-plan-heading">';
			$pricePlansHTML .= '<td colspan="9" class="price-plan-big-label">'.$periodLabel.'</td>';
			$pricePlansHTML .= '</tr>';
			$pricePlansHTML .= '<tr>';
			$pricePlansHTML .= '<td class="price-plan-label">'.$this->lang->getText('NRS_ADMIN_PRICE_TYPE_TEXT').'</td>';
			foreach($weekDays AS $weekDay => $dayName)
			{
				$pricePlansHTML .= '<td class="price-plan-label">'.$dayName.'</td>';
			}
			$pricePlansHTML .= '<td class="price-plan-label">&nbsp;</td>';
			$pricePlansHTML .= '</tr>';

			$ctr = 0;
			foreach ($dateRangeData AS $pricePlanRow)
			{
				$ctr++;
				if($dateRow['seasonal_price'] == 0)
				{
					// Regular prices
					$pricePlanEditLink = '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-edit-price-plan&amp;item_id='.$validItemId.'&amp;start_dt=0&amp;end_dt=0').'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a>';
					$pricePlanDeleteLink = '';
				} else
				{
					// Seasonal prices
					$pricePlanEditLink = '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-edit-price-plan&amp;item_id='.$validItemId.'&amp;start_dt='.$pricePlanRow['start_timestamp'].'&amp;end_dt='.$pricePlanRow['end_timestamp']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a>';
					$pricePlanDeleteCode = $validItemId.'|'.$pricePlanRow['start_timestamp'].'|'.$pricePlanRow['end_timestamp'];
					$pricePlanDeleteLink = '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-prices&tab=price-plans&noheader=true&amp;delete_price_plan='.$pricePlanDeleteCode).'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a>';
				}


				$pricePeriod = $this->lang->getText($pricePlanRow['price_type'] == 1 ? 'NRS_PER_DAY_SHORT_TEXT' : 'NRS_PER_HOUR_SHORT_TEXT');
				$priceTypeTitle = '';
				if($validVATPercentage > 0)
				{
					$priceTypeTitle = $this->lang->getText('NRS_PRICE_TEXT').' / '.$pricePeriod.' ('.$this->lang->getText('NRS_WITHOUT_VAT_TEXT').')<br />';
				}
				$priceTypeTitle .= $this->lang->getText('NRS_PRICE_TEXT').' / '.$pricePeriod;

				$prices = array();
				foreach($weekDays AS $weekDay => $dayName)
				{
					$price = $paramCurrencySymbol.' '.number_format_i18n($pricePlanRow[$weekDay], 2);
					$price .= $validVATPercentage > 0 ? '<br />'.$paramCurrencySymbol.' '.number_format_i18n($pricePlanRow[$weekDay]*( 1 + $validVATPercentage / 100), 2) : '';
					$prices[] = $price;
				}

				$class = $ctr % 2 == 0 ? 'even' : 'odd';
				$showModifyLinks = $ctr == 1 ? TRUE : FALSE;

				// Price by days
				$pricePlansHTML .= '<tr class="'.$class.'">';
					$pricePlansHTML .= '<td class="price-plan-label">'.$priceTypeTitle.'</td>';
					foreach($prices AS $price)
					{
						$pricePlansHTML .= '<td class="price-plan-label">'.$price.'</td>';
					}
					$pricePlansHTML .= '<td class="price-plan-links">';
					if($showModifyLinks)
					{
						$pricePlansHTML .= '<span class="price-plan-link">'.$pricePlanEditLink.'</span>';
						if($pricePlanDeleteLink)
						{
							$pricePlansHTML .= ' &nbsp;&nbsp;&nbsp;||&nbsp;&nbsp;&nbsp; ';
							$pricePlansHTML .= '<span class="price-plan-link">'.$pricePlanDeleteLink.'</span>';
						}
					} else
					{
						$pricePlansHTML .= "&nbsp;";
					}
					$pricePlansHTML .= '</td>';
				$pricePlansHTML .= '</tr>';
			}
		}

		if(sizeof($dateRange) > 0)
		{
			$JSONParams = array(
				"error" => 0,
				"message" => $pricePlansHTML,
			);
		} else
		{
			$JSONParams = array(
				"error" => 1,
				"message" => "Sorry, No data found.",
			);
		}

		return $JSONParams;
	}
}