<?php
/**
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
*/

final class NRSExtraBlockSearch extends NRSSearch implements iNRSSearch
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig)
	{
		// Set booking expiration and clear expired bookings
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramConfig, "CLEAR_EXPIRED_BOOKINGS");
	}

	public function processBlockRequest()
	{
		// Set class variables
		$this->setRequestParams();

		// First: Validate search engine
		$this->validateSearchEngine();

		// Second: Validate Time input
		$this->validateTimeInput($this->pickupTimestamp, $this->dropoffTimestamp);

		if($this->isValidSearch())
		{
			// Data defined successfully, now remove session variables
			$this->removeSessionVariables();

			// Set fresh session variables
			$this->setMySessionVars();
		}
	}

	/**
	 * Step no. 1 - Show reservation box. (optional) + show car
	 * Step no. 2 - (optional) Select car, if no car provided
	 * Step no. 3 - Select car extras
	 * Step no. 4 - Show booking details
	 * Step no. 5 - Process booking
	 * Step no. 6 - PayPal payment
	 */
	private function setRequestParams()
	{
		// came from step1
		$customerInputPickupDate = $this->getValidValueInput(array('POST', 'SESSION'), 'pickup_date', date($this->shortDateFormat), true, $this->shortDateFormat);
		$customerInputPickupTime = $this->getValidValueInput(array('POST', 'SESSION'), 'pickup_time', date("H:i:s"), true, 'time_validation');
		// For blocking we allow only to select only from date and time options
		$customerInputDropoffDate = $this->getValidValueInput(array('POST', 'SESSION'), 'dropoff_date', date($this->shortDateFormat), true, $this->shortDateFormat);
		$customerInputDropoffTime = $this->getValidValueInput(array('POST', 'SESSION'), 'dropoff_time', date("H:i:s"), true, 'time_validation');
		$this->pickupTimestamp = NRSValidator::getUTCTimestampFromLocalISODateTime($customerInputPickupDate, $customerInputPickupTime);
		$this->dropoffTimestamp = NRSValidator::getUTCTimestampFromLocalISODateTime($customerInputDropoffDate, $customerInputDropoffTime);

		if(isset($_POST['extra_ids']))
		{
			// Came from step 2
			$this->extraIds = $this->getValidArrayInput(array('POST'), 'extra_ids', array(), true, 'intval');
		}

		/**********************************************************************/
		if($this->debugMode)
		{
			echo "\$customerInputPickupDate: $customerInputPickupDate<br />";
			echo "\$customerInputPickupTime: $customerInputPickupTime<br />";
			echo "\$customerInputDropoffDate: $customerInputDropoffDate<br />";
			echo "\$customerInputDropoffTime: $customerInputDropoffTime<br />";
			echo "\$this->pickupTimestamp: $this->pickupTimestamp<br />";
			echo "\$this->dropoffTimestamp: $this->dropoffTimestamp<br />";
			echo "\$this->extraIds: "; print_r($this->extraIds); echo "<br />";
			echo "POST: ".nl2br(print_r($_POST, TRUE));
		}
		/**********************************************************************/
	}


	public function doBlock()
	{
		$validNewlyInsertedBookingId= 0;
		$validPickupTimestamp 		= intval($this->pickupTimestamp);
		$validDropoffTimestamp 		= intval($this->dropoffTimestamp);
		$sanitizedBlockName      	= sanitize_text_field($_POST['block_name']);

		if(sizeof($this->extraIds) > 0)
		{
			// For blocks payments are always successful
			$sqlInsertQuery1 = "
              INSERT INTO {$this->nrsPrefix}bookings
              (
                    booking_timestamp, pickup_timestamp, dropoff_timestamp,
                    customer_id, is_block, payment_success, block_name
              ) VALUES
              (
                    '".time()."', '{$validPickupTimestamp}', '{$validDropoffTimestamp}',
                    '0', '1', '1', '{$sanitizedBlockName}'
              )
            ";
			//echo "<br />[Insert 1: {$sqlInsertQuery1}]";
			//die("<br />END");

			// DB INSERT
			$insertResult = $this->internalWPDB->query($sqlInsertQuery1);

			if($insertResult)
			{
				$validNewlyInsertedBookingId = intval($this->internalWPDB->insert_id);
			}

			foreach ($this->extraIds as $extraId)
			{
				$validExtraId = intval($extraId);

				// -1 units_booked means - all extra units of that extra been blocked
				$sqlInsertQuery2 = "
					INSERT INTO {$this->nrsPrefix}booking_options
					(
						booking_id, item_id, extra_id, option_id, units_booked
					) VALUES
					(
						'{$validNewlyInsertedBookingId}', '0', '{$validExtraId}', '0', '-1'
					)
				";
				//echo "<br />[Insert 2: {$sqlInsertQuery2}]";
				//die("<br />END");

				// DB INSERT
				$this->internalWPDB->query($sqlInsertQuery2);
			}
		}
	}
}