<?php
/**
 * Admin include file for Booking Manager
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

// URL defaults
$validCustomerId = 0;
$tab = "";
$searchUrlPart = "";
$customerUrlPart = "";

// Print default
$html = "";
$tabName = "search";
$bookingTableTitle = "";

// Set defaults - 2
$totalMonths = 0;
$listType = 0;
$fromISODate = "";
$toISODate = "";
$fromTimestamp = 0;
$toTimestamp = 0;
$searchBetween = "";
$searchUrlPart = ""; // copy this line, if file is not included

// Process $_GET requests and set variables
if(
	isset($_GET['search_pickup_date']) || isset($_GET['search_dropoff_date']) || isset($_GET['search_booking_date'])
	|| isset($_GET['search_customer_date']) || isset($_GET['search_item_calendar']) || isset($_GET['search_extras_calendar'])
) {
	if(isset($_GET['search_pickup_date']))
	{
		$listType   = intval($_GET['pickup_date_list_type']);
		$fromISODate  = NRSValidator::getValidISODate($_GET['from_pickup_date'], $objCore->getConfig('short_date_format'));
		$toISODate    = NRSValidator::getValidISODate($_GET['to_pickup_date'], $objCore->getConfig('short_date_format'));
		$searchBetween   = "pickup_date";
	} else if(isset($_GET['search_dropoff_date']))
	{
		$listType   = intval($_GET['dropoff_date_list_type']);
		$fromISODate  = NRSValidator::getValidISODate($_GET['from_dropoff_date'], $objCore->getConfig('short_date_format'));
		$toISODate    = NRSValidator::getValidISODate($_GET['to_dropoff_date'], $objCore->getConfig('short_date_format'));
		$searchBetween   = "dropoff_date";
	} else if(isset($_GET['booking_date_list_type']))
	{
		$listType   = intval($_GET['booking_date_list_type']);
		$fromISODate  = NRSValidator::getValidISODate($_GET['from_booking_date'], $objCore->getConfig('short_date_format'));
		$toISODate    = NRSValidator::getValidISODate($_GET['to_booking_date'], $objCore->getConfig('short_date_format'));
		$searchBetween   = "booking_date";
	} else if(isset($_GET['search_customer_date']))
	{
		$listType = intval($_GET['customer_date_list_type']); // 3 - registration date, 4 - last visit
		$fromISODate  = NRSValidator::getValidISODate($_GET['from_customer_date'], $objCore->getConfig('short_date_format'));
		$toISODate    = NRSValidator::getValidISODate($_GET['to_customer_date'], $objCore->getConfig('short_date_format'));
		$searchBetween   = "customer_date";
	} else if(isset($_GET['search_item_calendar']))
	{
		$listType   = 0;
		$fromISODate  = NRSValidator::getValidISODate($_GET['from_item_calendar'], $objCore->getConfig('short_date_format'));
		$toISODate    = NRSValidator::getValidISODate($_GET['to_item_calendar'], $objCore->getConfig('short_date_format'));
		$searchBetween   = "item_calendar";
	} else if(isset($_GET['search_extras_calendar']))
	{
		$listType   = 0;
		$fromISODate  = NRSValidator::getValidISODate($_GET['from_extras_calendar'], $objCore->getConfig('short_date_format'));
		$toISODate    = NRSValidator::getValidISODate($_GET['to_extras_calendar'], $objCore->getConfig('short_date_format'));
		$searchBetween   = "extras_calendar";
	}

	// +1 because we want to include current month
	$totalMonths = NRSValidator::getTotalMonthsBetweenTwoISODates($fromISODate, $toISODate)+1;
	$fromTimestamp = NRSValidator::getUTCTimestampFromLocalISODateTime($fromISODate, '00:00:00');
	$toTimestamp = NRSValidator::getUTCTimestampFromLocalISODateTime($toISODate, '23:59:59');

	$searchUrlPart .= "&{$searchBetween}_list_type={$listType}";
	$searchUrlPart .= "&from_{$searchBetween}={$fromISODate}";
	$searchUrlPart .= "&to_{$searchBetween}={$toISODate}";
}

// Get customer details if set - to list bookings only from customer with specific id
if(isset($_GET['customer_id']) && NRSValidator::isInteger($_GET['customer_id']))
{
	$validCustomerId = intval($_GET['customer_id']);
	$customerUrlPart = "&customer_id=".$validCustomerId;
	if($searchBetween == "")
	{
		$searchBetween = "customer_bookings";
	}
}

// Default tabs setting
$searchResultsTabChecked = ' checked="checked"';

if(isset($_GET['tab']))
{
	$tab = "&tab=".sanitize_key($_GET['tab']);
	switch($_GET['tab'])
	{
		case "search-results":
			$searchResultsTabChecked = ' checked="checked"';
			break;
	}
}