<?php
/**
 * Demo import manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSAdminDemoImporter
{
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
    {
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;
    }

    public function getDemosDropDownList($name="demo_type", $selectedOption = "")
    {
        $demos = '<select name="'.$name.'" class="required">';
        $demos .= '<option value=""> --- Select Live Demo --- </option>';
        //$demos .= '<option value="1"'.($selectedOption == 1 ? ' selected="selected"' : '').'>Minimal Live Demo - Tesla Test Drive</option>';
        $demos .= '<option value="2"'.($selectedOption == 2 ? ' selected="selected"' : '').'>Standard Live Demo - Car Rental Agency</option>';
        //$demos .= '<option value="3"'.($selectedOption == 3 ? ' selected="selected"' : '').'>Complex Live Demo - Enterprise Car Rental</option>';
        $demos .= '</select>';

        return $demos;
    }

    public function importLiveDemo()
    {
        $demoType = isset($_POST['demo_type']) ? intval($_POST['demo_type']) : 0;
        $validDemoType = in_array($demoType, array(1,2,3)) ? $demoType : 0;

        $imported = false;

        switch($validDemoType)
        {
            case 1:
                $imported = $this->importMinimalLiveDemo();
                break;
            case 2:
                $imported = $this->importStandardLiveDemo();
                break;
            case 3:
                $imported = $this->importComplexLiveDemo();
                break;
            default:
                // Do nothing
        }

        if($imported)
        {
            $_SESSION['ok_msg'] = 'Completed: Demo data imported successfully!';
        } else
        {
            $_SESSION['msg'] = 'Failed: Demo was not imported!';
        }

        return $imported;
    }

    /**
     * Tesla Test Drive
     * @return bool
     */
    private function importMinimalLiveDemo()
    {
        // Truncate all current tables
        $this->truncateAllTables();

        // Insert NRS tables data
        $arrSQL = $this->getNRSSQLData();
        foreach($arrSQL AS $sql)
        {
            $this->internalWPDB->query($sql);
        }

        // Drop all posts in db with post type 'car'
        $this->dropAllPostsWithItemType();

        // Insert posts with post type 'car'
        $postSQL = $this->getNRSPostsSQLData();
        $this->internalWPDB->query($postSQL);

        return true;
    }

    /**
     * Agency Car Rental
     * @return bool
     */
    private function importStandardLiveDemo()
    {
        // Truncate all current tables
        $this->truncateAllTables();

        // Insert NRS tables data
        $arrSQL = $this->getNRSSQLData();
        foreach($arrSQL AS $sql)
        {
            $this->internalWPDB->query($sql);
        }

        // Drop all posts in db with post type 'car'
        $this->dropAllPostsWithItemType();

        // Insert posts with post type 'car'
        $postSQL = $this->getNRSPostsSQLData();
        $this->internalWPDB->query($postSQL);

        return true;
    }

    /**
     * Enterprise Car Rental
     * @return bool
     */
    private function importComplexLiveDemo()
    {
        // Truncate all current tables
        $this->truncateAllTables();

        // Insert NRS tables data
        $arrSQL = $this->getNRSSQLData();
        foreach($arrSQL AS $sql)
        {
            $this->internalWPDB->query($sql);
        }

        // Drop all posts in db with post type 'car'
        $this->dropAllPostsWithItemType();

        // Insert posts with post type 'car'
        $postSQL = $this->getNRSPostsSQLData();
        $this->internalWPDB->query($postSQL);

        return true;
    }


    private function truncateAllTables()
    {
        $arrAllTables = $this->getAllTablesArray();
        foreach($arrAllTables AS $table)
        {
            $this->internalWPDB->query("TRUNCATE TABLE {$this->nrsPrefix}".$table);
        }
    }

    private function getAllTablesArray()
    {
        $nrsTables = array(
            "api_log",
            "body_types",
            "bookings", // Only Truncate
            "booking_options", // Only Truncate
            "closed_dates", // Only Truncate
            "customers",
            "deposits",
            "discounts",
            "email_contents",
            "extras",
            "features",
            "fuel_types",
            "invoices",
            "items",
            "item_features",
            "item_locations",
            "locations",
            "manufacturers",
            "options",
            "payment_methods",
            "prepayments",
            "price_plans",
            "settings",
            "transmission_types",
        );

        return $nrsTables;
    }

    private function dropAllPostsWithItemType()
    {
        $this->internalWPDB->query("DELETE FROM `{$this->internalWPDB->prefix}posts` WHERE post_type='".$GLOBALS['NRS_EXTENSION']."'");
    }

    /**
     * Make sure than all " has a backslash - \"
     */
    private function getNRSPostsSQLData()
    {
        $SQLData = 'INSERT INTO `'.$this->internalWPDB->prefix.'posts` (`ID`, `post_author`, `post_date`, `post_date_gmt`, `post_content`, `post_title`, `post_excerpt`, `post_status`, `comment_status`, `ping_status`, `post_password`, `post_name`, `to_ping`, `pinged`, `post_modified`, `post_modified_gmt`, `post_content_filtered`, `post_parent`, `guid`, `menu_order`, `post_type`, `post_mime_type`, `comment_count`) VALUES
(192, 1, \'2015-04-29 09:41:45\', \'2015-04-29 11:41:45\', \'[car_rental_system display="item" item="1"]\r\n[car_rental_system display="search" item="1"]\', \'Peugeot 207\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'peugeot-207\', \'\', \'\', \'2015-04-29 09:41:45\', \'2015-04-29 11:41:45\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=192\', 0, \'car\', \'\', 0),
(193, 1, \'2015-04-29 09:43:27\', \'2015-04-29 11:43:27\', \'[car_rental_system display="item" item="2"]\r\n[car_rental_system display="search" item="2"]\', \'Suzuki Alto\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'suzuki-alto\', \'\', \'\', \'2015-05-01 17:13:49\', \'2015-05-01 19:13:49\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=193\', 0, \'car\', \'\', 0),
(194, 1, \'2015-04-29 09:44:51\', \'2015-04-29 11:44:51\', \'[car_rental_system display="item" item="3"]\r\n[car_rental_system display="search" item="3"]\', \'Opel Vivaro\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'opel-vivaro\', \'\', \'\', \'2015-04-29 09:44:51\', \'2015-04-29 11:44:51\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=194\', 0, \'car\', \'\', 0),
(195, 1, \'2015-04-29 09:46:11\', \'2015-04-29 11:46:11\', \'[car_rental_system display="item" item="4"]\r\n[car_rental_system display="search" item="4"]\', \'Peugeot Boxer\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'peugeot-boxer\', \'\', \'\', \'2015-04-29 09:46:12\', \'2015-04-29 11:46:12\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=195\', 0, \'car\', \'\', 0),
(196, 1, \'2015-04-29 09:47:55\', \'2015-04-29 11:47:55\', \'[car_rental_system display="item" item="5"]\r\n[car_rental_system display="search" item="5"]\', \'Audi A6\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'audi-a6\', \'\', \'\', \'2015-04-29 09:47:56\', \'2015-04-29 11:47:56\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=196\', 0, \'car\', \'\', 0),
(197, 1, \'2015-04-29 09:49:01\', \'2015-04-29 11:49:01\', \'[car_rental_system display="item" item="6"]\r\n[car_rental_system display="search" item="6"]\', \'Citroen C5\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'citroen-c5\', \'\', \'\', \'2015-04-29 09:49:01\', \'2015-04-29 11:49:01\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=197\', 0, \'car\', \'\', 0),
(199, 1, \'2015-04-29 09:51:20\', \'2015-04-29 11:51:20\', \'[car_rental_system display="item" item="8"]\r\n[car_rental_system display="search" item="8"]\', \'Opel Astra Sport Tourer\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'opel-astra-sport-tourer\', \'\', \'\', \'2015-04-29 09:51:21\', \'2015-04-29 11:51:21\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=199\', 0, \'car\', \'\', 0),
(200, 1, \'2015-04-29 09:52:23\', \'2015-04-29 11:52:23\', \'[car_rental_system display="item" item="9"]\r\n[car_rental_system display="search" item="9"]\', \'Opel Insignia\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'opel-insignia\', \'\', \'\', \'2015-04-29 09:52:24\', \'2015-04-29 11:52:24\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=200\', 0, \'car\', \'\', 0),
(201, 1, \'2015-04-29 09:53:32\', \'2015-04-29 11:53:32\', \'[car_rental_system display="item" item="10"]\r\n[car_rental_system display="search" item="10"]\', \'Mazda 6\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'mazda-6\', \'\', \'\', \'2015-04-29 09:53:32\', \'2015-04-29 11:53:32\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=201\', 0, \'car\', \'\', 0),
(203, 1, \'2015-04-29 09:55:49\', \'2015-04-29 11:55:49\', \'[car_rental_system display="item" item="12"]\r\n[car_rental_system display="search" item="12"]\', \'Mercedes ML350\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'mercedes-ml350\', \'\', \'\', \'2015-04-29 09:55:49\', \'2015-04-29 11:55:49\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=203\', 0, \'car\', \'\', 0),
(204, 1, \'2015-04-29 09:57:01\', \'2015-04-29 11:57:01\', \'[car_rental_system display="item" item="13"]\r\n[car_rental_system display="search" item="13"]\', \'Nissan Qashqai\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'nissan-qashqai\', \'\', \'\', \'2015-04-29 09:57:01\', \'2015-04-29 11:57:01\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=204\', 0, \'car\', \'\', 0),
(228, 1, \'2015-09-08 19:37:57\', \'2015-09-09 02:37:57\', \'[car_rental_system display="item" item="16"]\r\n[car_rental_system display="search" item="16"]\', \'Kia Ceed\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'kia-ceed\', \'\', \'\', \'2015-09-08 19:37:57\', \'2015-09-09 02:37:57\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=228\', 0, \'car\', \'\', 0),
(229, 1, \'2015-09-08 19:43:14\', \'2015-09-09 02:43:14\', \'[car_rental_system display="item" item="17"]\r\n[car_rental_system display="search" item="17"]\', \'VW Touareg\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'vwtouareg\', \'\', \'\', \'2015-09-08 19:46:22\', \'2015-09-09 02:46:22\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=229\', 0, \'car\', \'\', 0),
(230, 1, \'2015-09-08 19:49:42\', \'2015-09-09 02:49:42\', \'[car_rental_system display="item" item="15"]\r\n[car_rental_system display="search" item="15"]\', \'Nissan Qashqai+2\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'nissan-qashqai2\', \'\', \'\', \'2015-09-08 19:49:42\', \'2015-09-09 02:49:42\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=230\', 0, \'car\', \'\', 0),
(231, 1, \'2015-09-09 11:55:55\', \'2015-09-09 18:55:55\', \'[car_rental_system display="item" item="14"]\r\n[car_rental_system display="search" item="14"]\', \'Ford Fiesta\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'ford-fiesta\', \'\', \'\', \'2015-09-09 11:55:55\', \'2015-09-09 18:55:55\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=231\', 0, \'car\', \'\', 0),
(232, 1, \'2015-10-27 14:18:30\', \'2015-10-27 21:18:30\', \'Thank you. We received your payment. Your reservation is now confirmed.\', \'Reservation confirmed\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'reservation-confirmed\', \'\', \'\', \'2015-10-27 14:18:30\', \'2015-10-27 21:18:30\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=232\', 0, \'car\', \'\', 0),
(233, 1, \'2015-10-27 14:18:30\', \'2015-10-27 21:18:30\', \'Payment was cancelled. Your reservation were not confirmed.\', \'Payment cancelled\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'payment-cancelled\', \'\', \'\', \'2015-10-27 14:18:30\', \'2015-10-27 21:18:30\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=233\', 0, \'car\', \'\', 0),
(234, 1, \'2015-03-10 07:49:22\', \'2015-10-27 21:18:30\', \'<strong>PRICE</strong>\r\nPrice includes: Civilial insurance, CASCO insurance, Emergency road assistance 24/7, Sales Tax.\r\n\r\n<strong>PERIOD</strong>\r\nMinimal rental period 1 day.\r\n\r\n<strong>RENTER\'\'S LIABILITY</strong>\r\nThe renter is obligated to provide a vehicle to the lessee for a specified price.
The lessee becomes the righteous owner of a car during the period of rent. The renter insures the car and the lessee. The renter is obligated to check the condition of the vehicle and ensure that it is safe to use before the rent. The car that the renter provides must be clean and tanked up.\r\n\r\n<strong>LIMITATIONS</strong>\r\nThe lessee must have at least one year of driving experience,
use the car only in the territory of Lithuania (unless the renter specifies differently). The mileage of the rented car is unlimited.\r\n\r\n<strong>LESSEE&#39;S LIABILITY</strong>\r\nThe lessee must provide a valid driver license, which allows him to drive the rented car. The lessee must also submit a passport or ID card to the renter. The lessee must pay full price for the rent before the beginning of the rent.
The lessee must leave a deposit for the car which varies from 100 to 400 USD depending on the class of car. That may be used to cover any damages made to the car, that may occur during the period of car rent. When returning the car the lessee must also pay for the consumed fuel in the fuel tank, since the renter always provides a car with the full fuel tank.\r\n\r\n<strong>LIABILITY</strong>\r\n
The lessee undertakes full responsibility if a non insurable event occurs during the period of rent. The lessee takes the responsibility for all the consequences that may occur if transferring the car to a third person. If the lessee violates the road traffic rules he must pay all related penalties.
In case of car theft the lessee must compensate the damage if don‘t return the car keys and registration documents to the renter.\', \'Car rental terms and conditions\', \'\', \'publish\', \'closed\', \'closed\', \'\', \'car-rental-terms-and-conditions\', \'\', \'\', \'2015-10-27 14:18:30\', \'2015-10-27 21:18:30\', \'\', 0, \'http://cars.matuliauskas.com/en/?post_type=car&#038;p=234\', 0, \'car\', \'\', 0)';
        return $SQLData;
    }

    /**
     * NRS SQL Data
     * @return array
     */
    private function getNRSSQLData()
    {
        $pluginVersion = number_format(floatval($GLOBALS['NRS_VERSION']), 1,'.','');

        $arrSQL = array();
        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}body_types` (`body_type_id`, `body_type_title`) VALUES
(1, 'Intermediate'),
(2, 'Compact'),
(3, 'Station Wagon'),
(4, 'SUV'),
(5, 'Minibus')";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}customers` (`customer_id`, `title`, `first_name`, `last_name`, `birthdate`, `street_address`, `city`, `state`, `zipcode`, `country`, `phone`, `email`, `additional_comments`, `ip`, `existing_customer`, `registration_timestamp`, `last_visit_timestamp`) VALUES
(1, 'Mr.', 'John', 'Smith', '1980-06-09', '625 2nd Street', 'San Francisco', 'CA', '94107', 'United States', '+14506004790', 'john.smith@gmail.com', 'Please leave car keys by the front door upon delivery.', '0.0.0.0', 0, 1444584654, 0)";


        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}deposits` (`deposit_id`, `item_id`, `period_from`, `period_till`, `fixed_rental_deposit`) VALUES
(3, 10, 0, 31622399, 230.00),
(4, 1, 0, 31622399, 110.00),
(5, 2, 0, 31622399, 110.00),
(6, 14, 0, 31622399, 110.00),
(7, 9, 0, 31622399, 230.00),
(8, 5, 0, 31622399, 230.00),
(9, 6, 0, 31622399, 230.00),
(10, 8, 0, 31622399, 220.00),
(11, 16, 0, 31622399, 110.00),
(12, 15, 0, 31622399, 230.00),
(13, 13, 0, 31622399, 230.00),
(14, 17, 0, 31622399, 230.00),
(15, 12, 0, 31622399, 230.00),
(16, 3, 0, 31622399, 230.00),
(17, 4, 0, 31622399, 800.00)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}discounts` (`discount_id`, `discount_type`, `item_id`, `extra_id`, `period_from`, `period_till`, `discount_percentage`) VALUES
(7, 1, 10, 0, 86400, 259199, 0.000),
(8, 1, 1, 0, 86400, 259199, 0.000),
(9, 1, 2, 0, 86400, 259199, 0.000),
(10, 1, 14, 0, 86400, 259199, 0.000),
(11, 1, 9, 0, 86400, 259199, 0.000),
(12, 1, 5, 0, 86400, 259199, 0.000),
(13, 1, 6, 0, 86400, 259199, 0.000),
(14, 1, 8, 0, 86400, 259199, 0.000),
(15, 1, 16, 0, 86400, 259199, 0.000),
(16, 1, 15, 0, 86400, 259199, 0.000),
(17, 1, 13, 0, 86400, 259199, 0.000),
(18, 1, 17, 0, 86400, 259199, 0.000),
(19, 1, 12, 0, 86400, 259199, 0.000),
(20, 1, 3, 0, 86400, 259199, 0.000),
(21, 1, 4, 0, 86400, 259199, 0.000),
(22, 1, 10, 0, 259200, 518399, 14.610),
(23, 1, 10, 0, 518400, 777599, 29.250),
(24, 1, 10, 0, 777600, 1295999, 43.890),
(25, 1, 10, 0, 1296000, 2591999, 46.340),
(26, 1, 10, 0, 2592000, 31622399, 51.210),
(27, 1, 1, 0, 259200, 518399, 10.350),
(28, 1, 1, 0, 518400, 777599, 20.690),
(29, 1, 1, 0, 777600, 1295999, 31.040),
(30, 1, 1, 0, 1296000, 2591999, 41.390),
(31, 1, 1, 0, 2592000, 31622399, 51.730),
(32, 1, 2, 0, 259200, 518399, 9.080),
(33, 1, 2, 0, 518400, 777599, 13.640),
(34, 1, 2, 0, 777600, 1295999, 27.280),
(35, 1, 2, 0, 1296000, 2591999, 36.360),
(36, 1, 2, 0, 2592000, 31622399, 54.570),
(37, 1, 14, 0, 259200, 518399, 9.080),
(38, 1, 14, 0, 518400, 777599, 13.640),
(39, 1, 14, 0, 777600, 1295999, 27.280),
(40, 1, 14, 0, 1296000, 2591999, 36.360),
(41, 1, 14, 0, 2592000, 31622399, 54.570),
(42, 1, 9, 0, 259200, 518399, 7.320),
(43, 1, 9, 0, 518400, 777599, 14.610),
(44, 1, 9, 0, 777600, 1295999, 21.930),
(45, 1, 9, 0, 1296000, 2591999, 29.250),
(46, 1, 9, 0, 2592000, 31622399, 51.210),
(47, 1, 5, 0, 259200, 518399, 11.770),
(48, 1, 5, 0, 518400, 777599, 23.530),
(49, 1, 5, 0, 777600, 1295999, 35.300),
(50, 1, 5, 0, 1296000, 2591999, 37.250),
(51, 1, 5, 0, 2592000, 31622399, 41.190),
(52, 1, 6, 0, 259200, 518399, 7.320),
(53, 1, 6, 0, 518400, 777599, 14.610),
(54, 1, 6, 0, 777600, 1295999, 21.930),
(55, 1, 6, 0, 1296000, 2591999, 24.380),
(56, 1, 6, 0, 2592000, 31622399, 51.210),
(57, 1, 8, 0, 259200, 518399, 9.380),
(58, 1, 8, 0, 518400, 777599, 18.750),
(59, 1, 8, 0, 777600, 1295999, 28.130),
(60, 1, 8, 0, 1296000, 2591999, 37.500),
(61, 1, 8, 0, 2592000, 31622399, 46.880),
(62, 1, 16, 0, 259200, 518399, 9.380),
(63, 1, 16, 0, 518400, 777599, 18.750),
(64, 1, 16, 0, 777600, 1295999, 28.130),
(65, 1, 16, 0, 1296000, 2591999, 31.270),
(66, 1, 16, 0, 2592000, 31622399, 46.880),
(67, 1, 15, 0, 259200, 518399, 14.610),
(68, 1, 15, 0, 518400, 777599, 29.250),
(69, 1, 15, 0, 777600, 1295999, 43.890),
(70, 1, 15, 0, 1296000, 2591999, 46.340),
(71, 1, 15, 0, 2592000, 31622399, 51.210),
(72, 1, 13, 0, 259200, 518399, 14.610),
(73, 1, 13, 0, 518400, 777599, 29.250),
(74, 1, 13, 0, 777600, 1295999, 43.890),
(75, 1, 13, 0, 1296000, 2591999, 46.340),
(76, 1, 13, 0, 2592000, 31622399, 51.210),
(77, 1, 17, 0, 259200, 518399, 7.320),
(78, 1, 17, 0, 518400, 777599, 14.640),
(79, 1, 17, 0, 777600, 1295999, 21.930),
(80, 1, 17, 0, 1296000, 2591999, 29.250),
(81, 1, 17, 0, 2592000, 31622399, 39.020),
(82, 1, 12, 0, 259200, 518399, 10.720),
(83, 1, 12, 0, 518400, 777599, 21.430),
(84, 1, 12, 0, 777600, 1295999, 32.150),
(85, 1, 12, 0, 1296000, 2591999, 33.920),
(86, 1, 12, 0, 2592000, 31622399, 37.490),
(87, 1, 3, 0, 259200, 518399, 3.050),
(88, 1, 3, 0, 518400, 777599, 5.000),
(89, 1, 3, 0, 777600, 1295999, 6.670),
(90, 1, 3, 0, 1296000, 2591999, 8.350),
(91, 1, 3, 0, 2592000, 31622399, 10.000),
(92, 1, 4, 0, 259200, 518399, 1.760),
(93, 1, 4, 0, 518400, 777599, 3.020),
(94, 1, 4, 0, 777600, 1295999, 5.260),
(95, 1, 4, 0, 1296000, 2591999, 5.260),
(96, 1, 4, 0, 2592000, 31622399, 5.260)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}email_contents` (`email_id`, `email_subject`, `email_body`) VALUES
(1, 'Reservation details - no. [BOOKING_CODE]', 'Dear, [CUSTOMER_NAME],\n\nYour reservation details were received.\n\nYour reservation details:\n\n[INVOICE]\n\nRegards,\n[PORTAL_NAME],\n[PORTAL_PHONE],\n[PORTAL_EMAIL]'),
(2, 'Reservation no. [BOOKING_CODE] - confirmed', 'Dear, [CUSTOMER_NAME],\n\nWe received your payment. Your reservation is now confirmed.\n\nYour reservation details:\n\n[INVOICE]\n\nRegards,\n[PORTAL_NAME],\n[PORTAL_PHONE],\n[PORTAL_EMAIL]'),
(3, 'Reservation no. [BOOKING_CODE] - cancelled', 'Dear, [CUSTOMER_NAME],\n\nYour reservation no. [BOOKING_CODE] were cancelled.\n\nRegards,\n[PORTAL_NAME],\n[PORTAL_PHONE],\n[PORTAL_EMAIL]'),
(4, 'Notification: new reservation - [BOOKING_CODE]', 'New reservation no. [BOOKING_CODE] received from [CUSTOMER_NAME].\n\nReservation details:\n[INVOICE]'),
(5, 'Notification: reservation paid - [BOOKING_CODE]', 'Reservation no. [BOOKING_CODE] was recently paid by [CUSTOMER_NAME].\n\nReservation details:\n[INVOICE]'),
(6, 'Notification: reservation cancelled - [BOOKING_CODE]', 'Reservation no. [BOOKING_CODE] for [CUSTOMER_NAME] was recently cancelled.\n\nDetails of reservation, which were cancelled:\n[INVOICE]')";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}extras` (`extra_id`, `extra_name`, `price`, `price_type`, `prepayment_percentage`, `fixed_rental_deposit`, `units_in_stock`, `min_units_per_booking`, `max_units_per_booking`, `options_display_mode`, `measurement_unit`) VALUES
(1, 'GPS', 3.31, 1, 100.00, 0.00, 50, 0, 1, 1, ''),
(3, 'Baby Seat', 3.31, 1, 100.00, 0.00, 50, 0, 2, 1, '')";


        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}features` (`feature_id`, `feature_title`, `display_in_item_list`) VALUES
(1, 'Power Steering', 1),
(2, 'Audio system', 1),
(3, 'Air Bags', 1),
(4, 'Air Conditioning', 1),
(5, 'Cruise Control', 1),
(6, 'Electric windows', 1),
(7, 'Central locking', 1),
(8, 'ABS', 1)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}fuel_types` (`fuel_type_id`, `fuel_type_title`) VALUES
(1, 'Petrol'),
(2, 'Diesel')";

        $arrSQL[] = 'INSERT INTO `'.$this->nrsPrefix.'invoices` (`booking_id`, `customer_name`, `customer_email`, `grand_total`, `fixed_deposit_amount`, `total_pay_now`, `pickup_location`, `dropoff_location`, `invoice`) VALUES
(0, \'Mr. John Smith\', \'john.smith@gmail.com\', 189.24, 230.00, 189.24, \'2. San Francisco Intl. Airport (SFO) - Hwy 101, San Francisco, CA 94128\', \'3. Oakland Intl. Airport (OAK) - 1 Airport Dr, Oakland, CA 94621\', \'<table style="font-family:Verdana, Geneva, sans-serif;font-size: 12px;background-color:#eeeeee;width:840px;border:none" cellpadding="5" cellspacing="1">
    <tbody>
    <tr>
        <td align="left" style="font-weight:bold;background-color:#eeeeee;padding-left:5px" colspan="2">Customer Details</td>
    </tr>
    <tr>
        <td align="left" style="width:160px;background-color:#ffffff;padding-left:5px">Reservation code</td>
        <td align="left" style="background-color:#ffffff;padding-left:5px">R1AHKECN</td>
    </tr>
            <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Customer</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Mr. John Smith</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Date of Birth</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">1980-06-09</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Address</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">625 2nd Street</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">City</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">San Francisco</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">State</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">CA</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Postal Code</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">94107</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Country</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">United States</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Phone</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">+14506004790</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Email</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">john.smith@gmail.com</td>
        </tr>
                <tr>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Additional Comments</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Please leave car keys by the front door upon delivery.</td>
        </tr>
        </tbody>
</table>
<br />
<table style="font-family:Verdana, Geneva, sans-serif;font-size: 12px;background:#999999;width:840px;border:none" cellpadding="5" cellspacing="1">
<tbody>
<tr>
    <td align="left" style="font-weight:bold;background-color:#eeeeee;padding-left:5px" colspan="3">Rental Details</td>
</tr>
            <tr style="background-color:#343434;color: white" class="location-headers">
            <td align="left" class="col1" style="padding-left:5px"><strong>Pick-up Location</strong></td>
            <td align="left" class="col2" style="padding-left:5px" colspan="2"><strong>Drop-Off Location</strong></td>
        </tr>

    <tr style="background-color:#FFFFFF" class="location-details">
                    <td align="left" class="col1" style="padding-left:5px" colspan="1">
		2. San Francisco Intl. Airport (SFO) - Hwy 101, San Francisco, CA 94128            </td>
                            <td align="left" class="col2" style="padding-left:5px" colspan="2">
		3. Oakland Intl. Airport (OAK) - 1 Airport Dr, Oakland, CA 94621            </td>
            </tr>


    <tr style="background-color:#343434;color: white" class="duration-headers">
                    <td align="left" class="col1" style="padding-left:5px" colspan="1"><strong>Pick-up Date &amp; Time</strong></td>
                            <td align="left" class="col2" style="padding-left:5px" colspan="1"><strong>Drop-off Date &amp; Time</strong></td>
            <td align="right" class="col3" style="padding-right:5px"><strong>Period</strong></td>
            </tr>

    <tr style="background-color:#FFFFFF" class="duration-details">
                    <td align="left" class="col1" style="padding-left:5px" colspan="1">
		October 16, 2015 &nbsp;&nbsp; 11:00 AM            </td>
                            <td align="left" class="col2" style="padding-left:5px" colspan="1">
		October 19, 2015 &nbsp;&nbsp; 10:00 PM            </td>
            <td align="right" class="col3" style="padding-right:5px">
		4 days            </td>
            </tr>

<!-- ITEMS -->
    <tr class="item-headers" style="background-color:#343434;color: white">
        <td align="left" class="col1" style="padding-left:5px"><strong>Selected Cars</strong></td>
        <td align="left" class="col2" style="padding-left:5px"><strong>Price</strong></td>
        <td align="right" class="col3" style="padding-right:5px"><strong>Total</strong></td>
    </tr>
    <tr style="background-color:#FFFFFF" class="items">
        <td align="left" class="col1" style="padding-left:5px">
		Mazda 6, Intermediate        </td>
        <td align="left" class="col2" style="padding-left:5px">
            <span title="1 vehicle(s) x $ 115.72 w/o Tax + $ 10.41 Tax = 1 x $ 126.14" style="cursor:pointer">
		$ 115.72            </span>
        </td>
        <td align="right" class="col3" style="padding-right:5px">
            <span title="$ 115.72 w/o Tax + $ 10.41 Tax = $ 126.14" style="cursor:pointer">
		$ 115.72            </span>
        </td>
    </tr>

<!-- PICKUP FEES -->
    <tr style="background-color:#343434;color: white" class="office-fee-headers">
        <td align="left" class="col1" style="padding-left:5px" colspan="3"><strong>Location Fees</strong></td>
    </tr>
    <tr style="background-color:#FFFFFF" class="office-fees">
        <td align="left" class="col1" style="padding-left:5px">Pick-up fee                    </td>
        <td align="left" class="col2" style="padding-left:5px">
            <span title="1 vehicle(s) x $ 7.44 w/o Tax + $ 0.67 Tax = 1 x $ 8.11" style="cursor:pointer">
		$ 7.44            </span>
        </td>
        <td align="right" class="col3" style="padding-right:5px">
            <span title="$ 7.44 w/o Tax + $ 0.67 Tax = $ 8.11" style="cursor:pointer">
		$ 7.44            </span>
        </td>
    </tr>



<!-- DROPOFF FEES -->
    <tr style="background-color:#FFFFFF" class="office-fees">
        <td align="left" class="col1" style="padding-left:5px">Drop-off fee           (Nightly rate applied)        </td>
        <td align="left" class="col2" style="padding-left:5px">
            <span title="1 vehicle(s) x $ 23.97 w/o Tax + $ 2.16 Tax = 1 x $ 26.13" style="cursor:pointer">
		$ 23.97            </span>
        </td>
        <td align="right" class="col3" style="padding-right:5px">
            <span title="$ 23.97 w/o Tax + $ 2.16 Tax = $ 26.13" style="cursor:pointer">
		$ 23.97            </span>
        </td>
    </tr>

<!-- EXTRAS -->
    <tr class="extra-headers" style="background-color:#343434;color: white">
       <td align="left" class="col1" colspan="3"><strong>Rental Options</strong></td>
    </tr>
    <tr style="background-color:#FFFFFF" class="extras">
         <td align="left" class="col1" style="padding-left:5px">Baby Seat</td>
         <td align="left" class="col2" style="padding-left:5px">
             <span title="1 extra(s) x $ 13.24 w/o Tax + $ 1.19 Tax = 1 x $ 14.43" style="cursor:pointer">
		$ 13.24             </span>
         </td>
         <td align="right" class="col3" style="padding-right:5px">
             <span title="$ 13.24 w/o Tax + $ 1.19 Tax = $ 14.43" style="cursor:pointer">
		$ 13.24            </span>
         </td>
    </tr>
    <tr style="background-color:#FFFFFF" class="extras">
         <td align="left" class="col1" style="padding-left:5px">GPS</td>
         <td align="left" class="col2" style="padding-left:5px">
             <span title="1 extra(s) x $ 13.24 w/o Tax + $ 1.19 Tax = 1 x $ 14.43" style="cursor:pointer">
		$ 13.24             </span>
         </td>
         <td align="right" class="col3" style="padding-right:5px">
             <span title="$ 13.24 w/o Tax + $ 1.19 Tax = $ 14.43" style="cursor:pointer">
		$ 13.24            </span>
         </td>
    </tr>


<!-- TOTAL -->
<tr style="background-color:#343434;color: white" class="total-headers">
    <td align="left" class="col1" colspan="3" style="padding-left:5px"><strong>Total</strong></td>
</tr>
    <tr style="background-color:#FFFFFF">
        <td align="right" class="col1" style="padding-right:5px" colspan="2">
            <strong>Sub Total:</strong>
        </td>
        <td align="right" class="col3" style="padding-right:5px">
            <strong>$ 173.61</strong>
        </td>
    </tr>
    <tr style="background-color:#f2f2f2">
        <td align="right" class="col1" style="padding-right:5px" colspan="2">
		Tax (9.00 %):
        </td>
        <td align="right" class="col3" style="padding-right:5px">
		$ 15.62        </td>
    </tr>
<tr style="background-color:#FFFFFF">
    <td align="right" class="col1" style="padding-right:5px" colspan="2">
        <strong>Grand Total:</strong>
    </td>
    <td align="right" class="col3" style="padding-right:5px">
        <strong>$ 189.24</strong>
    </td>
</tr>
    <tr style="background-color:#f2f2f2">
        <td align="right" class="col1" style="padding-right:5px" colspan="2">
		Deposit:
        </td>
        <td align="right" class="col3" style="padding-right:5px">
            <span title="Cars Deposit ($ 230.00) + Extras Deposit ($ 0.00) = $ 230.00" style="cursor:pointer">
		$ 230.00            </span>
        </td>
    </tr>
</tbody>
</table>

<!-- PAYMENT METHOD DETAILS -->
    <br />
    <table style="font-family:Verdana, Geneva, sans-serif;font-size: 12px;background:#999999;width:840px;border:none" cellpadding="4" cellspacing="1">
        <tr>
            <td align="left" colspan="2" style="font-weight:bold;background-color:#eeeeee;padding-left:5px">Payment Details</td>
        </tr>
        <tr>
            <td align="left" width="30%" style="font-weight:bold;background-color:#ffffff;padding-left:5px">Pay By</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Bank Transfer</td>
        </tr>
        <tr>
            <td align="left" width="30%" style="font-weight:bold;background-color:#ffffff;padding-left:5px">Payment Details</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">Receiver: NATIVE RENTAL, LTD<br />
Account no.: US27 7300 0204 2870 6432<br />
Bank: Bank of America, Inc.</td>
        </tr>
        <tr>
            <td align="left" width="30%" style="font-weight:bold;background-color:#ffffff;padding-left:5px">Transaction ID</td>
            <td align="left" style="background-color:#ffffff;padding-left:5px">N/A</td>
        </tr>
    </table>
\')';

        /**
         * Make Sure that all need car images are in /extensions/car/front/demo-gallery/
         * Make sure that all items bellow has 'demo_image=1','demo_image_2=1','demo_image_3=1' attributes, to load car images from demo gallery
         */
        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}items` (`item_id`, `item_description_page_id`, `manufacturer_id`, `body_type_id`, `transmission_type_id`, `fuel_type_id`, `model_name`, `item_image_1`, `item_image_2`, `item_image_3`, `demo_image_1`, `demo_image_2`, `demo_image_3`, `mileage`, `fuel_consumption`, `engine_capacity`, `max_passengers`, `max_luggage`, `item_doors`, `min_driver_age`, `units_in_stock`, `max_units_per_booking`, `enabled`, `display_in_slider`, `display_in_item_list`, `display_in_price_table`, `display_in_calendar`, `options_display_mode`, `measurement_unit`) VALUES
(1, 192, 3, 2, 2, 2, '207', '1433866270_1432632903_peugeot 207.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '5-6 l/100 km', '1600 ccm', 5, 1, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(2, 193, 2, 2, 2, 1, 'Alto', '1433866289_1432632917_Suzuki alto.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '0', '4-5L/100km', '1000 ccm', 5, 1, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(3, 194, 4, 5, 2, 2, 'Vivaro', '1433866477_1432632928_Opel Vivaro.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '9 l/100 km', '2000 ccm', 8, 1, 4, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(4, 195, 3, 5, 2, 2, 'Boxer', '1433866491_1432632939_Peugeot Boxer.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '8-9 l/100 km', '2200 ccm', 3, 5, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(5, 196, 10, 3, 3, 2, 'A6', '1433866509_1432632949_Audi A6.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '7-9 l/100 km', '2000 ccm', 5, 1, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(6, 197, 9, 3, 3, 2, 'C5', '1433866536_1432899430_c5s.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '5-7 l/100 km', '1600 ccm', 5, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(8, 199, 4, 3, 3, 1, 'Astra Sport Tourer', '1433866619_1432632987_Opel Astra Sport Tourer.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '7-9 l/100 km', '1400 ccm', 5, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(9, 200, 4, 3, 3, 2, 'Insignia', '1433866673_1432899607_Opel Insignia universal22.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '7-9 l/100 km', '2000 ccm', 5, 1, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(10, 201, 7, 1, 1, 1, '6', '1433866303_1432633008_Mazda 6.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '9-11 l/100 km', '2500 ccm', 5, 1, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(12, 203, 6, 4, 3, 1, 'ML350', '1433866707_1432633030_Mercedes ML350.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '10-12 l/100 km', '3500 ccm', 5, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(13, 204, 5, 4, 3, 1, 'Qashqai', '1433866727_1432633039_Nissan Qashqai.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '8-9 l/100 km', '2000 ccm', 5, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(14, 231, 8, 2, 2, 2, 'Fiesta', '1436773115_ford fiesta 2.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '5-6 l/100km', '1400 ccm', 5, 1, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(15, 230, 5, 4, 2, 2, 'Qashqai+2', '1436773210_Nissan Qashqai+2.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '7-9 l/100km', '2000 ccm', 7, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(16, 228, 11, 3, 2, 2, 'Ceed', '1436773158_Kia Ceed SW.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '6-8 l/100km', '1600 ccm', 5, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, ''),
(17, 229, 12, 4, 3, 2, 'Touareg', '1436773349_VW Touareg.jpg', '1437598418_nice-car-interior.png', '1437598419_nice-car-boot.jpg', 1, 1, 1, '', '9-11 l/100km', '2500 ccm', 5, 2, 5, 0, 10, 1, 1, 1, 1, 1, 1, 1, '')";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}item_features` (`item_id`, `feature_id`) VALUES
(13, 8),
(13, 3),
(13, 4),
(13, 2),
(13, 7),
(13, 5),
(13, 6),
(13, 1),
(8, 8),
(8, 3),
(8, 4),
(8, 2),
(8, 7),
(8, 5),
(8, 6),
(8, 1),
(9, 8),
(9, 3),
(9, 4),
(9, 2),
(9, 7),
(9, 5),
(9, 6),
(9, 1),
(3, 8),
(3, 3),
(3, 4),
(3, 2),
(3, 7),
(3, 5),
(3, 6),
(3, 1),
(1, 8),
(1, 3),
(1, 4),
(1, 2),
(1, 7),
(1, 5),
(1, 6),
(1, 1),
(4, 3),
(4, 4),
(4, 7),
(4, 5),
(4, 6),
(4, 1),
(2, 8),
(2, 3),
(2, 4),
(2, 2),
(2, 7),
(2, 1),
(17, 8),
(17, 3),
(17, 4),
(17, 2),
(17, 7),
(17, 5),
(17, 6),
(17, 1),
(15, 8),
(15, 3),
(15, 4),
(15, 2),
(15, 7),
(15, 5),
(15, 6),
(15, 1),
(5, 8),
(5, 3),
(5, 4),
(5, 2),
(5, 7),
(5, 5),
(5, 6),
(5, 1),
(6, 8),
(6, 3),
(6, 4),
(6, 2),
(6, 7),
(6, 5),
(6, 6),
(6, 1),
(14, 8),
(14, 3),
(14, 2),
(14, 7),
(14, 5),
(14, 6),
(14, 1),
(16, 8),
(16, 3),
(16, 4),
(16, 2),
(16, 7),
(16, 5),
(16, 6),
(16, 1),
(10, 8),
(10, 3),
(10, 4),
(10, 2),
(10, 7),
(10, 5),
(10, 6),
(10, 1),
(12, 8),
(12, 3),
(12, 4),
(12, 2),
(12, 7),
(12, 5),
(12, 6),
(12, 1)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}item_locations` (`item_id`, `location_id`, `location_type`) VALUES
(11, 4, 1),
(11, 3, 1),
(11, 2, 1),
(11, 1, 1),
(11, 5, 1),
(11, 6, 1),
(11, 4, 2),
(11, 3, 2),
(11, 2, 2),
(11, 1, 2),
(11, 5, 2),
(11, 6, 2),
(7, 4, 1),
(7, 3, 1),
(7, 2, 1),
(7, 1, 1),
(7, 5, 1),
(7, 6, 1),
(7, 4, 2),
(7, 3, 2),
(7, 2, 2),
(7, 1, 2),
(7, 5, 2),
(7, 6, 2),
(13, 4, 1),
(13, 3, 1),
(13, 2, 1),
(13, 1, 1),
(13, 5, 1),
(13, 6, 1),
(13, 4, 2),
(13, 3, 2),
(13, 2, 2),
(13, 1, 2),
(13, 5, 2),
(13, 6, 2),
(8, 4, 1),
(8, 3, 1),
(8, 2, 1),
(8, 1, 1),
(8, 5, 1),
(8, 6, 1),
(8, 4, 2),
(8, 3, 2),
(8, 2, 2),
(8, 1, 2),
(8, 5, 2),
(8, 6, 2),
(9, 4, 1),
(9, 3, 1),
(9, 2, 1),
(9, 1, 1),
(9, 5, 1),
(9, 6, 1),
(9, 4, 2),
(9, 3, 2),
(9, 2, 2),
(9, 1, 2),
(9, 5, 2),
(9, 6, 2),
(3, 4, 1),
(3, 3, 1),
(3, 2, 1),
(3, 1, 1),
(3, 5, 1),
(3, 6, 1),
(3, 4, 2),
(3, 3, 2),
(3, 2, 2),
(3, 1, 2),
(3, 5, 2),
(3, 6, 2),
(1, 4, 1),
(1, 3, 1),
(1, 2, 1),
(1, 1, 1),
(1, 5, 1),
(1, 6, 1),
(1, 4, 2),
(1, 3, 2),
(1, 2, 2),
(1, 1, 2),
(1, 5, 2),
(1, 6, 2),
(4, 4, 1),
(4, 3, 1),
(4, 2, 1),
(4, 1, 1),
(4, 5, 1),
(4, 6, 1),
(4, 4, 2),
(4, 3, 2),
(4, 2, 2),
(4, 1, 2),
(4, 5, 2),
(4, 6, 2),
(2, 4, 1),
(2, 3, 1),
(2, 2, 1),
(2, 1, 1),
(2, 5, 1),
(2, 6, 1),
(2, 4, 2),
(2, 3, 2),
(2, 2, 2),
(2, 1, 2),
(2, 5, 2),
(2, 6, 2),
(17, 4, 1),
(17, 3, 1),
(17, 2, 1),
(17, 1, 1),
(17, 5, 1),
(17, 6, 1),
(17, 4, 2),
(17, 3, 2),
(17, 2, 2),
(17, 1, 2),
(17, 5, 2),
(17, 6, 2),
(15, 4, 1),
(15, 3, 1),
(15, 2, 1),
(15, 1, 1),
(15, 5, 1),
(15, 6, 1),
(15, 4, 2),
(15, 3, 2),
(15, 2, 2),
(15, 1, 2),
(15, 5, 2),
(15, 6, 2),
(5, 4, 1),
(5, 3, 1),
(5, 2, 1),
(5, 1, 1),
(5, 5, 1),
(5, 6, 1),
(5, 4, 2),
(5, 3, 2),
(5, 2, 2),
(5, 1, 2),
(5, 5, 2),
(5, 6, 2),
(6, 4, 1),
(6, 3, 1),
(6, 2, 1),
(6, 1, 1),
(6, 5, 1),
(6, 6, 1),
(6, 4, 2),
(6, 3, 2),
(6, 2, 2),
(6, 1, 2),
(6, 5, 2),
(6, 6, 2),
(14, 4, 1),
(14, 3, 1),
(14, 2, 1),
(14, 1, 1),
(14, 5, 1),
(14, 6, 1),
(14, 4, 2),
(14, 3, 2),
(14, 2, 2),
(14, 1, 2),
(14, 5, 2),
(14, 6, 2),
(16, 4, 1),
(16, 3, 1),
(16, 2, 1),
(16, 1, 1),
(16, 5, 1),
(16, 6, 1),
(16, 4, 2),
(16, 3, 2),
(16, 2, 2),
(16, 1, 2),
(16, 5, 2),
(16, 6, 2),
(10, 4, 1),
(10, 3, 1),
(10, 2, 1),
(10, 1, 1),
(10, 5, 1),
(10, 6, 1),
(10, 4, 2),
(10, 3, 2),
(10, 2, 2),
(10, 1, 2),
(10, 5, 2),
(10, 6, 2),
(12, 4, 1),
(12, 3, 1),
(12, 2, 1),
(12, 1, 1),
(12, 5, 1),
(12, 6, 1),
(12, 4, 2),
(12, 3, 2),
(12, 2, 2),
(12, 1, 2),
(12, 5, 2),
(12, 6, 2)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}locations` (`location_id`, `location_title`, `location_address`, `pickup_fee`, `dropoff_fee`, `open_mondays`, `open_tuesdays`, `open_wednesdays`, `open_thursdays`, `open_fridays`, `open_saturdays`, `open_sundays`, `open_time_mon`, `open_time_tue`, `open_time_wed`, `open_time_thu`, `open_time_fri`, `open_time_sat`, `open_time_sun`, `close_time_mon`, `close_time_tue`, `close_time_wed`, `close_time_thu`, `close_time_fri`, `close_time_sat`, `close_time_sun`, `afterhours_pickup_location_id`, `afterhours_pickup_fee`, `afterhours_dropoff_location_id`, `afterhours_dropoff_fee`) VALUES
(1, '4. San Jose Intl. Airport (SJC)', '1701 Airport Blvd, San Jose, CA 95110', 99.17, 99.17, 1, 1, 1, 1, 1, 1, 1, '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', -1, 106.61, -1, 106.61),
(2, '3. Oakland Intl. Airport (OAK)', '1 Airport Dr, Oakland, CA 94621', 16.53, 16.53, 1, 1, 1, 1, 1, 1, 1, '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', -1, 23.97, -1, 23.97),
(3, '2. San Francisco Intl. Airport (SFO)', 'Hwy 101, San Francisco, CA 94128', 7.44, 7.44, 1, 1, 1, 1, 1, 1, 1, '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', -1, 14.88, -1, 14.88),
(4, '1. Native Rental HQ', '625 2nd Street, San Francisco, CA 94107', 0.00, 0.00, 1, 1, 1, 1, 1, 1, 1, '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', -1, 7.44, -1, 7.44),
(5, '5. Los Angeles Intl. Airport (LAX)', '1 World Way, Los Angeles, CA 90045', 0.00, 0.00, 1, 1, 1, 1, 1, 1, 1, '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', -1, 7.44, -1, 7.44),
(6, '6. Your preferred address', '', 0.00, 0.00, 1, 1, 1, 1, 1, 1, 1, '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '08:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', '18:00:00', -1, 7.44, -1, 7.44)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}manufacturers` (`manufacturer_id`, `manufacturer_title`) VALUES
(1, 'Toyota'),
(2, 'Suzuki'),
(3, 'Peugeot'),
(4, 'Opel'),
(5, 'Nissan'),
(6, 'Mercedes'),
(7, 'Mazda'),
(8, 'Ford'),
(9, 'Citroen'),
(10, 'Audi'),
(11, 'Kia'),
(12, 'VW')";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}payment_methods` (`payment_method_code`, `method_name`, `method_details`, `method_enabled`, `method_order`, `unpaid_booking_expiration_time`) VALUES
('bank', 'Bank Transfer', 'Receiver: NATIVE RENTAL, LTD\nAccount no.: US27 7300 0204 2870 6432\nBank: Bank of America, Inc.', 1, 2, 604800),
('phone', 'Pay over the Phone', '+1 631 612 4020', 0, 3, 604800),
('poa', 'Pay at Pick-up', 'Credit Card Required', 1, 4, 0),
('pp', 'Online - PayPal', 'youremail@domain.com', 0, 1, 600)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}prepayments` (`prepayment_id`, `item_id`, `period_from`, `period_till`, `prepayment_percentage`) VALUES
(1, 0, 0, 31622399, 100.00)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}price_plans` (`plan_id`, `item_id`, `start_timestamp`, `end_timestamp`, `price_type`, `mon`, `tue`, `wed`, `thu`, `fri`, `sat`, `sun`, `seasonal_price`) VALUES
(1, 1, 0, 0, 1, 23.97, 23.97, 23.97, 23.97, 23.97, 23.97, 23.97, 0),
(2, 1, 0, 0, 2, 1.21, 1.21, 1.21, 1.21, 1.21, 1.21, 1.21, 0),
(3, 2, 0, 0, 1, 18.18, 18.18, 18.18, 18.18, 18.18, 18.18, 18.18, 0),
(4, 2, 0, 0, 2, 0.92, 0.92, 0.92, 0.92, 0.92, 0.92, 0.92, 0),
(5, 3, 0, 0, 1, 49.59, 49.59, 49.59, 49.59, 49.59, 49.59, 49.59, 0),
(6, 3, 0, 0, 2, 2.25, 2.25, 2.25, 2.25, 2.25, 2.25, 2.25, 0),
(7, 4, 0, 0, 1, 47.11, 47.11, 47.11, 47.11, 47.11, 47.11, 47.11, 0),
(8, 4, 0, 0, 2, 2.50, 2.50, 2.50, 2.50, 2.50, 2.50, 2.50, 0),
(9, 5, 0, 0, 1, 42.15, 42.15, 42.15, 42.15, 42.15, 42.15, 42.15, 0),
(10, 5, 0, 0, 2, 2.13, 2.13, 2.13, 2.13, 2.13, 2.13, 2.13, 0),
(11, 6, 0, 0, 1, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 0),
(12, 6, 0, 0, 2, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 0),
(15, 8, 0, 0, 1, 26.45, 26.45, 26.45, 26.45, 26.45, 26.45, 26.45, 0),
(16, 8, 0, 0, 2, 1.33, 1.33, 1.33, 1.33, 1.33, 1.33, 1.33, 0),
(17, 9, 0, 0, 1, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 0),
(18, 9, 0, 0, 2, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 0),
(19, 10, 0, 0, 1, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 0),
(20, 10, 0, 0, 2, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 0),
(23, 12, 0, 0, 1, 46.28, 46.28, 46.28, 46.28, 46.28, 46.28, 46.28, 0),
(24, 12, 0, 0, 2, 2.33, 2.33, 2.33, 2.33, 2.33, 2.33, 2.33, 0),
(25, 13, 0, 0, 1, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 0),
(26, 13, 0, 0, 2, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 1.71, 0),
(27, 14, 0, 0, 1, 18.18, 18.18, 18.18, 18.18, 18.18, 18.18, 18.18, 0),
(28, 14, 0, 0, 2, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0),
(29, 15, 0, 0, 1, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 0),
(30, 15, 0, 0, 2, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0),
(31, 16, 0, 0, 1, 26.45, 26.45, 26.45, 26.45, 26.45, 26.45, 26.45, 0),
(32, 16, 0, 0, 2, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0),
(33, 17, 0, 0, 1, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 33.88, 0),
(34, 17, 0, 0, 2, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0.00, 0)";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}settings` (`conf_key`, `conf_value`) VALUES
('conf_api_max_failed_requests_per_period', '3'),
('conf_api_max_requests_per_period', '50'),
('conf_booking_model', '1'),
('conf_classify_items', '1'),
('conf_currency_code', 'USD'),
('conf_currency_symbol', '$'),
('conf_customer_additional_comments_required', '0'),
('conf_customer_additional_comments_visible', '1'),
('conf_customer_birthdate_required', '1'),
('conf_customer_birthdate_visible', '1'),
('conf_customer_city_required', '1'),
('conf_customer_city_visible', '1'),
('conf_customer_country_required', '0'),
('conf_customer_country_visible', '1'),
('conf_customer_email_required', '1'),
('conf_customer_email_visible', '1'),
('conf_customer_first_name_required', '1'),
('conf_customer_first_name_visible', '1'),
('conf_customer_last_name_required', '1'),
('conf_customer_last_name_visible', '1'),
('conf_cancelled_payment_page_id', '232'),
('conf_confirmation_page_id', '233'),
('conf_customer_phone_required', '1'),
('conf_customer_phone_visible', '1'),
('conf_customer_state_required', '0'),
('conf_customer_state_visible', '1'),
('conf_customer_street_address_required', '1'),
('conf_customer_street_address_visible', '1'),
('conf_customer_title_required', '1'),
('conf_customer_title_visible', '1'),
('conf_customer_zipcode_required', '0'),
('conf_customer_zipcode_visible', '1'),
('conf_deposit_enabled', '1'),
('conf_discount_enabled', '1'),
('conf_maximum_booking_period', '31536000'),
('conf_measurement_unit', 'Mi'),
('conf_minimum_block_period_between_bookings', '7199'),
('conf_minimum_booking_period', '28800'),
('conf_minimum_period_until_pickup', '86400'),
('conf_noon_time', '12:00:00'),
('conf_plugin_version', '{$pluginVersion}'),
('conf_portal_city', 'San Francisco'),
('conf_portal_country', 'United States'),
('conf_portal_email', 'info@yourdomain.com'),
('conf_portal_name', 'Native car rental'),
('conf_portal_phone', '+14506004790'),
('conf_portal_state', 'California'),
('conf_portal_street_address', '625 2nd Street'),
('conf_portal_zipcode', '94107'),
('conf_prepayment_enabled', '1'),
('conf_price_calculation_type', '1'),
('conf_paypal_sandbox_mode', '0'),
('conf_recaptcha_enabled', '0'),
('conf_recaptcha_secret_key', ''),
('conf_recaptcha_site_key', ''),
('conf_search_body_type_required', '0'),
('conf_search_body_type_visible', '1'),
('conf_search_booking_code_required', '0'),
('conf_search_booking_code_visible', '0'),
('conf_search_dropoff_date_required', '1'),
('conf_search_dropoff_date_visible', '1'),
('conf_search_dropoff_location_required', '1'),
('conf_search_dropoff_location_visible', '1'),
('conf_search_enabled', '1'),
('conf_search_fuel_type_required', '0'),
('conf_search_fuel_type_visible', '1'),
('conf_search_pickup_date_required', '1'),
('conf_search_pickup_date_visible', '1'),
('conf_search_pickup_location_required', '1'),
('conf_search_pickup_location_visible', '1'),
('conf_search_transmission_type_required', '0'),
('conf_search_transmission_type_visible', '0'),
('conf_send_emails', '1'),
('conf_short_date_format', 'm/d/Y'),
('conf_show_prices_with_vat', '0'),
('conf_system_style', '1'),
('conf_tos_page_id', '234'),
('conf_updated', '0'),
('conf_vat_percentage', '9')";

        $arrSQL[] = "INSERT INTO `{$this->nrsPrefix}transmission_types` (`transmission_type_id`, `transmission_type_title`) VALUES
(1, 'Tiptronic'),
(2, 'Manual'),
(3, 'Automatic')";

        return $arrSQL;
    }
}