<?php
/**
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

if(!session_id())
{
	session_start();
}
//locate the wp-config.php so we can start to use global variable $wpdb to get database connection and other wp functions
require_once('../../../../wp-config.php');
global $wpdb;

// Load config
$sanitizedExtension = isset($_GET['extension']) ? sanitize_key($_GET['extension']) : "car";
if(file_exists('../'.$sanitizedExtension.'-rental-config.php'))
{
	require('../'.$sanitizedExtension.'-rental-config.php');
} else
{
	require('../car-rental-config.php');
}
// Instead of initializer, include them here
require_once('../includes/static.class.NRSValidator.php');
require_once('../includes/static.class.NRSFormatter.php');
require_once('../includes/static.class.NRSSecurity.php');
require_once('../includes/class.NRSCore.php');
require_once('../includes/final.class.NRSApiLog.php');
// Include specific class
require_once('includes/final.class.NRSAjaxProcessor.php');


$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$ajaxProcessor = new NRSAjaxProcessor($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objAPILog = new NRSAPILog($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$paramAction = isset($_GET['action']) ? sanitize_text_field($_GET['action']) : 0;

switch($paramAction)
{
	case "customer-lookup":
		$validEmail = isset($_GET['email']) && is_email($_GET['email']) ? sanitize_email($_GET['email']) : "";
		$validYearOfBirth = isset($_GET['year']) ? NRSValidator::getValidInteger($_GET['year'], "0000") : "0000";
		$requireYearOfBirth = $objCore->getCustomerFieldStatus("birthdate", "REQUIRED") ? TRUE : FALSE;
		$JSONParams = $ajaxProcessor->getAjaxCustomerDetails($validEmail, $validYearOfBirth, $requireYearOfBirth);
		$isFailed = $JSONParams['error'] == 0 ? FALSE : TRUE;
		$totalRequestsLeft = $objAPILog->getTotalRequestsLeft();
		$failedRequestsLeft = $objAPILog->getFailedRequestsLeft();
		$emailAttemptsLeft = $objAPILog->getFailedEmailAttemptsLeft($validEmail);

		if($totalRequestsLeft == 0 || $failedRequestsLeft == 0 || $emailAttemptsLeft == 0)
		{
			// Override default return
			$JSONParams = $ajaxProcessor->getBlockMessage();
		}
		// Save log
		$objAPILog->saveLog($validEmail, $validYearOfBirth, $requireYearOfBirth, $isFailed);
		$ajaxProcessor->sendJSONResponse($JSONParams);
		break;
	default:
		$JSONParams = $ajaxProcessor->getErrorMessage();
		$ajaxProcessor->sendJSONResponse($JSONParams);
}