<?php
/**
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objPayPal = new NRSPayPal($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getConfig('paypal_sandbox_mode'));

/*
 * API CALLBACK PATH: http://yourdomain.com/wp-content/plugins/native-rental-system/car-api-paypal.php
 * NOTES:
Since this script is executed on the back end between the PayPal server and this
script, you will want to log errors to a file or email. Do not try to use echo
or print--it will not work!

Here we are turning on PHP error logging to a file called ".ipn_errors.log". Make
sure your web server has permissions to write to that file. In a production
environment it is better to have that log file outside of the web root.
*/
$errorLogFile = $GLOBALS['NRS_PLUGIN_PATH'].'/.ipn_errors.log';
$debugFile = $GLOBALS['NRS_PLUGIN_PATH'].'/.ipn_debug.log';

// Try to keep error log file always enabled, even on live website to have an ability to investigate broken/invalid transactions
$errorLogEnabled = TRUE;
// Enable debug only if testing. Do not use it in production
$debugEnabled = FALSE;

try
{
    $objPayPal->requirePostMethod();
    $verified = $objPayPal->processIpn();
} catch (Exception $e)
{
    if($errorLogEnabled)
    {
        $fp = fopen($errorLogFile, 'a');
        fwrite($fp, $e->getMessage() . "\n\n");
        fclose($fp);  // close file
    }
    exit(0);
}
// DEBUG: Force verified to process further debug
//$verified = TRUE;
$errorMessage = "";
/*
The processIpn() method returned true if the IPN was "VERIFIED" and false if it
was "INVALID".
*/
if ($verified)
{
    /*
    Once you have a verified IPN you need to do a few more checks on the POST
    fields--typically against data you stored in your database during when the
    end user made a purchase (such as in the "success" page on a web payments
    standard button). The fields PayPal recommends checking are:

        1. Check the $_POST['payment_status'] is "Completed"
	    2. Check that $_POST['txn_id'] has not been previously processed
	    3. Check that $_POST['invoice'] is your Invoice Id is correct
	    4. Check that $_POST['receiver_email'] is your Primary PayPal email
	    5. Check that $_POST['payment_amount'] and $_POST['payment_currency']
	       are correct

    Since implementations on this varies, I will leave these checks out of this
    example and just send an email using the getTextReport() method to get all
    of the details about the IPN with 'Verified IPN' and $listener->getTextReport();
    */

    $arrIPNData = $objPayPal->getIPNData();
    $sanitizedBookingCode = sanitize_text_field($arrIPNData['invoice']);

    $objMail = new NRSMail($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
    $objBooking = new NRSBooking($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objMail, $sanitizedBookingCode);
    $objInvoice = new NRSInvoice($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objBooking->getBookingId());
    if($objBooking->isValidBooking())
    {
        if(isset($arrIPNData['payment_status'], $arrIPNData['payer_email'], $arrIPNData['txn_id']))
        {
            if($arrIPNData['payment_status'] == "Completed" || $arrIPNData['payment_status'] == "Pending")
            {
                // ------------------------------------------------------------------------------------------------------
                // Just to have nice printout setup out there
                $printPayerEmail = sanitize_text_field($arrIPNData['payer_email']);
                $printTxnId = sanitize_text_field($arrIPNData['txn_id']);
                ob_start();
                // Include invoice template
                include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.paypal-transaction-details.php');
                $payPalHtmlToAppend = ob_get_contents();
                ob_end_clean();
                // ------------------------------------------------------------------------------------------------------
                $appendStatus = $objInvoice->appendInvoiceHTML($payPalHtmlToAppend);

                $objBooking->markPaidBooking(TRUE, $arrIPNData['txn_id'], $arrIPNData['payer_email']);
            } else if ($arrIPNData['payment_status'] == "Refunded" || $arrIPNData['payment_status'] == "Reversed")
            {
                $objBooking->refundBooking(TRUE);
            } else
            {
                $errorMessage .= "Payment status - ".sanitize_text_field($arrIPNData['payment_status'])." - is unknown.\n";
            }
        } else
        {
            $errorMessage .= "Payment status, payer email or transaction id parameter is missing.\n";
        }
    } else
    {
        $errorMessage .= "Booking code - {$sanitizedBookingCode} - is invalid.\n\n";
    }
} else
{
    $errorMessage .= "Invalid IPN\n";
    /*
    An Invalid IPN *may* be caused by a fraudulent transaction attempt. It's
    a good idea to have a developer or sys admin manually investigate any
    invalid IPN with 'Invalid IPN' and, $listener->getTextReport().
    */
}

if($errorLogEnabled)
{
    $fp = fopen($errorLogFile, 'a');
    fwrite($fp, "{$errorMessage}\n");
    fclose($fp);  // close file
}
if($debugEnabled)
{
    $fp = fopen($debugFile, 'a');
    fwrite($fp, $verified ? "Verified IPN\n" : "Invalid IPN\n");
    fwrite($fp, $objPayPal->getTextReport()."\n\n");
    fclose($fp);  // close file
}