<?php
/**
 * Booking step no. 2
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objItemsObserver = new NRSItemsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objDepositsObserver = new NRSItemDepositsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objSearch = new NRSResultsSearch($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objMail = new NRSMail($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objBooking = new NRSBooking($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objMail, $objSearch->getBookingCode());
$objPickupLocationManager = new NRSLocation(
	$GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'],
	$objCore->getAllConfigArray(), $objSearch->getPickupLocationId()
);
$objDropoffLocationManager = new NRSLocation(
	$GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'],
	$objCore->getAllConfigArray(), $objSearch->getDropoffLocationId()
);

// Search fields visibility settings
$pickupLocationVisible = $objCore->getSearchFieldStatus("pickup_location", "VISIBLE");
$pickupDateVisible = $objCore->getSearchFieldStatus("pickup_date", "VISIBLE");
$dropoffLocationVisible = $objCore->getSearchFieldStatus("dropoff_location", "VISIBLE");
$dropoffDateVisible = $objCore->getSearchFieldStatus("dropoff_date", "VISIBLE");
$bodyTypeVisible = $objCore->getSearchFieldStatus("body_type", "VISIBLE");
$transmissionTypeVisible = $objCore->getSearchFieldStatus("transmission_type", "VISIBLE");
$fuelTypeVisible = $objCore->getSearchFieldStatus("fuel_type", "VISIBLE");
$existingBookingCodeVisible = $objCore->getSearchFieldStatus("booking_code", "VISIBLE");

if($objSearch->isNewBooking() == FALSE)
{
	$printPageLabel = $objCore->getLangText('NRS_RESERVATION_NO_TEXT')." ".$objSearch->getBookingCode()." ".$objCore->getLangText('NRS_RESERVATION_EDIT_TEXT');
} else
{
	$printPageLabel = $objCore->getLangText('NRS_RESERVATION_DATA_TEXT');
}

if($objSearch->isValidSearch())
{
	$pickupLocationData = $objPickupLocationManager->getLocationDetails($objSearch->getLocalPickupDayOfWeek());
	$dropoffLocationData = $objDropoffLocationManager->getLocationDetails($objSearch->getLocalDropoffDayOfWeek());
	$pickupNightlyRateApplied = $objPickupLocationManager->isAfterhoursTime($objSearch->getLocalPickupDayOfWeek(), $objSearch->getLocalPickupTime());
	$dropoffNightlyRateApplied = $objDropoffLocationManager->isAfterhoursTime($objSearch->getLocalDropoffDayOfWeek(), $objSearch->getLocalDropoffTime());

	/*************************************************************/
	// ------------------ Pickup Fee & details -------------------
	$pickupFeeDetails = $pickupLocationData['print_open_hours'].' - '.$pickupLocationData['print_pickup_fee_dynamic'];
	if($objPickupLocationManager->isPickupWorkingInAfterhours($objSearch->getLocalPickupDayOfWeek()))
	{
		$pickupFeeDetails .= ', '.$objCore->getLangText('NRS_RESERVATION_AFTERHOURS_TEXT').' - '.$pickupLocationData['print_afterhours_pickup_fee_dynamic'];
	}
	$pickupFee = $pickupNightlyRateApplied ? $pickupLocationData['print_afterhours_pickup_fee_dynamic'] : $pickupLocationData['print_pickup_fee_dynamic'];
	/*************************************************************/


	/*************************************************************/
	// ------------------ Dropoff Fee & details -------------------
	$dropoffFeeDetails = $dropoffLocationData['print_open_hours'].' - '.$dropoffLocationData['print_dropoff_fee_dynamic'];
	if($objDropoffLocationManager->isDropoffWorkingInAfterhours($objSearch->getLocalDropoffDayOfWeek()))
	{
		$dropoffFeeDetails .= ', '.$objCore->getLangText('NRS_RESERVATION_AFTERHOURS_TEXT').' - '.$dropoffLocationData['print_afterhours_dropoff_fee_dynamic'];
	}
	$dropoffFee = $dropoffNightlyRateApplied ? $dropoffLocationData['print_afterhours_dropoff_fee_dynamic'] : $dropoffLocationData['print_dropoff_fee_dynamic'];
	/*************************************************************/

	$allItemTypes = $objItemsObserver->getAllBodyTypes();
	$classifiedItems = $objItemsObserver->areItemsClassified();
	$gotResults = false;
	$items = array();
	$itemTypesWithItems = array();
	if($classifiedItems)
	{
		$itemTypesWithItems = array();
		foreach($allItemTypes AS $type)
		{
			$type['got_search_result'] = false;
			$itemIds = $objSearch->getAvailableItemIdsForType($type['body_type_id']);
			$objSearchManagerForItems = new NRSSearchManagerForItems(
				$GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray(),
				$objBooking->getBookingId(), $objSearch->getPickupLocationId(), $itemIds, $objSearch->getSelectedItemUnits(), $objSearch->getSelectedItemOptions()
			);
			$type['items'] = $objSearchManagerForItems->getAvailableElements($objSearch->getPickupTimestamp(), $objSearch->getDropoffTimestamp());

			if(sizeof($type['items']) > 0)
			{
				$type['got_search_result'] = true;
				$gotResults = true;
				// Add to stack
				$itemTypesWithItems[] = $type;
			}
		}
	} else
	{
		// Get all items from body type 0 and other body types (last '-1' parameters means, that we skip body type check)
		$itemIds = $objSearch->getAvailableItemIds();
		$objSearchManagerForItems = new NRSSearchManagerForItems(
			$GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray(),
			$objBooking->getBookingId(), $objSearch->getPickupLocationId(), $itemIds, $objSearch->getSelectedItemUnits(), $objSearch->getSelectedItemOptions()
		);
		$items = $objSearchManagerForItems->getAvailableElements($objSearch->getPickupTimestamp(), $objSearch->getDropoffTimestamp());

		if(sizeof($items) > 0)
		{
			$gotResults = true;
		}
	}

	if($gotResults)
	{
		wp_enqueue_script( 'custom_script5', $GLOBALS['NRS_FRONT_URL'].'js/jquery.validate.js' );

		// Load template
		if($classifiedItems)
		{
			include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.step2-classified-search-results.php');
		} else
		{
			include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.step2-search-results.php');
		}
	} else
	{
		include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.booking-failure-with-search-all-buttons.php');
	}
} else
{
	// Load failure template
	include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.booking-failure.php');
}