<?php
/**
 * Booking step no. 4
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objDepositsObserver = new NRSItemDepositsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objPrepaymentsObserver = new NRSItemPrepaymentsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objSearch = new NRSResultsSearch($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objMail = new NRSMail($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objBooking = new NRSBooking($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objMail, $objSearch->getBookingCode());
$objPickupLocationManager = new NRSLocation(
    $GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'],
    $objCore->getAllConfigArray(), $objSearch->getPickupLocationId()
);
$objDropoffLocationManager = new NRSLocation(
    $GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'],
    $objCore->getAllConfigArray(), $objSearch->getDropoffLocationId()
);

// Search fields visibility settings
$pickupLocationVisible = $objCore->getSearchFieldStatus("pickup_location", "VISIBLE");
$pickupDateVisible = $objCore->getSearchFieldStatus("pickup_date", "VISIBLE");
$dropoffLocationVisible = $objCore->getSearchFieldStatus("dropoff_location", "VISIBLE");
$dropoffDateVisible = $objCore->getSearchFieldStatus("dropoff_date", "VISIBLE");

if($objSearch->isNewBooking() == false)
{
    $printPageLabel = $objCore->getLangText('NRS_ITEM_RENTAL_DETAILS_TEXT')." - ".$objCore->getLangText('NRS_RESERVATION_NO_TEXT')." ".$objSearch->getBookingCode()." ".$objCore->getLangText('NRS_RESERVATION_EDIT_TEXT');
} else
{
    $printPageLabel = $objCore->getLangText('NRS_ITEM_RENTAL_DETAILS_TEXT');
}

// Customer fields visibility settings
$titleVisible = $objCore->getCustomerFieldStatus("title", "VISIBLE");
$firstNameVisible = $objCore->getCustomerFieldStatus("first_name", "VISIBLE");
$lastNameVisible = $objCore->getCustomerFieldStatus("last_name", "VISIBLE");
$birthdateVisible = $objCore->getCustomerFieldStatus("birthdate", "VISIBLE");
$streetAddressVisible = $objCore->getCustomerFieldStatus("street_address", "VISIBLE");
$cityVisible = $objCore->getCustomerFieldStatus("city", "VISIBLE");
$stateVisible = $objCore->getCustomerFieldStatus("state", "VISIBLE");
$zipcodeVisible = $objCore->getCustomerFieldStatus("zipcode", "VISIBLE");
$countryVisible = $objCore->getCustomerFieldStatus("country", "VISIBLE");
$phoneVisible = $objCore->getCustomerFieldStatus("phone", "VISIBLE");
$emailVisible = $objCore->getCustomerFieldStatus("email", "VISIBLE");
$additionalCommentsVisible = $objCore->getCustomerFieldStatus("additional_comments", "VISIBLE");

// If it is not visible, then if will not be required (function will always return false of 'required+not visible')
$boolTitleRequired = $objCore->getCustomerFieldStatus("title", "REQUIRED") ? TRUE : FALSE;
$boolBirthdateRequired = $objCore->getCustomerFieldStatus("birthdate", "REQUIRED") ? TRUE : FALSE;
$boolEmailRequired = $objCore->getCustomerFieldStatus("email", "REQUIRED") ? TRUE : FALSE;

$titleRequired = $objCore->getCustomerFieldStatus("title", "REQUIRED") ? 'required' : '';
$firstNameRequired = $objCore->getCustomerFieldStatus("first_name", "REQUIRED") ? 'required' : '';
$lastNameRequired = $objCore->getCustomerFieldStatus("last_name", "REQUIRED") ? 'required' : '';
$birthdateRequired = $objCore->getCustomerFieldStatus("birthdate", "REQUIRED") ? 'required' : '';
$streetAddressRequired = $objCore->getCustomerFieldStatus("street_address", "REQUIRED") ? 'required' : '';
$cityRequired = $objCore->getCustomerFieldStatus("city", "REQUIRED") ? 'required' : '';
$stateRequired = $objCore->getCustomerFieldStatus("state", "REQUIRED") ? 'required' : '';
$zipcodeRequired = $objCore->getCustomerFieldStatus("zipcode", "REQUIRED") ? 'required' : '';
$countryRequired = $objCore->getCustomerFieldStatus("country", "REQUIRED") ? 'required' : '';
$phoneRequired = $objCore->getCustomerFieldStatus("phone", "REQUIRED") ? 'required' : '';
$emailRequired = $objCore->getCustomerFieldStatus("email", "REQUIRED") ? 'required' : '';
$additionalCommentsRequired = $objCore->getCustomerFieldStatus("additional_comments", "REQUIRED") ? 'required' : '';

// We call this externally because this want to get titleDropDown, and because this only applies to existing customer
$objCustomer = new NRSCustomer($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], "", $objBooking->getCustomerId());
$customerData = $objCustomer->getCustomerDetails();
$validTitle = isset($customerData['title']) ? $customerData['title'] : "";
$validFirstName = isset($customerData['first_name']) ? $customerData['first_name'] : "";
$validLastName = isset($customerData['last_name']) ? $customerData['last_name'] : "";
$validBirthdate = isset($customerData['birthdate']) ? $customerData['birthdate'] : "0000-00-00";
$birthdateParts = explode("-", $validBirthdate);
$validBirthYear = isset($birthdateParts[0]) ? $birthdateParts[0] : "0000";
$validBirthMonth = isset($birthdateParts[1]) ? $birthdateParts[1] : "00";
$validBirthDay = isset($birthdateParts[2]) ? $birthdateParts[2] : "00";
$validStreetAddress = isset($customerData['street_address']) ? $customerData['street_address'] : "";
$validCity = isset($customerData['city']) ? $customerData['city'] : "";
$validState = isset($customerData['state']) ? $customerData['state'] : "";
$validZIPCode = isset($customerData['zipcode']) ? $customerData['zipcode'] : "";
$validCountry = isset($customerData['country']) ? $customerData['country'] : "";
$validPhone = isset($customerData['phone']) ? $customerData['phone'] : "";
$validEmail = isset($customerData['email']) ? $customerData['email'] : "";
$validAdditionalComments = isset($customerData['additional_comments']) ? $customerData['additional_comments'] : "";

// Set defaults
$pickupLocationData = array();
$dropoffLocationData = array();
if($objSearch->isValidSearch())
{
    $priceSummary = $objSearch->getPriceSummary();
    $paymentMethods = $objCore->getPaymentMethods($objSearch->getPaymentMethodCode());
    $selectedPaymentMethod = $objCore->getPaymentDataByCode($objSearch->getPaymentMethodCode());
    $selectedPaymentMethodName = isset($selectedPaymentMethod['method_name']) ? $selectedPaymentMethod['method_name'] : "";
    $selectedPaymentMethodDetails = isset($selectedPaymentMethod['method_details']) ? $selectedPaymentMethod['method_details'] : "";
    $printSelectedPaymentMethodDetails = isset($selectedPaymentMethod['method_details']) ? $selectedPaymentMethod['print_method_details'] : "";
    $arrPaymentCodes = $objCore->getPaymentMethodCodes();
    $pickupLocationData = $objPickupLocationManager->getLocationDetails($objSearch->getLocalPickupDayOfWeek());
    $dropoffLocationData = $objDropoffLocationManager->getLocationDetails($objSearch->getLocalDropoffDayOfWeek());
    $printPickupMainColspan = $dropoffLocationVisible ? 1 : 3;
    $printDropoffMainColspan = $pickupLocationVisible ? 2 : 3;
    $printPickupColspan = $dropoffDateVisible ? 1 : 3;
    $printDropoffColspan = $pickupDateVisible ? 1 : 2;

    if(in_array("pp",$arrPaymentCodes))
    {
        if(in_array("poa",$arrPaymentCodes))
        {
            $printPayNowText = $objCore->getLangText('NRS_PAY_NOW_OR_AT_PICKUP_TEXT');
        } else
        {
            $printPayNowText = $objCore->getLangText('NRS_PAY_NOW_TEXT');
        }
    } else
    {
        if(in_array("bank",$arrPaymentCodes) || in_array("phone",$arrPaymentCodes))
        {
            $printPayNowText = $objCore->getLangText('NRS_PAY_NOW_OR_AT_PICKUP_TEXT');
        } else
        {
            $printPayNowText = $objCore->getLangText('NRS_PAY_AT_PICKUP_TEXT');
        }
    }
}

// START: Are we booking only those items who has available units in stock?
$selectedItemIds = $objSearch->getSelectedItemIds();
$objSearchManagerForItems = new NRSSearchManagerForItems(
    $GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray(),
    $objBooking->getBookingId(), $objSearch->getPickupLocationId(), $selectedItemIds, $objSearch->getSelectedItemUnits(), $objSearch->getSelectedItemOptions()
);
$availableOfSelectedItems = $objSearchManagerForItems->getAvailableElements($objSearch->getPickupTimestamp(), $objSearch->getDropoffTimestamp());

$totalSelectedItems = sizeof($selectedItemIds);
$totalAvailableOfSelectedItems = sizeof($availableOfSelectedItems);
// END: Are we booking only those items who has available units in stock?

if($totalAvailableOfSelectedItems > 0 && $objSearch->isValidSearch())
{
    wp_enqueue_script( 'custom_script5', $GLOBALS['NRS_FRONT_URL'].'js/jquery.validate.js' );
    wp_enqueue_script( 'nrs-frontend-js' );

    // Load template
    include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.step4-booking-details.php');
} else if(!$totalSelectedItems == 0 && $objSearch->isValidSearch())
{
    include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.booking-failure-with-search-all-buttons.php');
} else
{
    // Load failure template
    include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.booking-failure.php');
}