<?php
/**
 * Booking step no. 5
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

$objCore = new NRSCore($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objPayPal = new NRSPayPal($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getConfig('paypal_sandbox_mode'));
$objDepositsObserver = new NRSItemDepositsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objPrepaymentsObserver = new NRSItemPrepaymentsObserver($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objSearch = new NRSResultsSearch($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray());
$objMail = new NRSMail($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG']);
$objBooking = new NRSBooking($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objMail, $objSearch->getBookingCode());
$objCustomer = new NRSCustomer($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objSearch->getCustomerEmail());
$objPickupLocation = new NRSLocation($this->internalWPDB, $this->nrsPrefix, $this->lang, $objCore->getAllConfigArray(), $objSearch->getPickupLocationId());
$objDropoffLocation = new NRSLocation($this->internalWPDB, $this->nrsPrefix, $this->lang,$objCore->getAllConfigArray(), $objSearch->getDropoffLocationId());
$objPickupLocationManager = new NRSLocation(
	$GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'],
	$objCore->getAllConfigArray(), $objSearch->getPickupLocationId()
);
$objDropoffLocationManager = new NRSLocation(
	$GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'],
	$objCore->getAllConfigArray(), $objSearch->getDropoffLocationId()
);

// Search fields visibility settings
$pickupLocationVisible = $objCore->getSearchFieldStatus("pickup_location", "VISIBLE");
$pickupDateVisible = $objCore->getSearchFieldStatus("pickup_date", "VISIBLE");
$dropoffLocationVisible = $objCore->getSearchFieldStatus("dropoff_location", "VISIBLE");
$dropoffDateVisible = $objCore->getSearchFieldStatus("dropoff_date", "VISIBLE");
// It's just for search fields, not for car details itself
//$bodyTypeVisible = $objCore->getSearchFieldStatus("body_type", "VISIBLE");
//$transmissionTypeVisible = $objCore->getSearchFieldStatus("transmission_type", "VISIBLE");
//$fuelTypeVisible = $objCore->getSearchFieldStatus("fuel_type", "VISIBLE");
//$existingBookingCodeVisible = $objCore->getSearchFieldStatus("booking_code", "VISIBLE");

// Customer fields visibility settings
$titleVisible = $objCore->getCustomerFieldStatus("title", "VISIBLE");
$firstNameVisible = $objCore->getCustomerFieldStatus("first_name", "VISIBLE");
$lastNameVisible = $objCore->getCustomerFieldStatus("last_name", "VISIBLE");
$birthdateVisible = $objCore->getCustomerFieldStatus("birthdate", "VISIBLE");
$streetAddressVisible = $objCore->getCustomerFieldStatus("street_address", "VISIBLE");
$cityVisible = $objCore->getCustomerFieldStatus("city", "VISIBLE");
$stateVisible = $objCore->getCustomerFieldStatus("state", "VISIBLE");
$zipcodeVisible = $objCore->getCustomerFieldStatus("zipcode", "VISIBLE");
$countryVisible = $objCore->getCustomerFieldStatus("country", "VISIBLE");
$phoneVisible = $objCore->getCustomerFieldStatus("phone", "VISIBLE");
$emailVisible = $objCore->getCustomerFieldStatus("email", "VISIBLE");
$additionalCommentsVisible = $objCore->getCustomerFieldStatus("additional_comments", "VISIBLE");

// START: Are we booking only those items who has available units in stock?
$selectedItemIds = $objSearch->getSelectedItemIds();
$objSearchManagerForItems = new NRSSearchManagerForItems(
    $GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objCore->getAllConfigArray(),
    $objBooking->getBookingId(), $objSearch->getPickupLocationId(), $selectedItemIds, $objSearch->getSelectedItemUnits(), $objSearch->getSelectedItemOptions()
);
$availableOfSelectedItems = $objSearchManagerForItems->getAvailableElements($objSearch->getPickupTimestamp(), $objSearch->getDropoffTimestamp());

$totalSelectedItems = sizeof($selectedItemIds);
$totalAvailableOfSelectedItems = sizeof($availableOfSelectedItems);
// END: Are we booking only those items who has available units in stock?


$bookingCode = "";
$invoiceHtml = "";
$emailSentSuccessfully = TRUE;
if ($totalAvailableOfSelectedItems > 0 && $objSearch->isValidSearch())
{
	// First - get the prices summary
	// NOTE 1: Order is important booking can be saved with saveBookingData(..) only after objSearch->getPriceSummary() was called.
	// NOTE 2: This is because if we would save data first, and we would have only 1 car in database for that period,
	//         then our price summary would not be able to pull that car as available for the booking
	$priceSummary =  $objSearch->getPriceSummary();

	// First - save new customer data
	// We set update last visit timestamp to TRUE here, because we want that customers last visit time would be updated to current time
	$objCustomer->saveCustomerData($objSearch->getCustomerInputDataArray(), TRUE);
	// Second - Pass all search data and save the booking (order is important, because we use booking customer id in booking manager
	// NOTE: Order is important, booking can only be saved after objCustomer->saveCustomerData(..) was called to not to loose customer id
	$objBooking->saveBookingData($objCustomer->getCustomerId(), $objSearch->getSearchInputDataArray());
	// NOTE: Order is important, booking invoice html can be created only after BookingManager->saveBookingData(..) was called
	/*******************************************************************************************************/
	$customerDetails =  $objCustomer->getCustomerDetails();
	$pickupLocationData = $objPickupLocation->getLocationDetails($objSearch->getLocalPickupDayOfWeek());
	$dropoffLocationData = $objDropoffLocation->getLocationDetails($objSearch->getLocalDropoffDayOfWeek());
	$printPickupMainColspan = $dropoffLocationVisible ? 1 : 3;
	$printDropoffMainColspan = $pickupLocationVisible ? 2 : 3;
	$printPickupColspan = $dropoffDateVisible ? 1 : 3;
	$printDropoffColspan = $pickupDateVisible ? 1 : 2;

	if($objSearch->getPaymentMethodCode() == "pp")
	{
		$printPayNowText = $objCore->getLangText('NRS_STEP5_PAID_ONLINE_TEXT');
	} else
	{
		$printPayNowText = $objCore->getLangText('NRS_STEP5_PAY_AT_PICKUP_TEXT');
	}
	$paymentData = $objCore->getPaymentDataByCode($objSearch->getPaymentMethodCode());
	$showPaymentMethodDetails = FALSE;
	$printPaymentMethodName = "";
	$printPaymentMethodDetails = "";

	if($objPrepaymentsObserver->arePrepaymentsEnabled() && in_array($objSearch->getPaymentMethodCode(), array("poa", "bank", "phone")))
	{
		$showPaymentMethodDetails = TRUE;
	}
	$printPaymentMethodName = $paymentData['method_name'];
	$printPaymentMethodDetails = nl2br($paymentData['method_details']);

	ob_start();
	// Include invoice template
	include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.step5-booking-invoice.php');
	$invoiceHtml = ob_get_contents();
	ob_end_clean();
	/*******************************************************************************************************/
	$customerDetails = $objCustomer->getCustomerDetails();

	// Create the invoice
	$pickupLocationHTML = $objPickupLocation->getPrintPickupLocation($objSearch->getLocalPickupDayOfWeek());
	$dropoffLocationHTML = $objDropoffLocation->getPrintDropoffLocation($objSearch->getLocalDropoffDayOfWeek());
	// NOTE: Order is important, new instance must be created only after BookingManager->saveBookingData(..) was called
	// Third - save invoice
	$objInvoice = new NRSInvoice($GLOBALS['wpdb'], $GLOBALS['NRS_PREFIX'], $GLOBALS['NRS_LANG'], $objBooking->getBookingId());
	$objInvoice->saveInvoiceHTML(
		$customerDetails['print_full_name'], $customerDetails['email'],
		$priceSummary['overall']['grand_total'], $priceSummary['overall']['fixed_deposit_amount'], $priceSummary['overall']['total_pay_now'],
		$pickupLocationHTML, $dropoffLocationHTML, $invoiceHtml
	);
	//die($invoiceHtml);

	// Process Booking
	if(
		$objSearch->isPaymentRequired() == FALSE
		|| in_array($objSearch->getPaymentMethodCode(), array("poa", "bank", "phone"))
	) {
		// Send confirmation email
		$emailSentSuccessfully = $objMail->sendBookingDetailsEmail($objBooking->getBookingId(), TRUE);
	} else if($objSearch->getPaymentMethodCode() == "pp")
	{
		// Process to PayPal order page
		$paymentMethodDetails = $objCore->getPaymentDataByCode('pp');
		$businessEmail = isset($paymentMethodDetails['method_details']) ? sanitize_email($paymentMethodDetails['method_details']) : "";
		if ($businessEmail != "")
		{
			if($objCore->getConfig('confirmation_page_id') != "" && $objCore->getConfig('confirmation_page_id') != 0)
			{
				$confirmURL = get_permalink($objCore->getConfig('confirmation_page_id'));
			} else
			{
				$confirmURL = site_url();
			}

			if($objCore->getConfig('cancelled_payment_page_id') != "" && $objCore->getConfig('cancelled_payment_page_id') != 0)
			{
				$cancelURL = get_permalink($objCore->getConfig('cancelled_payment_page_id'));
			} else
			{
				$cancelURL = site_url();
			}

			// If there is a valid business email set, process the transfer to PayPal payment page
			$objPayPal->addField('business', $businessEmail);
			$objPayPal->addField('notify_url', site_url().'/wp-content/plugins/native-rental-system/car-api-paypal.php');
			$objPayPal->addField('return', $confirmURL);
			$objPayPal->addField('cancel_return', $cancelURL);
			$objPayPal->addField('item_name', $objCore->getConfig('portal_name'));
			$objPayPal->addField('invoice', $objBooking->getBookingCode());
			$objPayPal->addField('currency_code', $objCore->getConfig('currency_code'));
			$objPayPal->addField('amount', number_format(floatval($priceSummary['overall']['total_pay_now']), 2, '.', ''));
			//$objPayPal->submitPayPalPost(); // submit the fields to paypal
			//$objPayPal->dumpFields();      // for debugging, output a table of all the fields
		}

		// Send confirmation email
		$emailSentSuccessfully = $objMail->sendBookingDetailsEmail($objBooking->getBookingId(), TRUE);
	}
}

// NOTE! Do not use 'sizeof(items)' in verification bellow, because car was just booked and removed from available db
if($objSearch->isValidSearch())
{
	// SUCCEED (booking confirmed)
	wp_enqueue_script( 'custom_script5', $GLOBALS['NRS_FRONT_URL'].'js/jquery.validate.js' );

	if($objSearch->getPaymentMethodCode() == "pp")
	{
		// Load template
		include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.step5-processing-paypal-payment.php');
	} else
	{
		// Load template
		include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.booking-confirmed.php');
	}

	// If it's desired to kill the session, also delete the session cookie.
	// Note: This will destroy the session, and not just the session data!
    // This has to be moved out of the code before headers
    /*if (ini_get('session.use_cookies'))
    {
        $params = session_get_cookie_params();
        setcookie(session_name(), '', time() - 42000,
            $params['path'], $params['domain'],
            $params['secure'], $params['httponly']
        );
    }*/

    // Finally, destroy the session
	// TODO: At least in local host the session destroy bellow sometimes (not always) produces this error:
    // Warning: session_destroy(): Session object destruction failed in <..>display-step5-booking-process.php on line 215
    // Not sure why it does that, because booking appears to work well.
	session_destroy();
} else
{
	// Load failure template
	include($GLOBALS['NRS_EXTENSION_FRONT_PATH'].'templates/template.booking-failure.php');
}