<?php
/**
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSAjaxProcessor
{
	protected $internalWPDB = NULL;
	protected $nrsPrefix 	= "";
	protected $lang 		= NULL;

	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
	{
		$this->internalWPDB = $paramWPDB;
		$this->nrsPrefix = sanitize_text_field($paramNRSPrefix);

		// Already sanitized before in it's constructor. Too much sanitation will kill the system speed
		$this->lang = $paramNRSLang;
	}

	public function concatReplyMessages(array $replyMessages)
	{
		$ret = array();
		if (sizeof($replyMessages) == 1 && is_array($replyMessages[0]))
		{
			$ret = $replyMessages[0];
		} else if (sizeof($replyMessages) > 1 && is_array($replyMessages[0]) && is_array($replyMessages[1]))
		{
			$firstMessageDataArray = $replyMessages[0];
			for($i = 1; $i < sizeof($replyMessages); $i++)
			{
				$firstMessageDataArray['message'.($i+1)] = $replyMessages[$i]['message'];
			}

			$ret = $firstMessageDataArray;
		}

		return $ret;
	}


	public function sendJSONResponse($JSONParams)
	{
		if(isset($JSONParams['error']) && isset($JSONParams['message']))
		{
			echo json_encode($JSONParams);
		} else
		{
			// Unknown Error, required JSON Response params are missing
			$JSONParams = $this->getErrorMessage();
			echo json_encode($JSONParams);
		}
	}

	public function getBlockMessage()
	{
		$JSONParams = array(
			"error" => 1,
			"message" => $this->lang->getText('NRS_ERROR_EXCEEDED_CUSTOMER_LOOKUP_ATTEMPTS_TEXT'),
		);

		return $JSONParams;
	}

	public function getErrorMessage()
	{
		$JSONParams = array(
			"error" => 99,
			"message" => $this->lang->getText('NRS_ERROR_CUSTOMER_DETAILS_UNKNOWN_ERROR_TEXT'),
		);

		return $JSONParams;
	}	
	
	public function getAjaxCustomerDetails($paramEmail, $paramYearOfBirth = "0000", $paramRequireYearOfBirth = FALSE)
	{
		$validEmail = sanitize_email($paramEmail);
		$validYearOfBirth = NRSValidator::getValidInteger($paramYearOfBirth, "0000");
		$customerData = $this->internalWPDB->get_row("
			SELECT * FROM {$this->nrsPrefix}customers
			WHERE email='{$validEmail}' LIMIT 1
			", ARRAY_A);
		if (!is_null($customerData))
		{
			$dobParts = explode("-", $customerData['birthdate']);
			$customerYearOfBirth = isset($dobParts[0]) ? $dobParts[0] : "0000";
			if($paramRequireYearOfBirth && $customerYearOfBirth != $validYearOfBirth)
			{
				// NOTE: For better security to protect from email database attacks, we don't want to disclose that the year is not valid.
				// That's why we just give default message
				$JSONParams = array(
					"error" => 1,
					"message" => $this->lang->getText('NRS_ERROR_CUSTOMER_DETAILS_NOT_FOUND_TEXT'),
				);
			} else
			{
				$arrValues = array(
					"Mr.",
					"Ms.",
					"Mrs.",
					"Miss.",
					"Dr.",
					"Prof."
				);
				$arrTitles = array(
					$this->lang->getText('NRS_MR_TEXT'),
					$this->lang->getText('NRS_MS_TEXT'),
					$this->lang->getText('NRS_MRS_TEXT'),
					$this->lang->getText('NRS_MISS_TEXT'),
					$this->lang->getText('NRS_DR_TEXT'),
					$this->lang->getText('NRS_PROF_TEXT'),
				);
				$titleOptionsHTML = '';
				$selected = $customerData['title'] == "" ? ' selected="selected"' : '';
				$titleOptionsHTML .= '<option value=""'.$selected.'>'.$this->lang->getText('NRS_SELECT_DROPDOWN_TEXT').'</option>';
				for($p = 0; $p < 6; $p++)
				{
					if($arrValues[$p] == $customerData['title'])
					{
						$titleOptionsHTML .= '<option value="'.$arrValues[$p].'" selected="selected">'.$arrTitles[$p].'</option>';
					} else
					{
						$titleOptionsHTML .= '<option value="'.$arrValues[$p].'" >'.$arrTitles[$p].'</option>';
					}
				}
				$customerBirthDateParts = explode("-",$customerData['birthdate']);
				$customerBirthYear = $customerBirthDateParts[0];
				$customerBirthMonth = $customerBirthDateParts[1];
				$customerBirthDay = $customerBirthDateParts[2];

				$JSONParams = array(
					"error" => 0,
					"message" => $this->lang->getText('NRS_ERROR_CUSTOMER_DETAILS_NO_ERROR_TEXT'),
					"title" => $titleOptionsHTML,
					"first_name" => $customerData['first_name'],
					"last_name" => $customerData['last_name'],
					"birthdate" => $customerData['birthdate'],
					"birth_year" => $customerBirthYear,
					"birth_month" => $customerBirthMonth,
					"birth_day" => $customerBirthDay,
					"street_address" => $customerData['street_address'],
					"city" => $customerData['city'],
					"state" => $customerData['state'],
					"zipcode" => $customerData['zipcode'],
					"country" => $customerData['country'],
					"phone" => $customerData['phone'],
					"email" => $customerData['email'],
					"additional_comments" => $customerData['additional_comments'],
				);
			}
		} else
		{
			$JSONParams = array(
				"error" => 1,
				"message" => $this->lang->getText('NRS_ERROR_CUSTOMER_DETAILS_NOT_FOUND_TEXT'),
			);
		}

		return $JSONParams;
	}
}