<?php
/**
 * NRS Calendar
 * Abstract class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

abstract class NRSCalendar
{
    protected $internalWPDB 		    = NULL;
    protected $nrsPrefix 			    = "";
    protected $lang 			        = NULL;
    protected $debugMode 			    = 0;
    protected $savedConfig              = array();

    protected $currencySymbol		    = '$';
    protected $currencyCode			    = 'USD';
    protected $vatPercentage		    = 0.00;
    protected $showPricesWithVAT	    = 0;

    protected $noonTime	                = '12:00:00';

    /**
     * @param wpdb $paramWPDB
     * @param $paramNRSPrefix
     * @param NRSLanguage $paramNRSLang
     * @param array $paramConfig
     */
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig = array())
    {
        // Set class settings
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;
        $this->savedConfig = $paramConfig;

        $this->currencySymbol = NRSValidator::getValidSetting($paramConfig['conf_currency_symbol'], "textval", "$");
        $this->currencyCode = NRSValidator::getValidSetting($paramConfig['conf_currency_code'], "textval", "USD");
        $this->vatPercentage = NRSValidator::getValidSetting($paramConfig['conf_vat_percentage'], "floatval", 21.00);
        $this->showPricesWithVAT = NRSValidator::getValidSetting($paramConfig['conf_show_prices_with_vat'], "intval", 1, array(0, 1));
        $this->noonTime = NRSValidator::getValidSetting($paramConfig['conf_show_prices_with_vat'], "time_format", "12:00:00");
    }

    public function inDebug()
    {
        return ($this->debugMode >= 1 ? TRUE : FALSE);
    }

    public function getAllDaysOfCurrentMonth()
    {
        return $this->getAllDaysOfTheMonth(date("Y"), date("m"));
    }

    public function getAllDaysOfNextMonth()
    {
        return $this->getAllDaysOfTheMonth(date("Y"), date("m")+1);
    }

    public function getAllDaysOfTheMonth($year="current", $month="current")
    {
        $ret = array();
        if($year =="current" && $month == "current")
        {
            $start_date = date("Y-m-01");
        } else
        {
            $start_date = date("{$year}-{$month}-01"); // Give in your own start date
        }
        $end_date = date("Y-m-t", strtotime($start_date));

        $number_of_days = (strtotime($end_date) - strtotime($start_date))/86400+1 ; // Add the last day also

        /*DEBUG*/ //echo "START: $start_date, END: $end_date, DIFF: $number_of_days<br />";

        for ($i = 0; $i < $number_of_days; $i++) {
            $date = strtotime(date("Y-m-d", strtotime($start_date)) . " +$i day");
            $ret[] = date('d', $date);
        }

        return $ret;
    }
}