<?php
/**
 * Deposit Manager
 * Abstract classes can't be created with new instance. It is only possible if they are extended by childs
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

abstract class NRSDepositManager
{
	protected $internalWPDB 		= NULL;
	protected $nrsPrefix 			= "";
	protected $lang 				= NULL;
	protected $debugMode 			= 0;
    protected $savedConfig          = array();
	/**
	 * @var int - either itemId or either extraId;
	 */
	protected $elementId			= 0;
	protected $depositEnabled 		= 1;
    protected $currencySymbol		= '$';
    protected $currencyCode			= 'USD';

	/**
	 * @param $paramWPDB
	 * @param $paramNRSPrefix
	 * @param NRSLanguage &$paramNRSLang - Language
	 * @param array $paramConfig
	 * @param $paramElementId
	 */
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig, $paramElementId)
	{
		// Set class settings
		$this->internalWPDB = $paramWPDB;
		$this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
		// Already sanitized before in it's constructor. Too much sanitation will kill the system speed
		$this->lang = $paramNRSLang;
		$this->savedConfig = $paramConfig;

		$this->elementId = NRSValidator::getValidValue($paramElementId, "intval", 0);
        $this->currencySymbol = NRSValidator::getValidSetting($paramConfig['conf_currency_symbol'], "textval", "$");
        $this->currencyCode = NRSValidator::getValidSetting($paramConfig['conf_currency_code'], "textval", "USD");
		// Set deposit status
		$this->setDepositStatus($paramConfig);
	}

	public function inDebug()
	{
		return ($this->debugMode >= 1 ? TRUE : FALSE);
	}

	/**
	 * Set deposit status - called in class constructor
	 * @param array $paramOptionalConfig
	 */
	private function setDepositStatus($paramOptionalConfig)
	{
		if(isset($paramOptionalConfig['conf_deposit_enabled']))
		{
            // Fast processing mode (for availability and price table), to reduce sql query amount
            if($this->debugMode >= 1)
			{
				echo "<br />Constructor: Deposit settings loaded from cache";
			}
			$this->depositEnabled = NRSValidator::getValidInteger($paramOptionalConfig['conf_deposit_enabled'], 1) == 1 ? TRUE : FALSE;
		} else
		{
            if($this->debugMode >= 1)
            {
                echo "<br />Constructor: Deposit settings loaded via database call";
            }
            $sql = "
                    SELECT conf_value AS deposit_enabled
                    FROM {$this->nrsPrefix}settings
                    WHERE conf_key='conf_deposit_enabled'
                ";
            $depositEnabled = $this->internalWPDB->get_var($sql);

            if(!is_null($depositEnabled) && intval($depositEnabled) == 1)
            {
                $this->depositEnabled = TRUE;
            } else
            {
                $this->depositEnabled = FALSE;
            }
        }
	}

	/**
	 * Are deposit differs for each item & extra
	 * @return bool
	 */
	public function isDepositEnabled()
	{
		return $this->depositEnabled;
	}
}
