<?php
/**
 * NRS Deposits Observer (no setup for single item)
 * Abstract class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

abstract class NRSDepositsObserver
{
	protected $internalWPDB 		    = NULL;
	protected $nrsPrefix 			    = "";
	protected $lang 			        = NULL;
	protected $debugMode 			    = 0;
	protected $depositsEnabled  		= TRUE;
	// Price calculation type: 1 - daily, 2 - hourly, 3 - mixed (daily+hourly)
	protected $priceCalculationType 	= 1;

	protected $currencySymbol		= '$';
	protected $currencyCode			= 'USD';
	protected $vatPercentage		= 0.00;
	protected $showPricesWithVAT	= 0;

	/**
	 * @param &$paramWPDB
	 * @param $paramNRSPrefix
	 * @param NRSLanguage $paramNRSLang
	 */
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
	{
		// Set class settings
		$this->internalWPDB = $paramWPDB;
		$this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
		// Already sanitized before in it's constructor. Too much sanitation will kill the system speed
		$this->lang = $paramNRSLang;
		// Set price calculation type
		$this->setPriceCalculationType();
		// Set discount status
		$this->setDepositsStatus();
		// Set currency symbol
		$this->setCurrencySymbol();
	}

	/**
	 * Set deposit status - called in class constructor
	 */
	private function setPriceCalculationType()
	{
		$sql = "
				SELECT conf_value AS price_calculation_type
				FROM {$this->nrsPrefix}settings
				WHERE conf_key='conf_price_calculation_type'
			";
		$priceCalculationType = $this->internalWPDB->get_var($sql);

		if(!is_null($priceCalculationType))
		{
			$this->priceCalculationType = NRSValidator::getValidInteger($priceCalculationType, 1);
		} else
		{
			$this->priceCalculationType = 1;
		}
	}

	/**
	 * Set currency symbol - called in class constructor
	 */
	private function setCurrencySymbol()
	{
		$sql = "
				SELECT conf_value AS currency_symbol
				FROM {$this->nrsPrefix}settings
				WHERE conf_key='conf_currency_symbol'
			";
		$currencySymbol = $this->internalWPDB->get_var($sql);

		if(!is_null($currencySymbol))
		{
			$this->currencySymbol = $currencySymbol;
		} else
		{
			$this->currencySymbol = "";
		}
	}

	/**
	 * Set discount status - called in class constructor
	 */
	private function setDepositsStatus()
	{
		$sql = "
				SELECT conf_value AS deposit_enabled
				FROM {$this->nrsPrefix}settings
				WHERE conf_key='conf_deposit_enabled'
			";
		$depositEnabled = $this->internalWPDB->get_var($sql);

		if(!is_null($depositEnabled) && intval($depositEnabled) == 1)
		{
			$this->depositsEnabled = TRUE;
		} else
		{
			$this->depositsEnabled = FALSE;
		}
	}

	public function areDepositsEnabled()
	{
		return $this->depositsEnabled;
	}
}