<?php
/**
 * Prepayment Manager
 * Abstract classes can't be created with new instance. It is only possible if they are extended by childs
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

abstract class NRSPrepaymentManager
{
	protected $internalWPDB 		= NULL;
	protected $nrsPrefix 			= "";
	protected $lang 				= NULL;
	protected $debugMode 			= 0;
	/**
	 * @var int - either itemId or either extraId;
	 */
	protected $elementId			= 0;
	protected $prepaymentEnabled 	= 1;

	/**
	 * @param $paramWPDB
	 * @param $paramNRSPrefix
	 * @param NRSLanguage &$paramNRSLang - Language
	 * @param $paramElementId
     * @param array $paramOptionalConfig
	 */
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId, $paramOptionalConfig = array())
	{
		// Set class settings
		$this->internalWPDB = $paramWPDB;
		$this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
		// Already sanitized before in it's constructor. Too much sanitation will kill the system speed
		$this->lang = $paramNRSLang;

		$this->elementId = NRSValidator::getValidValue($paramElementId, "intval", 0);
		// Set prepayment status
		$this->setPrepaymentStatus($paramOptionalConfig);
	}

	public function inDebug()
	{
		return ($this->debugMode >= 1 ? TRUE : FALSE);
	}

	/**
	 * Set prepayment status - called in class constructor
     * @param array $paramOptionalConfig
	 */
	private function setPrepaymentStatus($paramOptionalConfig)
	{
        if(isset($paramOptionalConfig['conf_prepayment_enabled']))
        {
            // Fast processing mode (for availability and price table), to reduce sql query amount
            if($this->debugMode >= 1)
            {
                echo "<br />Constructor: Prepayment settings loaded from cache";
            }
            $this->prepaymentEnabled = NRSValidator::getValidInteger($paramOptionalConfig['conf_prepayment_enabled'], 1) == 1 ? TRUE : FALSE;
        } else
        {
            if($this->debugMode >= 1)
            {
                echo "<br />Constructor: Prepayment settings loaded via database call";
            }
            $sql = "
				SELECT conf_value AS prepayment_enabled
				FROM {$this->nrsPrefix}settings
				WHERE conf_key='conf_prepayment_enabled'
			";
            $prepaymentEnabled = $this->internalWPDB->get_var($sql);

            if(!is_null($prepaymentEnabled) && intval($prepaymentEnabled) == 1)
            {
                $this->prepaymentEnabled = TRUE;
            } else
            {
                $this->prepaymentEnabled = FALSE;
            }
        }
	}

	/**
	 * Are prepayment differs for each item & extra
	 * @return bool
	 */
	public function isPrepaymentEnabled()
	{
		return $this->prepaymentEnabled;
	}
}
