<?php
/**
 * NRS Prepayments Observer (no setup for single item)
 * Abstract class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

abstract class NRSPrepaymentsObserver
{
	protected $internalWPDB 		    = NULL;
	protected $nrsPrefix 			    = "";
	protected $lang 			        = NULL;
	protected $debugMode 			    = 0;
	protected $prepaymentsEnabled  		= TRUE;
	// Price calculation type: 1 - daily, 2 - hourly, 3 - mixed (daily+hourly)
	protected $priceCalculationType 	= 1;

	/**
	 * @param &$paramWPDB
	 * @param $paramNRSPrefix
	 * @param NRSLanguage $paramNRSLang
	 * @param int $paramPriceCalculationType
	 */
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramPriceCalculationType = 1)
	{
		// Set class settings
		$this->internalWPDB = $paramWPDB;
		$this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
		// Already sanitized before in it's constructor. Too much sanitation will kill the system speed
		$this->lang = $paramNRSLang;
		// Set price calculation type
		$this->setPriceCalculationType();
		// Set discount status
		$this->setPrepaymentsStatus();
	}


	/**
	 * Set prepayment status - called in class constructor
	 */
	private function setPriceCalculationType()
	{
		$sql = "
				SELECT conf_value AS price_calculation_type
				FROM {$this->nrsPrefix}settings
				WHERE conf_key='conf_price_calculation_type'
			";
		$priceCalculationType = $this->internalWPDB->get_var($sql);

		if(!is_null($priceCalculationType))
		{
			$this->priceCalculationType = NRSValidator::getValidInteger($priceCalculationType, 1);
		} else
		{
			$this->priceCalculationType = 1;
		}
	}

	/**
	 * Set discount status - called in class constructor
	 */
	private function setPrepaymentsStatus()
	{
		$sql = "
				SELECT conf_value AS prepayment_enabled
				FROM {$this->nrsPrefix}settings
				WHERE conf_key='conf_prepayment_enabled'
			";
		$prepaymentEnabled = $this->internalWPDB->get_var($sql);

		if(!is_null($prepaymentEnabled) && intval($prepaymentEnabled) == 1)
		{
			$this->prepaymentsEnabled = TRUE;
		} else
		{
			$this->prepaymentsEnabled = FALSE;
		}
	}

	public function arePrepaymentsEnabled()
	{
		return $this->prepaymentsEnabled;
	}
}