<?php
/**
 * NRS Price Table
 * Abstract class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

abstract class NRSPriceTable
{
    protected $internalWPDB 		    = NULL;
    protected $nrsPrefix 			    = "";
    protected $lang 			        = NULL;
    protected $debugMode 			    = 0;
    protected $savedConfig              = array();

    // Price calculation type: 1 - daily, 2 - hourly, 3 - mixed (daily+hourly)
    protected $priceCalculationType 	= 1;
    protected $currencySymbol		    = '$';
    protected $currencyCode			    = 'USD';
    protected $vatPercentage		    = 0.00;
    protected $showPricesWithVAT	    = 0;

    /**
     * @param &$paramWPDB
     * @param $paramNRSPrefix
     * @param NRSLanguage $paramNRSLang
     * @param array $paramConfig
     */
    public function __construct(
        wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig = array())
    {
        // Set class settings
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;
        $this->savedConfig = $paramConfig;

        $this->priceCalculationType = NRSValidator::getValidSetting($paramConfig['conf_price_calculation_type'], "intval", 1, array(1, 2, 3));
        $this->currencySymbol = NRSValidator::getValidSetting($paramConfig['conf_currency_symbol'], "textval", "$");
        $this->currencyCode = NRSValidator::getValidSetting($paramConfig['conf_currency_code'], "textval", "USD");
        $this->vatPercentage = NRSValidator::getValidSetting($paramConfig['conf_vat_percentage'], "floatval", 21.00);
        $this->showPricesWithVAT = NRSValidator::getValidSetting($paramConfig['conf_show_prices_with_vat'], "intval", 1, array(0, 1));
    }

    public function inDebug()
    {
        return ($this->debugMode >= 1 ? TRUE : FALSE);
    }
}