<?php
/**
 * NRS Customers Observer (no setup for single customer)
 * Abstract class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

class NRSCustomersObserver
{
    protected $internalWPDB = NULL;
    protected $nrsPrefix = "";
    protected $lang = NULL;
    protected $debugMode = 0;

    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
    {
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;
    }

    public function inDebug()
    {
        return ($this->debugMode >= 1 ? TRUE : FALSE);
    }
    public function getAdminCustomerList($paramList = "ALL_CUSTOMERS", $timestampFrom = 0, $timestampTo = 0, $paramUrlPath = "")
    {
        $validTimestampFrom = NRSValidator::getValidInteger($timestampFrom, 0);
        $validTimestampTo = NRSValidator::getValidInteger($timestampTo, 0);
        $validUrlPath = sanitize_text_field($paramUrlPath);

        if ($paramList == "LAST_VISIT_BETWEEN")
        {
            $sqlCondition = "WHERE last_visit_timestamp BETWEEN $validTimestampFrom AND $validTimestampTo";
            $sqlOrderBy = "ORDER BY last_visit_timestamp ASC";
        } else if($paramList == "REGISTRATION_BETWEEN")
        {
            $sqlCondition = "WHERE registration_timestamp BETWEEN $validTimestampFrom AND $validTimestampTo";
            $sqlOrderBy = "ORDER BY registration_timestamp ASC";
        } else
        {
            // Do nothing, get all
            $sqlCondition = "";
            $sqlOrderBy = "ORDER BY first_name ASC, last_name ASC";
        }

        $html = '';
        $rows = $this->internalWPDB->get_results("
            SELECT *
            FROM {$this->nrsPrefix}customers
            {$sqlCondition}
            {$sqlOrderBy}
        ", ARRAY_A);

        foreach ($rows AS $row)
        {
            $titleValueLabel = array(
                "Mr." 	=> $this->lang->getText('NRS_MR_TEXT'),
                "Ms." 	=> $this->lang->getText('NRS_MS_TEXT'),
                "Mrs." 	=> $this->lang->getText('NRS_MRS_TEXT'),
                "Miss." => $this->lang->getText('NRS_MISS_TEXT'),
                "Dr." 	=> $this->lang->getText('NRS_DR_TEXT'),
                "Prof." => $this->lang->getText('NRS_PROF_TEXT'),
            );
            $languageSpecificTitle = "";
            if($row['title'] != "" && isset($titleValueLabel[$row['title']]))
            {
                $languageSpecificTitle = $titleValueLabel[$row['title']];
            }

            if($row['registration_timestamp'] > 0)
            {
                $registrationTMZStamp = $row['registration_timestamp'] + get_option( 'gmt_offset' ) * 3600;
                $registrationDate = date_i18n("Y-m-d", $registrationTMZStamp, TRUE);
            } else
            {
                $registrationDate = $this->lang->getText('NRS_ADMIN_NEVER_TEXT');
            }

            if($row['last_visit_timestamp'] > 0)
            {
                $lastVisitTMZStamp = $row['last_visit_timestamp'] + get_option( 'gmt_offset' ) * 3600;
                $lastVisitDate = date_i18n("Y-m-d", $lastVisitTMZStamp, TRUE);
            } else
            {
                $lastVisitDate = $this->lang->getText('NRS_ADMIN_NEVER_TEXT');
            }

            $html .= '<tr>';
            $html .= '<td>'.$row['customer_id'].'</td>';
            $html .= '<td>'.$languageSpecificTitle." ".$row['first_name']." ".$row['last_name'].'</td>';
            $html .= '<td style="white-space: nowrap">'.$row['birthdate'].'</td>';
            $html .= '<td>'.$row['street_address'].", ".$row['city'].", ".$row['country']." - ".$row['zipcode'].'</td>';
            $html .= '<td>'.$row['phone'].'</td>';
            $html .= '<td>'.$row['email'].'</td>';
            $html .= '<td style="white-space: nowrap">'.$registrationDate.'</td>';
            $html .= '<td style="white-space: nowrap">'.$lastVisitDate.'</td>';
            $html .= '<td align="right" nowrap="nowrap">';
            if($row['existing_customer'] == 1)
            {
                $html .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-booking-search-results&amp;customer_id='.$row['customer_id']).'">'.$this->lang->getText('NRS_ADMIN_VIEW_BOOKINGS_TEXT').'</a><br />';
            } else
            {
                $html .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-booking-search-results&amp;customer_id='.$row['customer_id']).'">'.$this->lang->getText('NRS_ADMIN_VIEW_UNPAID_BOOKINGS_TEXT').'</a><br />';
            }
            $html .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-customer&amp;customer_id='.$row['customer_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
            $html .= '<a href="javascript:;" onclick="javascript:deleteCustomer(\''.$row['customer_id'].'\',\''.$validUrlPath.'\')">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a>';
            $html .= '</td>';
            $html .= '</tr>';
        }
        return $html;
    }
}