<?php
/**
 * Deposit processor. Used in administration side only
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSDeposit
{
    protected $internalWPDB	 	= NULL;
    protected $nrsPrefix 		= "";
    protected $lang 			= NULL;
    protected $debugMode 	 	= 0;
    protected $depositId        = 0;

    /**
     * @param $paramWPDB
     * @param $paramNRSPrefix
     * @param NRSLanguage &$paramNRSLang - LANGUAGE
     * @param $paramDepositId
     */
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramDepositId)
    {
        // Set class settings
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);

        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;

        // Set deposit id
        $this->depositId = NRSValidator::getValidInteger($paramDepositId, 0);
    }

    public function inDebug()
    {
        return ($this->debugMode >= 1 ? TRUE : FALSE);
    }

    public function getDepositId()
    {
        return $this->depositId;
    }

    /**
     * For internal class use only
     * @param $paramDepositId
     * @return mixed
     */
    private function getDepositDataFromDatabaseById($paramDepositId)
    {
        $validDepositId = NRSValidator::getValidInteger($paramDepositId, 0);
        $depositData = $this->internalWPDB->get_row("
            SELECT *
            FROM {$this->nrsPrefix}deposits
            WHERE deposit_id='{$validDepositId}'
        ", ARRAY_A);

        return $depositData;
    }

    public function getDepositDetails()
    {
        $depositData = $this->getDepositDataFromDatabaseById($this->depositId);

        return $depositData;
    }

    public function saveDeposit($paramItemId, $paramPeriodFrom, $paramPeriodTill, $paramFixedRentalDeposit)
    {
        $validDepositId = NRSValidator::getValidInteger($this->depositId, 0);
        $validItemId = NRSValidator::getValidInteger($paramItemId, 0);
        $validPeriodFrom = NRSValidator::getValidInteger($paramPeriodFrom, 0);
        $validPeriodTill = NRSValidator::getValidInteger($paramPeriodTill, 0);
        $validFixedRentalDeposit = floatval($paramFixedRentalDeposit);

        if($validDepositId > 0)
        {
            $itemExists = $this->internalWPDB->get_row("
                SELECT deposit_id
                FROM {$this->nrsPrefix}deposits
                WHERE deposit_id='{$validDepositId}'
            ", ARRAY_A);

            // If expr is greater than or equal to min and expr is less than or equal to max, BETWEEN returns 1, otherwise it returns 0
            $minDaysValueCheck = $this->internalWPDB->get_results("
                SELECT deposit_id
                FROM {$this->nrsPrefix}deposits
                WHERE deposit_id!='{$validDepositId}' AND item_id='{$validItemId}' AND (
                  '{$validPeriodFrom}' BETWEEN period_from AND period_till
                  OR '{$validPeriodTill}' BETWEEN period_from AND period_till
                )
            ", ARRAY_A);

            if(sizeof($minDaysValueCheck) > 0)
            {
                $_SESSION['msg'] = 'Error: Current deposit plan duration range intersects with other deposit plan!';
            } else if(is_null($itemExists))
            {
                $_SESSION['msg'] = 'Error: Deposit plan do not exist!';
            } else
            {
                $updated = $this->internalWPDB->query("
                    UPDATE {$this->nrsPrefix}deposits SET
                    item_id='{$validItemId}', period_from='{$validPeriodFrom}', period_till='{$validPeriodTill}',
                    fixed_rental_deposit='{$validFixedRentalDeposit}'
                    WHERE deposit_id='{$validDepositId}'
                ");
                if($updated === FALSE)
                {
                    $_SESSION['msg'] = 'Error: MySQL update error for existing deposit!';
                } else
                {
                    $_SESSION['ok_msg'] = 'Completed: Deposit plan was updated successfully!';
                }
            }
        } else
        {
            //If expr is greater than or equal to min and expr is less than or equal to max, BETWEEN returns 1, otherwise it returns 0
            $dayFromValueCheck = $this->internalWPDB->get_results("
                SELECT deposit_id
                FROM {$this->nrsPrefix}deposits
                WHERE item_id='{$validItemId}' AND (
                  '{$validPeriodFrom}' BETWEEN period_from AND period_till
                  OR '{$validPeriodTill}' BETWEEN period_from AND period_till
                )
            ", ARRAY_A);

            if(sizeof($dayFromValueCheck) > 0)
            {
                $_SESSION['msg'] = 'Error: Day from or day to value already exist, you can only perform edit operation!';
            } else
            {
                $inserted = $this->internalWPDB->query("
                    INSERT INTO {$this->nrsPrefix}deposits
                    (
                      item_id, period_from, period_till, fixed_rental_deposit
                    ) VALUES
                    (
                      '{$validItemId}', '{$validPeriodFrom}', '{$validPeriodTill}', '{$validFixedRentalDeposit}'
                    )
                 ");
                if($inserted === FALSE || $inserted === 0)
                {
                    $_SESSION['msg'] = 'Error: MySQL insert error for new deposit!';
                } else
                {
                    $_SESSION['ok_msg'] = 'Completed: New deposit plan was added successfully!';
                    // Update class deposit id with newly inserted deposit it for future work
                    $this->depositId = $this->internalWPDB->insert_id;
                }
            }
        }
    }

    public function deleteDeposit()
    {
        $validDepositId = NRSValidator::getValidInteger($this->depositId);
        $deleted = $this->internalWPDB->query("
            DELETE FROM {$this->nrsPrefix}deposits
            WHERE deposit_id='{$validDepositId}'
        ");
        if($deleted === FALSE || $deleted === 0)
        {
            $_SESSION['msg'] = 'Error: MySQL delete error for existing deposit. No deposit row were deleted from database!';
        } else
        {
            $_SESSION['ok_msg'] = "Completed: Deposit plan deleted successfully!";
        }
    }
}