<?php
/**
 * Discount processor. Used in administration side only
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSDiscount
{
    protected $internalWPDB	 	= NULL;
    protected $nrsPrefix 		= "";
    protected $lang 			= NULL;
    protected $debugMode 	 	= 0;
    protected $discountId        = 0;

    /**
     * @param $paramWPDB
     * @param $paramNRSPrefix
     * @param NRSLanguage &$paramNRSLang - LANGUAGE
     * @param $paramDiscountId
     */
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramDiscountId)
    {
        // Set class settings
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);

        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;

        // Set discount id
        $this->discountId = NRSValidator::getValidInteger($paramDiscountId, 0);
    }

    public function inDebug()
    {
        return ($this->debugMode >= 1 ? TRUE : FALSE);
    }

    public function getDiscountId()
    {
        return $this->discountId;
    }

    /**
     * For internal class use only
     * @param $paramDiscountId
     * @return mixed
     */
    private function getDiscountDataFromDatabaseById($paramDiscountId)
    {
        $validDiscountId = NRSValidator::getValidInteger($paramDiscountId, 0);
        $discountData = $this->internalWPDB->get_row("
            SELECT *
            FROM {$this->nrsPrefix}discounts
            WHERE discount_id='{$validDiscountId}'
        ", ARRAY_A);

        return $discountData;
    }

    public function getDiscountDetails()
    {
        $discountData = $this->getDiscountDataFromDatabaseById($this->discountId);

        return $discountData;
    }

    public function saveDiscount($validItemId, $validExtraId, $paramPeriodFrom, $paramPeriodTill, $paramDiscountType, $paramDiscountPercentage)
    {
        $validDiscountId = NRSValidator::getValidInteger($this->discountId, 0);
        $validItemId = NRSValidator::getValidInteger($validItemId, 0);
        $validExtraId = NRSValidator::getValidInteger($validExtraId, 0);
        $validPeriodFrom = NRSValidator::getValidInteger($paramPeriodFrom, 0);
        $validPeriodTill = NRSValidator::getValidInteger($paramPeriodTill, 0);
        $validDiscountType = in_array($paramDiscountType, array(1,2,3,4)) ? $paramDiscountType : 1;
        $validDiscountPercentage = floatval($paramDiscountPercentage);
        // Do not allow to have discounts more than 100%
        if($validDiscountPercentage > 100)
        {
            $validDiscountPercentage = 100;
        }

        if($validDiscountId > 0)
        {
            $itemExists = $this->internalWPDB->get_row("
                SELECT discount_id
                FROM {$this->nrsPrefix}discounts
                WHERE discount_id='{$validDiscountId}'
            ", ARRAY_A);

            //If expr is greater than or equal to min and expr is less than or equal to max, BETWEEN returns 1, otherwise it returns 0
            $dayFromValueCheck = $this->internalWPDB->get_results("
                SELECT discount_id
                FROM {$this->nrsPrefix}discounts
                WHERE discount_id!='{$validDiscountId}' AND discount_type='{$validDiscountType}' AND item_id='{$validItemId}' AND extra_id='{$validExtraId}' AND (
                    '{$validPeriodFrom}' BETWEEN period_from AND period_till
                    OR '{$validPeriodTill}' BETWEEN period_from AND period_till
                )
            ", ARRAY_A);

            if(sizeof($dayFromValueCheck) > 0)
            {
                $_SESSION['msg'] = 'Error: Day from or day to value already exist, you can only perform edit operation!';
            } else if(is_null($itemExists))
            {
                $_SESSION['msg'] = 'Error: Item do not exist!';
            } else
            {
                $updateSQL = "
                    UPDATE {$this->nrsPrefix}discounts SET
                    item_id='{$validItemId}', extra_id='{$validExtraId}', period_from='{$validPeriodFrom}', period_till='{$validPeriodTill}',
                    discount_percentage='{$validDiscountPercentage}'
                    WHERE discount_id='{$validDiscountId}'
                ";
                $updated = $this->internalWPDB->query($updateSQL);

                if($updated === FALSE)
                {
                    $_SESSION['msg'] = 'Error: MySQL update error for existing discount!';
                } else
                {
                    $_SESSION['ok_msg'] = 'Completed: Discount plan was updated successfully!';
                }
            }
        } else
        {
            //If expr is greater than or equal to min and expr is less than or equal to max, BETWEEN returns 1, otherwise it returns 0
            $dayFromValueCheck = $this->internalWPDB->get_results("
                SELECT discount_id
                FROM {$this->nrsPrefix}discounts
                WHERE discount_type='{$validDiscountType}' AND item_id='{$validItemId}' AND extra_id='{$validExtraId}' AND (
                  '{$validPeriodFrom}' BETWEEN period_from AND period_till
                  OR '{$validPeriodTill}' BETWEEN period_from AND period_till
                )
            ", ARRAY_A);

            if(sizeof($dayFromValueCheck) > 0)
            {
                $_SESSION['msg'] = 'Error: Day from or day to value already exist, you can only perform edit operation!';
            } else
            {
                $inserted = $this->internalWPDB->query("
                    INSERT INTO {$this->nrsPrefix}discounts
                    (
                        discount_type, item_id, extra_id,
                        period_from, period_till, discount_percentage
                    )
                    VALUES
                    (
                        '{$validDiscountType}', '{$validItemId}', '{$validExtraId}',
                        '{$validPeriodFrom}', '{$validPeriodTill}', '{$validDiscountPercentage}'
                    )
                 ");
                if($inserted === FALSE || $inserted === 0)
                {
                    $_SESSION['msg'] = 'Error: MySQL insert error for new discount!';
                } else
                {
                    $_SESSION['ok_msg'] = 'Completed: New discount plan was added successfully!';
                    // Update class discount id with newly inserted discount it for future work
                    $this->discountId = $this->internalWPDB->insert_id;
                }
            }
        }
    }

    public function deleteDiscount()
    {
        $validDiscountId = NRSValidator::getValidInteger($this->discountId);
        $deleted = $this->internalWPDB->query("
          DELETE FROM {$this->nrsPrefix}discounts
          WHERE discount_id='{$validDiscountId}'
        ");
        if($deleted === FALSE || $deleted === 0)
        {
            $_SESSION['msg'] = 'Error: MySQL delete error for existing discount. No discount row were deleted from database!';
        } else
        {
            $_SESSION['ok_msg'] = "Completed: Discount plan deleted successfully!";
        }
    }
}