<?php
/**
 * Extra Processor
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @uses NRSDepositManager, NRSDiscountManager, NRSPrepaymentManager
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSExtra extends NRSElement implements iNRSElement
{
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId, $paramOptionalConfig = array())
    {
        parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId, $paramOptionalConfig);
    }

    /**
     * @param $paramExtraId
     * @return mixed
     */
    private function getDataFromDatabaseById($paramExtraId)
    {
        $row = $this->internalWPDB->get_row("
            SELECT *
            FROM {$this->nrsPrefix}extras
            WHERE extra_id='".intval($paramExtraId)."'
        ", ARRAY_A);

        return $row;
    }

    public function getBasicDetails()
    {
        return $this->getDetails(TRUE);
    }

    public function getFullDetails()
    {
        return $this->getDetails(FALSE);
    }

    /**
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return array
     */
    public function getDetails($paramBasicDetails = FALSE)
    {
        // For extras basic and full details are the same
        $extraData = $this->getDataFromDatabaseById($this->elementId);

        return $extraData;
    }

    public function getFeaturesList()
    {
        // Extras do not have features
        return "";
    }

    public function getPickupLocationsList()
    {
        // Extras do not depend on locations
        return "";
    }
    public function getDropoffLocationsList()
    {
        // Extras do not depend on locations
        return "";
    }

    public function save()
    {
        $validExtraId = NRSValidator::getValidInteger($this->elementId, 0);
        $sanitizedExtraName = sanitize_text_field($_POST['extra_name']);
        $sanitizedMeasurementUnit = sanitize_text_field(esc_html($_POST['measurement_unit']));
        $validExtraUnitsInStock = NRSValidator::getValidInteger($_POST['units_in_stock'], 50);
        $validMinimumExtraUnitsPerBooking = NRSValidator::getValidInteger($_POST['min_units_per_booking'], 0);
        $validMaximumExtraUnitsPerBooking = NRSValidator::getValidInteger($_POST['max_units_per_booking'], 2);
        $validExtraPrice = floatval($_POST['price']);
        $validExtraPriceType = intval($_POST['price_type']);
        $validExtraPrepaymentPercentage = floatval($_POST['prepayment_percentage']);
        $validFixedExtraRentalDeposit = floatval($_POST['fixed_rental_deposit']);
        $validOptionsDisplayMode = intval($_POST['options_display_mode']);

        // Do not allow to have extra prepayment more than 100%
        if($validExtraPrepaymentPercentage > 100)
        {
            $validExtraPrepaymentPercentage = 100;
        }

        if($validMinimumExtraUnitsPerBooking > $validMaximumExtraUnitsPerBooking)
        {
            $_SESSION['msg'] = "Error: You can&#39;t set more minimum units per booking than maximum units per booking!";
        }

        if($validMaximumExtraUnitsPerBooking > $validExtraUnitsInStock)
        {
            $_SESSION['msg'] = "Error: You can&#39;t set more maximum units per booking than you have in stock!";
        }

        if(!isset($_SESSION['msg']))
        {
            if ($validExtraId > 0)
            {
                $this->internalWPDB->query("
                    UPDATE {$this->nrsPrefix}extras SET
                    extra_name='{$sanitizedExtraName}',
                    price='{$validExtraPrice}', price_type='{$validExtraPriceType}',
                    prepayment_percentage='{$validExtraPrepaymentPercentage}', fixed_rental_deposit='{$validFixedExtraRentalDeposit}',
                    units_in_stock='{$validExtraUnitsInStock}',
                    min_units_per_booking='{$validMinimumExtraUnitsPerBooking}', max_units_per_booking='{$validMaximumExtraUnitsPerBooking}',
                    options_display_mode='{$validOptionsDisplayMode}', measurement_unit='{$sanitizedMeasurementUnit}'
                    WHERE extra_id='{$validExtraId}'
                ");
                $_SESSION['ok_msg'] = "Completed: Extra item updated successfully!";
            } else
            {
                $this->internalWPDB->query("
                    INSERT INTO {$this->nrsPrefix}extras
                    (
                        extra_name, price, price_type,
                        prepayment_percentage, fixed_rental_deposit,
                        units_in_stock, min_units_per_booking, max_units_per_booking,
                        options_display_mode, measurement_unit
                    ) VALUES
                    (
                        '{$sanitizedExtraName}', '{$validExtraPrice}', '{$validExtraPriceType}',
                        '{$validExtraPrepaymentPercentage}', '{$validFixedExtraRentalDeposit}',
                        '{$validExtraUnitsInStock}', '{$validMinimumExtraUnitsPerBooking}', '{$validMaximumExtraUnitsPerBooking}',
                        '{$validOptionsDisplayMode}', '{$sanitizedMeasurementUnit}'
                    )
                ");
                $_SESSION['ok_msg'] = "Completed: New extra item added successfully!";
            }
        }
    }

    public function delete()
    {
        $this->internalWPDB->query("
            DELETE FROM {$this->nrsPrefix}extras
            WHERE extra_id='".intval($this->elementId)."'
        ");
    }


    /*******************************************************************************/
    /************************* ELEMENT SPECIFIC FUNCTIONS **************************/
    /*******************************************************************************/

    /**
     * @param string $paramName
     * @param string $selected
     * @param bool $paramRequired
     * @return string
     */
    public function getPriceTypesDropDown($paramName="price_type", $selected = "0", $paramRequired = TRUE)
    {
        $required = $paramRequired == FALSE ? "" : "required";

        $extraPriceTypeHTML = '<select name="'.$paramName.'" id="'.$paramName.'" class="'.$required.'">';
        $extraPriceTypeHTML .= '<option value="0"'.($selected == 0 ? ' selected="selected"' : '').'>'.$this->lang->getText('NRS_ADMIN_PER_BOOKING_TEXT').'</option>';
        $extraPriceTypeHTML .= '<option value="1"'.($selected == 1 ? ' selected="selected"' : '').'>'.$this->lang->getText('NRS_ADMIN_DAILY_TEXT').'</option>';
        $extraPriceTypeHTML .= '<option value="2"'.(in_array($selected, array(2,3)) ? ' selected="selected"' : '').'>'.$this->lang->getText('NRS_ADMIN_HOURLY_TEXT').'</option>';
        $extraPriceTypeHTML .= '</select>';

        return $extraPriceTypeHTML;
    }
}