<?php
/**
 * Extra's Deposit Manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSExtraDepositManager extends NRSDepositManager implements iNRSDepositManager
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig, $paramElementId)
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramConfig, $paramElementId);
	}

	/**
	 * For extras it's always the same
	 * @param $paramPeriodInSeconds
	 * @return float
	 */
	public function getFixedDepositAmountByPeriod($paramPeriodInSeconds)
	{
		return $this->getFixedDepositAmount();
	}

	/**
	 * @return int
	 */
	public function getMinimalFixedDepositAmount()
	{
		// For extras there are no min or max deposits - only one, which can be 0.00 or not
		return $this->getFixedDepositAmount();
	}

	/**
	 * Only for extras we can have a method without a period
	 * @return int
	 */
	private function getFixedDepositAmount()
	{
		$fixedRentalDeposit = 0;

		if($this->depositEnabled)
		{
			$validExtraId = NRSValidator::getValidInteger($this->elementId, 0);

			$query = "
			  SELECT fixed_rental_deposit
			  FROM {$this->nrsPrefix}extras
			  WHERE extra_id='{$validExtraId}'
			";
			$row = $this->internalWPDB->get_row($query, ARRAY_A);

			// DEBUG
			//echo nl2br($query);

			if(!is_null($row))
			{
				$fixedRentalDeposit = $row['fixed_rental_deposit'];
			}
		}

		return $fixedRentalDeposit;
	}

	public function getMinimalFixedDepositDetails()
	{
        $retDeposit = array();
        // For extras there are no min or max deposits - only one, which can be 0.00 or not
        $unitFixedDepositAmount = $this->getFixedDepositAmount();
        $roundedDeposit = round($unitFixedDepositAmount, 2);

        $retDeposit['unit']['fixed_deposit_amount'] = $unitFixedDepositAmount;
        // Unit prints
        $retDeposit['unit_tiny_print']['fixed_deposit_amount'] = NRSFormatter::getFormattedPrice($roundedDeposit, "tiny", $this->currencySymbol, $this->currencyCode);
        $retDeposit['unit_tiny_without_fraction_print']['fixed_deposit_amount'] = NRSFormatter::getFormattedPrice($roundedDeposit, "tiny_without_fraction", $this->currencySymbol, $this->currencyCode);
        $retDeposit['unit_print']['fixed_deposit_amount'] = NRSFormatter::getFormattedPrice($roundedDeposit, "regular", $this->currencySymbol, $this->currencyCode);
        $retDeposit['unit_without_fraction_print']['fixed_deposit_amount'] = NRSFormatter::getFormattedPrice($roundedDeposit, "regular_without_fraction", $this->currencySymbol, $this->currencyCode);
        $retDeposit['unit_long_print']['fixed_deposit_amount'] = NRSFormatter::getFormattedPrice($roundedDeposit, "long", $this->currencySymbol, $this->currencyCode);
        $retDeposit['unit_long_without_fraction_print']['fixed_deposit_amount'] = NRSFormatter::getFormattedPrice($roundedDeposit, "long_without_fraction", $this->currencySymbol, $this->currencyCode);
        // Word prints
        $retDeposit['word_print']['fixed_deposit_amount'] = $roundedDeposit == 0.00 ? $this->lang->getText('NRS_NOT_REQUIRED_TEXT') : $this->lang->getText('NRS_REQUIRED_TEXT');

        return $retDeposit;
	}
}
