<?php
/**
 * NRS Extra Option Manager (with setup for single extra)
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSExtraOptionManager extends NRSOptionManager implements iNRSOptionManager
{
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId)
    {
        parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId);
    }

    /**
     * @return array
     */
    public function getOptions()
    {
        $validExtraId = NRSValidator::getValidInteger($this->elementId, 0);
        $rows = $this->internalWPDB->get_results("
			SELECT option_id, option_name
			FROM {$this->nrsPrefix}options
			WHERE extra_id='{$validExtraId}'
			ORDER BY option_name ASC
		", ARRAY_A);

        return $rows;
    }


    /**
     * @return int
     */
    public function getTotalOptions()
    {
        $validExtraId = NRSValidator::getValidInteger($this->elementId, 0);

        $totalOptions = $this->internalWPDB->get_var("
			SELECT COUNT(option_id) AS total_options
			FROM {$this->nrsPrefix}options
			WHERE extra_id='{$validExtraId}'
		");

        return !is_null($totalOptions) ? intval($totalOptions) : 0;
    }

    public function getDropDown($paramSelectedOptionId = 0, $measurementUnit = "")
    {
        $options = $this->getOptions($this->elementId);
        $measurementUnit = $measurementUnit != '' ? ' '.$measurementUnit : '';

        $ret = '';
        $ret .= '<select name="extra_options['.$this->elementId.']">';
        foreach($options AS $option)
        {
            $selected = $option['option_id'] == $paramSelectedOptionId ? ' selected="selected"': '';
            $ret .= '<option value="'.$option['option_id'].'"'.$selected.'>'.$option['option_name'].$measurementUnit.'</option>';
        }
        $ret .= '</select>';

        return $ret;
    }

    /**
     * @param int $paramSelectedOptionId
     * @param string $measurementUnit
     * @return string
     */
    public function getSlider($paramSelectedOptionId = 0, $measurementUnit = "")
    {
        $options = $this->getOptions($this->elementId);
        $measurementUnit = $measurementUnit != '' ? ' '.$measurementUnit : '';
        $newOptions = array();
        foreach($options AS $option)
        {
            $newOptions[$option['option_id']] = $option['option_name'];
        }
        // asort - sort array and maintain index association
        asort($newOptions, SORT_NUMERIC);

        reset($newOptions);
        $firstArrayKey = !is_null(key($newOptions)) ? key($newOptions) : 0;

        $allValuesAreAllowedNumbers = TRUE;
        $selectedValue = "";
        $rangeStep = 1;
        $i = 1;
        $prev = 0;
        $step = 1;
        foreach($newOptions AS $id=>$value)
        {
            if(is_numeric($value))
            {
                // find the step
                if($i == 2)
                {
                    $step = abs($value - $prev);
                } else if($i > 2)
                {
                    //i == 2+
                    if(abs($value - $prev) != $step)
                    {
                        // Range are not balanced
                        $allValuesAreAllowedNumbers = FALSE;
                    }
                }
                $prev = $value;
                $i++;
                if($paramSelectedOptionId == $id)
                {
                    $selectedValue = $value;
                }
            } else
            {
                $allValuesAreAllowedNumbers = FALSE;
            }
        }
        if($step == 0)
        {
            $allValuesAreAllowedNumbers = FALSE;
        }

        if($allValuesAreAllowedNumbers == FALSE)
        {
            // If not every element is a number, then call a drop-down instead
            return $this->getDropDown($paramSelectedOptionId, $measurementUnit);
        } else
        {
            $minArrayNumber = min($newOptions);
            $maxArrayNumber = max($newOptions);
            $selectedValue = $selectedValue == "" ? $minArrayNumber : $selectedValue;
            $ret = '';
            $ret .= '<label for="extra_fader_'.$this->elementId.'"></label>';
            $ret .= '<input id="extra_fader_'.$this->elementId.'" type="range" min="'.$minArrayNumber.'" max="'.$maxArrayNumber.'" step="'.$step.'" value="'.$selectedValue.'" list="extra_volsettings_'.$this->elementId.'"
        oninput="outputUpdate('.$firstArrayKey.', value, \'extra_volume_'.$this->elementId.'\', \'extra_option_'.$this->elementId.'\', \'extra_volsettings'.$this->elementId.'\')">';
            $ret .= '<datalist id="extra_volsettings'.$this->elementId.'">';
            foreach($newOptions AS $id=>$value)
            {
                $ret .= '<option value="'.$id.'">'.$value.'</option>';
            }
            $ret .= '</datalist>';
            $ret .= '<output for="extra_fader_'.$this->elementId.'" id="extra_volume_'.$this->elementId.'">'.$selectedValue.'</output>'.$measurementUnit;
            $ret .= '<input type="hidden" id="extra_option_'.$this->elementId.'" name="extra_options['.$this->elementId.']" value="'.$paramSelectedOptionId.'" />';

            return $ret;
        }
    }

    /**
     * @param bool $showRowNumbers
     * @param string $rowNumbersPrefix
     * @return string
     */
    public function getAdminList($showRowNumbers=FALSE, $rowNumbersPrefix="0.")
    {
        $optionList = '';
        $validExtraId = NRSValidator::getValidInteger($this->elementId, 0);

        $sqlQuery = "
            SELECT o.option_id, o.option_name, ext.measurement_unit
            FROM {$this->nrsPrefix}options o
            LEFT JOIN {$this->nrsPrefix}extras ext ON o.extra_id=ext.extra_id
            WHERE o.extra_id='{$validExtraId}'
            ORDER BY option_name ASC
        ";
        $rows = $this->internalWPDB->get_results($sqlQuery, ARRAY_A);

        // Debug
        //echo nl2br($sqlQuery);

        $i = 0;
        foreach($rows AS $row)
        {
            $i++;

            // HTML OUTPUT
            $optionList .= '<tr>';
            if($showRowNumbers)
            {
                $optionList .= '<td>'.$rowNumbersPrefix.sprintf('%02d', $i).'</td>';
            }
            $optionList .= '<td><strong>'.$row['option_name'].'</strong></td>';
            $optionList .= '<td><strong>'.$row['measurement_unit'].'</strong></td>';
            $optionList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-extra-option&amp;option_id='.$row['option_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
            $optionList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-extras-manager&amp;delete_option='.$row['option_id'].'&amp;noheader=true').'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a></td>';
            $optionList .= '</tr>';
        }

        return  $optionList;
    }
}