<?php
/**
 * Extra's Prepayment Manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSExtraPrepaymentManager extends NRSPrepaymentManager implements iNRSPrepaymentManager
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId, $paramOptionalConfig = array())
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId, $paramOptionalConfig);
	}

	/**
	 * Extras do not use prepayment period - it's always the same
	 * @param int $paramPeriodInSeconds
	 * @return mixed
	 */
	public function getPrepaymentPercentageByPeriod($paramPeriodInSeconds)
	{
		return $this->getPrepaymentPercentage();
	}

	/**
	 * @return int
	 */
	public function getMinimalPrepaymentPercentage()
	{
		// For extras there are no min or max prepayment percentages - only one, which can be 0.00 or not
		return $this->getPrepaymentPercentage();
	}

	/**
	 * Get deposit percent
	 * @return int
	 */
	private function getPrepaymentPercentage()
	{
		// 0 is OK to return. System has a great logic. There is no 'hacks' needed for that if we do it in the right way.
		$prepaymentPercentage = 0;
		if($this->prepaymentEnabled)
		{
			$validExtraId = NRSValidator::getValidInteger($this->elementId, 0);

			$row = $this->internalWPDB->get_row("
			  	SELECT prepayment_percentage
			  	FROM {$this->nrsPrefix}extras
			  	WHERE extra_id='{$validExtraId}'
			", ARRAY_A);

			if(!is_null($row))
			{
				$prepaymentPercentage = $row['prepayment_percentage'];
			}
		}

		return $prepaymentPercentage;
	}
}
