<?php
/**
 * Extra's Price Manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @uses NRSDepositManager, NRSDiscountManager, NRSPrepaymentManager
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSExtraPriceManager extends NRSPriceManager implements iNRSPriceManager
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig, $paramElementId)
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramConfig, $paramElementId);
	}

	/**
	 * @param int $paramPickupTimestamp
	 * @param int $paramDropoffTimestamp
	 * @return float
	 */
	public function getUnitPriceByInterval($paramPickupTimestamp, $paramDropoffTimestamp)
	{
		$subTotalExtraPrice 	= 0;
		$validExtraId 			= NRSValidator::getValidInteger($this->elementId, 0);
		$validPickupTimestamp	= NRSValidator::getValidInteger($paramPickupTimestamp, 0);
		$validDropoffTimestamp	= NRSValidator::getValidInteger($paramDropoffTimestamp, 0);
		$validPeriod			= NRSValidator::getPeriod($validPickupTimestamp, $validDropoffTimestamp, FALSE);
		$secondsOnLastDay 		= $validPeriod - floor($validPeriod / 86400) * 86400;

		$extraData = $this->internalWPDB->get_row("
			SELECT price, price_type
			FROM {$this->nrsPrefix}extras
			WHERE extra_id='{$validExtraId}'
		", ARRAY_A);
		if(!is_null($extraData))
		{
			$extraPrice = $extraData['price'];
			$extraPriceType = $extraData['price_type'];

			if($extraPriceType == 0)
			{
				// Price per booking
				$subTotalExtraPrice = $extraPrice;
			} else if($extraPriceType == 1 && $this->priceCalculationType == "1")
			{
				// Extra Price Type = DAYS, Price Calculation Type = DAYS
				$subTotalExtraPrice = $extraPrice * ceil($validPeriod / 86400);
			} else if ($extraPriceType == 2 && $this->priceCalculationType == "2")
			{
				// Extra Price Type = HOURS, Price Calculation Type = HOURS
				$subTotalExtraPrice = $extraPrice * ceil($validPeriod / 3600);
			} else if ($extraPriceType == 2 && $this->priceCalculationType == "3")
			{
				// Extra Price Type = HOURS, Price Calculation Type = MIXED (HOUR ACCURACY, RESULT IN DAYS)
				$subTotalExtraPrice = $extraPrice * ceil($validPeriod / 3600);



			} else if ($extraPriceType == 2 && $this->priceCalculationType == "1")
			{
				// Extra Price Type = HOURS, Price Calculation Type = DAYS
				$subTotalExtraPrice = ($extraPrice * 24) * ceil($validPeriod / 86400);
			} else if ($extraPriceType == 1 && $this->priceCalculationType == "2")
			{
				// Extra Price Type = DAYS, Price Calculation Type = HOURS
				$subTotalExtraPrice = ($extraPrice / 24) * ceil($validPeriod / 3600);
			} else if ($extraPriceType == 1 && $this->priceCalculationType == "3")
			{
				// Extra Price Type = DAYS, Price Calculation Type = MIXED (HOUR ACCURACY, RESULT IN DAYS)
				$subTotalExtraPrice = ($extraPrice / 24) * ceil($validPeriod / 3600);
			}

		}

        if($this->debugMode)
        {
            echo "<br />-&gt; Extra Id: {$validExtraId} , ";
            echo "Local Date: ".date("Y-m-d", $validPickupTimestamp + get_option('gmt_offset') * 3600)." (Unix, GMT: {$validPickupTimestamp}), ";
            echo "Price w/o VAT: ".$subTotalExtraPrice;
        }

		return $subTotalExtraPrice;
	}

	public function getUnitPriceDetailsByInterval($paramPickupTimestamp, $paramDropoffTimestamp)
	{
		return $this->getPriceDetails($paramPickupTimestamp, $paramDropoffTimestamp, 1, FALSE);
	}

	public function getMultipliedPriceDetailsByInterval($paramPickupTimestamp, $paramDropoffTimestamp, $paramMultiplier)
	{
		return $this->getPriceDetails($paramPickupTimestamp, $paramDropoffTimestamp, $paramMultiplier, FALSE);
	}

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getBasicWeekCheapestDayMinimalPriceDetails()
    {
        return $this->getWeekCheapestDayMinimalPriceDetails(TRUE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getFullWeekCheapestDayMinimalPriceDetails()
    {
        return $this->getWeekCheapestDayMinimalPriceDetails(FALSE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getBasicWeekPriciestDayMinimalPriceDetails()
    {
        return $this->getWeekPriciestDayMinimalPriceDetails(TRUE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getFullWeekPriciestDayMinimalPriceDetails()
    {
        return $this->getWeekPriciestDayMinimalPriceDetails(FALSE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     * SQL optimized method
     */
    public function getBasicWeekMinimalPriceDetails()
    {
        return $this->getWeekMinimalPriceDetails(TRUE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     * SQL optimized method
     */
    public function getFullWeekMinimalPriceDetails()
    {
        return $this->getWeekMinimalPriceDetails(FALSE);
    }


    /**
     * NOTE: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getWeekMinimalPriceDetails() method
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return mixed
     */
    private function getWeekCheapestDayMinimalPriceDetails($paramBasicDetails = FALSE)
	{
        // For extras Week's Cheapest and Priciest days are the same
        $arrWeekMinimalPriceDetails = $this->getWeekMinimalPriceDetails($paramBasicDetails);
        $weekPriciestDayMinPriceDetails = $arrWeekMinimalPriceDetails['cheapest_day'];

        return $weekPriciestDayMinPriceDetails;
	}

    /**
     * NOTE: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getWeekMinimalPriceDetails() method
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return mixed
     */
    private function getWeekPriciestDayMinimalPriceDetails($paramBasicDetails = FALSE)
	{
		// For extras Week's Cheapest and Priciest days are the same
        $arrWeekMinimalPriceDetails = $this->getWeekMinimalPriceDetails($paramBasicDetails);
        $weekPriciestDayMinPriceDetails = $arrWeekMinimalPriceDetails['priciest_day'];

        return $weekPriciestDayMinPriceDetails;
	}

	/**
     * SQL optimized method
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return array
     */
	private function getWeekMinimalPriceDetails($paramBasicDetails = FALSE)
	{
		$localPickupTimestamp = time() + get_option( 'gmt_offset' ) * 3600;
		$localDropoffTimestamp = ($this->priceCalculationType == "2" ? time()+3600 : time()+86400) + get_option( 'gmt_offset' ) * 3600;
        $minPriceDetails = $this->getPriceDetails($localPickupTimestamp, $localDropoffTimestamp, 1, TRUE, $paramBasicDetails);

        // For extras - min and max are the same
        $minimalPriceDetails = array(
            "cheapest_day" => $minPriceDetails,
            "priciest_day" => $minPriceDetails,
        );

        return $minimalPriceDetails;
	}

	/**
	 * Most advanced item pricing function EVER. Final
	 * @param int $paramPickupTimestamp
	 * @param int $paramDropoffTimestamp
	 * @param int $paramMultiplier - how many times multiply price for ['multiplied'] stack
	 * @param bool $paramMinimalPrice - should be use a minimal price instead of period
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return array
	 */
	public function getPriceDetails($paramPickupTimestamp, $paramDropoffTimestamp, $paramMultiplier = 1, $paramMinimalPrice = FALSE, $paramBasicDetails = FALSE)
	{
		// Single Extra Item

		// 1: Single Extra Subtotal (W/out VAT & w/out Discount)			= I.e. 100 EUR (4x25 EUR Daily Price)      / getPriceByPeriod()
		// --> 1A: Single Extra Subtotal (With VAT)
		// --> 1B: Single Extra Subtotal (Dynamic - with or w/out VAT)
		// 2: Single Extra Discount Percentage      						= I.e. 10%                                 / getTotalDiscountPercentageByPeriod()
		// 3: Single Extra Discount Amount (W/out VAT)	 					= I.e. 10 EUR (100 EUR * 10%)
		// --> 3A: Single Extra Discount Amount (With VAT)
		// --> 3B: Single Extra Discount Amount (Dynamic - with or w/out VAT)
		// 4: Single Extra Discounted Total (W/out VAT)     				= I.e. 90 EUR (100 EUR - 10%)
		// --> 4A: Single Extra Discounted Total (With VAT)					= I.e. 108.90 EUR (90 EUR + 18.90 EUR)
		// --> 4B: Single Extra Discounted Total (Dynamic - with or w/out VAT)
		// 5: Single Extra VAT Percentage (Tax)            					= I.e. 21%                                 / VARIABLE: this->vatPercentage
		// 6: Single Extra Subtotal VAT Amount (Tax)          				= I.e. 21 EUR (100 EUR * VAT_PERCENTAGE)
		// 7: Single Extra Discounted VAT Amount (Tax) 						= I.e. 18.90 EUR (90 EUR * VAT_PERCENTAGE)
		// 9: Single Extra Prepayment Percentage              					= I.e. 100%                                / getPrepaymentPercentageByPeriod()
		// 10: Single Extra Prepayment Amount (W/out VAT)        				= I.e. 90 EUR (90 EUR * PREPAYMENT_PERCENTAGE)
		// --> 10A: Single Extra Prepayment Amount (With VAT)					= I.e. 108.90 EUR (108.90 EUR * PREPAYMENT_PERCENTAGE)
		// --> 10B: Single Extra Prepayment Amount (Dynamic - with or w/out VAT)
		// 11: Single Extra Fixed Deposit Amount (No VAT Exist)				= I.e. 250 EUR 						       / getFixedDepositAmountByPeriod()

        if($this->debugMode == 2)
        {
            echo "<br />---------------------------------------------------------------------------------------------------------";
        }


        // Part 1: Extra Id
		$validExtraId 						= NRSValidator::getValidInteger($this->elementId);
		$validPickupTimestamp				= NRSValidator::getValidInteger($paramPickupTimestamp, 0);
		$validDropoffTimestamp				= NRSValidator::getValidInteger($paramDropoffTimestamp, 0);
		$validPeriodUntilPickup				= NRSValidator::getPeriod(time(), $validPickupTimestamp, FALSE);
		$validPeriod						= NRSValidator::getPeriod($validPickupTimestamp, $validDropoffTimestamp, FALSE);
        $validPeriodUntilPickupByPriceType  = 0;
        $validPeriodByPriceType             = 0;
		$validMultiplier					= NRSValidator::getValidInteger($paramMultiplier, 1);

        // Part 2: Periods by Price type
        // For period until pickup we need to floor days or hours depending on the mode
        // For Booking duration we need to ceil days or hours depending on the mode
        if($this->priceCalculationType == 1)
        {
            // Price by days
            $daysUntilPickup                = NRSValidator::getFloorDaysFromSeconds($validPeriodUntilPickup);
            $validPeriodUntilPickupByPriceType = $daysUntilPickup * 86400;

            $bookingDurationInDays          = NRSValidator::getCeilDaysFromSeconds($validPeriod);
            $validPeriodByPriceType         = $bookingDurationInDays * 86400;
        } else if($this->priceCalculationType == 2)
        {
            // Price by hours
            $hoursUntilPickup               = NRSValidator::getCeilHoursFromSeconds($validPeriodUntilPickup);
            $validPeriodUntilPickupByPriceType = $hoursUntilPickup * 3600;

            $bookingDurationInHours         = NRSValidator::getCeilHoursFromSeconds($validPeriod);
            $validPeriodByPriceType         = $bookingDurationInHours * 3600;
        } else if($this->priceCalculationType == 3)
        {
            // Mixed price by days and hours
            $daysAndHoursUntilPickup        = NRSValidator::getFloorDaysAndFloorHoursFromSeconds($validPeriodUntilPickup);
            $validPeriodUntilPickupByPriceType = $daysAndHoursUntilPickup['days'] * 86400 + $daysAndHoursUntilPickup['hours'] * 3600;

            $bookingDurationInDaysAndHours  = NRSValidator::getFloorDaysAndCeilHoursFromSeconds($validPeriod);
            $validPeriodByPriceType         = $bookingDurationInDaysAndHours['days'] * 86400 + $bookingDurationInDaysAndHours['hours'] * 3600;
        }

		// Part 3: Extra Prices
		// 1, 1A, 1B - Single Extra Subtotal (W/out VAT), (With VAT),(Dynamic - with or w/out VAT)
		$unitSubtotalPriceWithoutVAT  		= $this->getUnitPriceByInterval($validPickupTimestamp, $validDropoffTimestamp);
		$unitSubtotalPriceWithVAT 	 		= $unitSubtotalPriceWithoutVAT + $unitSubtotalPriceWithoutVAT * ($this->vatPercentage / 100);
		$unitSubtotalPriceDynamic 	 		= $this->showPricesWithVAT == "1" ? $unitSubtotalPriceWithVAT : $unitSubtotalPriceWithoutVAT;

		// 2 - Single Extra Discount Percentage
		$objDiscountManager = new NRSExtraDiscountManager($this->internalWPDB, $this->nrsPrefix, $this->lang, $validExtraId, $this->savedConfig);
		if($paramMinimalPrice == TRUE)
		{
			$unitDiscountPercentage 		= $objDiscountManager->getMaxTotalDiscountPercentage();
		} else
		{
			$unitDiscountPercentage			= $objDiscountManager->getTotalDiscountPercentageByPeriod($validPeriodUntilPickupByPriceType, $validPeriodByPriceType);
		}

		// 3, 3A, 3B - Single Extra Discount Amount (W/out VAT), (With VAT),(Dynamic - with or w/out VAT)
		$unitDiscountAmountWithoutVAT		= $unitSubtotalPriceWithoutVAT * ($unitDiscountPercentage / 100);
		$unitDiscountAmountWithVAT			= $unitDiscountAmountWithoutVAT + $unitDiscountAmountWithoutVAT * ($this->vatPercentage / 100);
		$unitDiscountAmountDynamic			= $this->showPricesWithVAT == "1" ? $unitDiscountAmountWithVAT : $unitDiscountAmountWithoutVAT;

		// 4, 4A, 4B - Single Extra Discounted Total (W/out VAT), (With VAT),(Dynamic - with or w/out VAT)
		$unitDiscountedTotalWithoutVAT 		=  $unitSubtotalPriceWithoutVAT - $unitDiscountAmountWithoutVAT;
		$unitDiscountedTotalWithVAT    		=  $unitSubtotalPriceWithVAT - $unitDiscountAmountWithVAT;
		$unitDiscountedTotalDynamic			=  $unitSubtotalPriceDynamic - $unitDiscountAmountDynamic;

		// 5 - Single Extra VAT Percentage (Tax)
		$unitVATPercentage 					= $this->vatPercentage;

		// 6 - Single Extra Subtotal VAT Amount (Tax)
		$unitSubtotalVATAmount 	  			= $unitSubtotalPriceWithVAT - $unitSubtotalPriceWithoutVAT;

		// 7 - Single Extra Discounted VAT Amount (Tax)
		$unitDiscountedVATAmount 			= $unitDiscountedTotalWithVAT - $unitDiscountedTotalWithoutVAT;

        // BASIC PRICE DETAILS
        $arrPriceDetails = array();
        $arrPriceDetails['element_id'] = $validExtraId;
        $arrPriceDetails['element_type'] = "extra";
        $arrPriceDetails['unit'] = array(
            "subtotal_price" 			=> $unitSubtotalPriceWithoutVAT,
            "subtotal_price_with_vat" 	=> $unitSubtotalPriceWithVAT,
            "subtotal_price_dynamic" 	=> $unitSubtotalPriceDynamic,
            "discount_amount"			=> $unitDiscountAmountWithoutVAT,
            "discount_amount_with_vat"	=> $unitDiscountAmountWithVAT,
            "discount_amount_dynamic"	=> $unitDiscountAmountDynamic,
            "discounted_total"			=> $unitDiscountedTotalWithoutVAT,
            "discounted_total_with_vat" => $unitDiscountedTotalWithVAT,
            "discounted_total_dynamic"	=> $unitDiscountedTotalDynamic,
            "subtotal_vat_amount" 		=> $unitSubtotalVATAmount,
            "discounted_vat_amount" 	=> $unitDiscountedVATAmount,
        );
        $arrPriceDetails['percentage'] = array(
            "discount"					=> $unitDiscountPercentage,
            "vat" 						=> $unitVATPercentage,
        );

        if($paramBasicDetails == FALSE)
        {
            // FULL PRICE DETAILS: BASIC AND ADDITIONAL PRICE DETAILS
            // 9 - Single Extra Prepayment Percentage
            $objPrepaymentManager = new NRSExtraPrepaymentManager($this->internalWPDB, $this->nrsPrefix, $this->lang, $validExtraId, $this->savedConfig);
            if($paramMinimalPrice == TRUE)
            {
                $unitPrepaymentPercentage 		= $objPrepaymentManager->getMinimalPrepaymentPercentage();
            } else
            {
                $unitPrepaymentPercentage 		= $objPrepaymentManager->getPrepaymentPercentageByPeriod($validPeriodByPriceType);
            }

            // 10 - Single Extra Prepayment Amount (W/out VAT), (With VAT), (Dynamic - with or w/out VAT)
            $unitPrepaymentAmountWithoutVAT		= $unitDiscountedTotalWithoutVAT * ($unitPrepaymentPercentage / 100);
            $unitPrepaymentAmountWithVAT		= $unitDiscountedTotalWithVAT * ($unitPrepaymentPercentage / 100);
            $unitPrepaymentAmountDynamic		= $this->showPricesWithVAT == "1" ? $unitPrepaymentAmountWithVAT : $unitPrepaymentAmountWithoutVAT;

            // 11 - Single Extra Fixed Deposit Amount (VAT for deposit do not exist)
            $objDepositManager = new NRSExtraDepositManager($this->internalWPDB, $this->nrsPrefix, $this->lang, $this->savedConfig, $validExtraId);
            if($paramMinimalPrice == TRUE)
            {
                $unitFixedDepositAmount 		= $objDepositManager->getMinimalFixedDepositAmount();
            } else
            {
                $unitFixedDepositAmount 		= $objDepositManager->getFixedDepositAmountByPeriod($validPeriodByPriceType);
            }

            $arrPriceDetails['unit']['prepayment_amount']           = $unitPrepaymentAmountWithoutVAT;
            $arrPriceDetails['unit']['prepayment_amount_with_vat']  = $unitPrepaymentAmountWithVAT;
            $arrPriceDetails['unit']['prepayment_amount_dynamic']   = $unitPrepaymentAmountDynamic;
            $arrPriceDetails['unit']['fixed_deposit_amount']        = $unitFixedDepositAmount;

            $arrPriceDetails['percentage']['prepayment']			= $unitPrepaymentPercentage;
        } else
        {
            $unitPrepaymentPercentage = 0;
            $unitFixedDepositAmount = 0;
        }

        // Multiplied prices
        $arrPriceDetails['multiplier'] = $validMultiplier;
        $arrPriceDetails['multiplied'] = NRSFormatter::getMultipliedNumberArray($arrPriceDetails['unit'], $validMultiplier);

        if($this->debugMode == 3)
        {
            // We want to do a debug here to avoid mess with printed data
            $pickupTMZStamp = $validPickupTimestamp + get_option( 'gmt_offset' ) * 3600;
            $dropoffTMZStamp = $validDropoffTimestamp + get_option( 'gmt_offset' ) * 3600;
            $printPickupDate = date_i18n( get_option( 'date_format' ).' '.get_option( 'time_format' ), $pickupTMZStamp, TRUE);
            $printDropoffDate = date_i18n( get_option( 'date_format' ).' '.get_option( 'time_format' ), $dropoffTMZStamp, TRUE);
            // Deep debug
            echo "<br /><strong>Returned price details for Extra Id={$validExtraId}:</strong>";
            echo "<br />Minimal price only:"; var_dump($paramMinimalPrice);
            echo "<br />Only basic details:"; var_dump($paramBasicDetails);
            echo "<br />Dates: {$printPickupDate} - {$printDropoffDate}";
            echo "<br />UNIX, GMT period: {$validPickupTimestamp} - {$validDropoffTimestamp}";
            echo "<br />Price calculation type: {$this->priceCalculationType}";
            echo "<br />Period by price type: {$validPeriodByPriceType}";
            echo "<br />Unit discount percentage: {$unitDiscountPercentage}";
            echo "<br />Unit prepayment percentage: {$unitPrepaymentPercentage}";
            echo "<br />Unit fixed deposit amount: {$unitFixedDepositAmount}";
            echo '<div style="font-size:12px;line-height:18px;color:navy;">'.nl2br(print_r($arrPriceDetails, TRUE)).'</div>';
            echo "---------------------------------------------------------------------------------------------------------";
            echo "<br /><br />";
        }

        // Unit prints
		$arrPriceDetails['unit_tiny_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "tiny");
		$arrPriceDetails['unit_tiny_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "tiny_without_fraction");
		$arrPriceDetails['unit_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "regular");
		$arrPriceDetails['unit_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "regular_without_fraction");
		$arrPriceDetails['unit_long_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "long");
		$arrPriceDetails['unit_long_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "long_without_fraction");

		// Multiplied prints
		$arrPriceDetails['multiplied_tiny_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "tiny");
		$arrPriceDetails['multiplied_tiny_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "tiny_without_fraction");
		$arrPriceDetails['multiplied_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "regular");
		$arrPriceDetails['multiplied_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "regular_without_fraction");
		$arrPriceDetails['multiplied_long_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "long");
		$arrPriceDetails['multiplied_long_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "long_without_fraction");

		// Word prints
		$arrPriceDetails['word_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "word");
		$arrPriceDetails['time_extension_print'] = $this->getPricePeriodText("SHORT");
		$arrPriceDetails['time_extension_long_print'] = $this->getPricePeriodText("LONG");

		// Percentage prints
		$arrPriceDetails['percentage_print'] = NRSFormatter::getFormattedPercentageArray($arrPriceDetails['percentage'], "regular");

		return $arrPriceDetails;
	}

	/**
	 * @param string $paramType - SHORT OR LONG
	 * @return string
	 */
	public function getPricePeriodText($paramType = "LONG")
	{
		$text = "";

		$validExtraId = NRSValidator::getValidInteger($this->elementId, 0);
		$extraData = $this->internalWPDB->get_row("
			SELECT price_type
			FROM {$this->nrsPrefix}extras
			WHERE extra_id='{$validExtraId}'
		", ARRAY_A);
		if(!is_null($extraData))
		{
			if($extraData['price_type'] == 0)
			{
				$text = $paramType == "LONG" ? $this->lang->getText('NRS_PER_BOOKING_TEXT') : $this->lang->getText('NRS_PER_BOOKING_SHORT_TEXT');
			} else
			{
				if ($this->priceCalculationType == 1)
				{
					$text = $paramType == "LONG" ? $this->lang->getText('NRS_PER_DAY_TEXT') : $this->lang->getText('NRS_PER_DAY_SHORT_TEXT');
				} else if ($this->priceCalculationType == 2)
				{
					$text = $paramType == "LONG" ? $this->lang->getText('NRS_PER_HOUR_TEXT') : $this->lang->getText('NRS_PER_HOUR_SHORT_TEXT');
				} else if ($this->priceCalculationType == 3)
				{
					$text = $paramType == "LONG" ? $this->lang->getText('NRS_PER_DAY_TEXT') : $this->lang->getText('NRS_PER_DAY_SHORT_TEXT');
				}
			}
		}

		return $text;
	}
}
