<?php
/**
 * Item Processor
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @uses NRSDepositManager, NRSDiscountManager, NRSPrepaymentManager
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItem extends NRSElement implements iNRSElement
{
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId, $paramOptionalConfig = array())
    {
        parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId, $paramOptionalConfig);
    }

    /**
     * @param $paramItemId
     * @return mixed
     */
    private function getDataFromDatabaseById($paramItemId)
    {
        $validItemId = NRSValidator::getValidInteger($paramItemId, 0);
        $row = $this->internalWPDB->get_row("
            SELECT *
            FROM {$this->nrsPrefix}items
            WHERE item_id='{$validItemId}'
        ", ARRAY_A);

        return $row;
    }

    /**
     * @param $manufacturerId
     * @return string
     */
    private function getManufacturerTitle($manufacturerId)
    {
        $ret = "";
        $row = $this->internalWPDB->get_row("
            SELECT manufacturer_title
            FROM {$this->nrsPrefix}manufacturers
            WHERE manufacturer_id='".intval($manufacturerId)."'
        ", ARRAY_A);

        if(!is_null($row))
        {
            $ret = $row['manufacturer_title'];
        }
        return $ret;
    }

    /**
     * @param $itemBodyTypeId
     * @return string
     */
    private function getBodyTypeTitle($itemBodyTypeId)
    {
        $ret = "";
        $row = $this->internalWPDB->get_row("
            SELECT body_type_title
            FROM {$this->nrsPrefix}body_types
            WHERE body_type_id='".intval($itemBodyTypeId)."'
        ", ARRAY_A);

        if(!is_null($row))
        {
            $ret = $row['body_type_title'];
        }
        return $ret;
    }

    /**
     * @param $paramTransmissionTypeId
     * @return string
     */
    private function getTransmissionTypeTitle($paramTransmissionTypeId)
    {
        $ret = "";
        $row = $this->internalWPDB->get_row("
            SELECT transmission_type_title
            FROM {$this->nrsPrefix}transmission_types
            WHERE transmission_type_id='".intval($paramTransmissionTypeId)."'
        ", ARRAY_A);

        if(!is_null($row))
        {
            $ret = $row['transmission_type_title'];
        }
        return $ret;
    }

    /**
     * @param $paramFuelTypeId
     * @return string
     */
    private function getFuelTypeTitle($paramFuelTypeId)
    {
        $ret = "";
        $row = $this->internalWPDB->get_row("
            SELECT fuel_type_title
            FROM {$this->nrsPrefix}fuel_types
            WHERE fuel_type_id='".intval($paramFuelTypeId)."'
        ", ARRAY_A);

        if(!is_null($row))
        {
            $ret = $row['fuel_type_title'];
        }
        return $ret;
    }

    /**
     * @param $paramItemId
     * @param bool $showOnlyItemListFeatures
     * @return string
     */
    private function getSelectedFeatures($paramItemId, $showOnlyItemListFeatures = FALSE)
    {
        $html = '';
        $sqlAddForItemListOnly = "";
        $validItemId = NRSValidator::isInteger($paramItemId) ? $paramItemId : 0;

        if($showOnlyItemListFeatures)
        {
            $sqlAddForItemListOnly = " AND f.display_in_item_list='1'";
        }

        $rows = $this->internalWPDB->get_results("
			SELECT f.feature_title
			FROM {$this->nrsPrefix}item_features AS itf, {$this->nrsPrefix}features AS f
			WHERE itf.item_id = '{$validItemId}' AND f.feature_id = itf.feature_id
			{$sqlAddForItemListOnly}
		", ARRAY_A);

        $num = sizeof($rows);

        if($num)
        {
            $html .= '<ul class="nrs-item-features-list">';
            foreach ($rows AS $row)
            {
                $html .= '<li>'.$row['feature_title'].'</li>';
            }
            $html .= '</ul>';
        }

        return $html;
    }

    public function getBasicDetails()
    {
        return $this->getDetails(TRUE);
    }

    public function getFullDetails()
    {
        return $this->getDetails(FALSE);
    }

    /**
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return array
     */
    public function getDetails($paramBasicDetails = FALSE)
    {
        $itemData = $this->getDataFromDatabaseById($this->elementId);

        if(!is_null($itemData))
        {
            $image1_Folder = $itemData['demo_image_1'] == 1 ? $GLOBALS['NRS_DEMO_GALLERY_URL'] : $GLOBALS['NRS_GALLERY_URL'];
            $image2_Folder = $itemData['demo_image_2'] == 1 ? $GLOBALS['NRS_DEMO_GALLERY_URL'] : $GLOBALS['NRS_GALLERY_URL'];
            $image3_Folder = $itemData['demo_image_3'] == 1 ? $GLOBALS['NRS_DEMO_GALLERY_URL'] : $GLOBALS['NRS_GALLERY_URL'];

            // Extend $item with additional details
            $itemData['item_description_page_url'] = $itemData['item_description_page_id'] != 0 ? get_permalink($itemData['item_description_page_id']) : "";
            $itemData['manufacturer_title'] = $this->getManufacturerTitle($itemData['manufacturer_id']);
            $itemData['body_type_title'] = $this->getBodyTypeTitle($itemData['body_type_id']);
            $itemData['fuel_type_title'] = $this->getFuelTypeTitle($itemData['fuel_type_id']);
            $itemData['transmission_type_title'] = $this->getTransmissionTypeTitle($itemData['transmission_type_id']);

            $itemData['mini_thumb_url'] = $itemData['item_image_1'] != "" ? $image1_Folder."mini_thumb_".$itemData['item_image_1'] : "";
            $itemData['thumb_url'] = $itemData['item_image_1'] != "" ? $image1_Folder."thumb_".$itemData['item_image_1'] : "";
            $itemData['big_thumb_url'] = $itemData['item_image_1'] != "" ? $image1_Folder."big_thumb_".$itemData['item_image_1'] : "";
            $itemData['image_url'] = $itemData['item_image_1'] != "" ? $image1_Folder.$itemData['item_image_1'] : "";

            $itemData['mini_thumb_2_url'] = $itemData['item_image_2'] != "" ? $image2_Folder."mini_thumb_".$itemData['item_image_2'] : "";
            $itemData['thumb_2_url'] = $itemData['item_image_2'] != "" ? $image2_Folder."thumb_".$itemData['item_image_2'] : "";
            $itemData['big_thumb_2_url'] = $itemData['item_image_2'] != "" ? $image2_Folder."big_thumb_".$itemData['item_image_2'] : "";
            $itemData['image_2_url'] = $itemData['item_image_2'] != "" ? $image2_Folder.$itemData['item_image_2'] : "";

            $itemData['mini_thumb_3_url'] = $itemData['item_image_3'] != "" ? $image3_Folder."mini_thumb_".$itemData['item_image_3'] : "";
            $itemData['thumb_3_url'] = $itemData['item_image_3'] != "" ? $image3_Folder."thumb_".$itemData['item_image_3'] : "";
            $itemData['big_thumb_3_url'] = $itemData['item_image_3'] != "" ? $image3_Folder."big_thumb_".$itemData['item_image_3'] : "";
            $itemData['image_3_url'] = $itemData['item_image_3'] != "" ? $image3_Folder.$itemData['item_image_3'] : "";

            $itemData['print_mileage'] = $itemData['mileage'] == "" ? $this->lang->getText('NRS_UNLIMITED_TEXT') : $itemData['mileage']."".$this->measurementUnit;
            if($paramBasicDetails == FALSE)
            {
                $itemData['print_features_for_list'] = $this->getSelectedFeatures($itemData['item_id'], TRUE);
                $itemData['print_features'] = $this->getSelectedFeatures($itemData['item_id']);
            }

            // Show of hide fields
            $itemData['show_manufacturer'] = $itemData['manufacturer_id'] > 0 && $itemData['manufacturer_title'] != "" ? TRUE : FALSE;
            $itemData['show_model_name'] = TRUE; // Always true - this field is mandatory
            $itemData['show_body_type'] = $itemData['body_type_id'] > 0 && $itemData['body_type_title'] != "" ? TRUE : FALSE;
            $itemData['show_transmission_type'] =$itemData['transmission_type_id'] > 0 && $itemData['transmission_type_title'] != "" ? TRUE : FALSE;
            $itemData['show_fuel_type'] = $itemData['fuel_type_id'] > 0 && $itemData['fuel_type_title'] != "" ? TRUE : FALSE;
            $itemData['show_fuel_consumption'] = $itemData['fuel_consumption'] != "" ? TRUE : FALSE;
            $itemData['show_max_passengers'] = $itemData['max_passengers'] > 0 ? TRUE : FALSE;

            $itemData['show_engine_capacity'] = $itemData['engine_capacity'] != "" ? TRUE : FALSE;
            $itemData['show_max_luggage'] = $itemData['max_luggage'] > 0 ? TRUE : FALSE;
            $itemData['show_item_doors'] = $itemData['item_doors'] > 0 ? TRUE : FALSE;
            $itemData['show_min_driver_age'] = $itemData['min_driver_age'] > 0 ? TRUE : FALSE;

            $itemData['show_mileage'] = $itemData['mileage'] > 0 || $itemData['mileage'] == "" ? TRUE : FALSE;
        }

        return $itemData;
    }

    /****************************************************************************/
    /*********************** ADVANCED METHODS: START ****************************/
    /****************************************************************************/

    /**
     * @param $imageFile
     * @param $paramImageCounter
     * @return bool
     */
    private function uploadImage(&$imageFile, $paramImageCounter)
    {
        $ret = false;

        // Settings
        $enable_thumbnails  = 1 ; // set 0 to disable thumbnail creation
        $maxImageSize     = 4096000 ; // max image size in bytes, default 1MB

        $validImageCounter = NRSValidator::getValidInteger($paramImageCounter, 1);
        if($validImageCounter < 1 || $validImageCounter > 3)
        {
            $validImageCounter = 1;
        }
        $validItemId = NRSValidator::getValidInteger($this->elementId, 0);
        $itemDetails = $this->getFullDetails();

        // Create writable uploads directory if it do not exist yet
        $uploadDirectoryWritable = NRSValidator::createWritableDirectory($GLOBALS['NRS_UPLOAD_PATH_WITHOUT_END_SLASH']);

        if($uploadDirectoryWritable && !is_null($itemDetails) && $imageFile['error'] == 0 && preg_match("#^image/#i", $imageFile['type']) && $imageFile['size'] <= $maxImageSize)
        {
            // Actions to perform, if new image been updated

            //$img_type = ($_FILES['item_image_'.$imageCounter]['type'] == "image/jpeg") ? ".jpg" : $img_type;
            //$img_type = ($_FILES['item_image_'.$imageCounter]['type'] == "image/gif") ? ".gif" : $img_type;
            //$img_type = ($_FILES['item_image_'.$imageCounter]['type'] == "image/png") ? ".png" : $img_type;
            $imgRealName = time().'_'.$imageFile['name'];
            $imgPath = $GLOBALS['NRS_UPLOAD_PATH'].$imgRealName;
            if($itemDetails['demo_image_'.$validImageCounter] == 0 && $itemDetails['item_image_'.$validImageCounter] != "")
            {
                // Unlink files only if it's not a demo image
                unlink($GLOBALS['NRS_UPLOAD_PATH'].$itemDetails['item_image_'.$validImageCounter]);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."big_thumb_".$itemDetails['item_image_'.$validImageCounter]);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."thumb_".$itemDetails['item_image_'.$validImageCounter]);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."mini_thumb_".$itemDetails['item_image_'.$validImageCounter]);
            }
            copy( $_FILES['item_image_'.$validImageCounter]['tmp_name'], $imgPath );
            if($enable_thumbnails)
            {
                $this->makeThumbnails($GLOBALS['NRS_UPLOAD_PATH'], $imgRealName, 360, 225, "big_thumb_");
                $this->makeThumbnails($GLOBALS['NRS_UPLOAD_PATH'], $imgRealName, 240, 150, "thumb_");
                $this->makeThumbnails($GLOBALS['NRS_UPLOAD_PATH'], $imgRealName, 100, 63, "mini_thumb_");
            }

            // Update the sql
            $this->internalWPDB->query("
                UPDATE {$this->nrsPrefix}items SET
                item_image_{$validImageCounter}='".sanitize_text_field($imgRealName)."', demo_image_{$validImageCounter}='0'
                WHERE item_id='{$validItemId}'
            ");
            $ret = true;
        }

        return $ret;
    }

    private function makeThumbnails($paramUploadDirectory, $paramImageName, $paramThumbnailWidth, $paramThumbnailHeight, $paramThumbnailNamePrefix = "thumb_")
    {
        $sanitizedUploadDirectory = sanitize_text_field($paramUploadDirectory);
        $sanitizedImageName = sanitize_text_field($paramImageName);
        $validThumbnailWidth = NRSValidator::getValidInteger($paramThumbnailWidth, 360);
        $validThumbnailHeight = NRSValidator::getValidInteger($paramThumbnailHeight, 225);
        $sanitizedThumbnailNamePrefix = sanitize_text_field($paramThumbnailNamePrefix);

        $image = wp_get_image_editor($sanitizedUploadDirectory.$sanitizedImageName); // Return an implementation that extends <tt>WP_Image_Editor</tt>

        if ( ! is_wp_error( $image ) )
        {
            $image->resize( $validThumbnailWidth, $validThumbnailHeight, true ); // height, width and crop
            $image->save( $sanitizedUploadDirectory.$sanitizedThumbnailNamePrefix.$sanitizedImageName );
        }
    }

    public function getFeaturesList()
    {
        $html = '<table width="100%"><tr>';
        $rows = $this->internalWPDB->get_results("
            SELECT *
            FROM {$this->nrsPrefix}features
            ORDER BY feature_title
        ", ARRAY_A);
        if(sizeof($rows) > 0)
        {
            $validElementId = NRSValidator::getValidInteger($this->elementId, 0);
            $i = 0;
            foreach ($rows AS $featureRow)
            {
                $checked = '';
                if($validElementId > 0)
                {
                    $itemFeatureData = $this->internalWPDB->get_row("
                        SELECT feature_id
                        FROM {$this->nrsPrefix}item_features
                        WHERE item_id='{$validElementId}' AND feature_id='".intval($featureRow['feature_id'])."'
                    ", ARRAY_A);
                    if(!is_null($itemFeatureData) && $itemFeatureData['feature_id'] == $featureRow['feature_id'])
                    {
                        $checked = ' checked="checked"';
                    }
                }
                $html .= '<td><input type="checkbox" name="feature[]" value="'.$featureRow['feature_id'].'"'.$checked.' /><span> '.$featureRow['feature_title'].'</span></td>';

                $i++;

                if($i == 2)
                {
                    $html .= '</tr><tr>';
                    $i = 0;
                }
            }
        }
        $html .= '</tr></table>';
        return $html;
    }

    public function getPickupLocationsList()
    {
        return $this->getLocationsList("PICKUP");
    }
    public function getDropoffLocationsList()
    {
        return $this->getLocationsList("DROPOFF");
    }
    private function getLocationsList($paramMode = "PICKUP")
    {
        $validLocationType = $paramMode == "DROPOFF" ? 2 : 1;
        $rows = $this->internalWPDB->get_results("
            SELECT *
            FROM {$this->nrsPrefix}locations
            ORDER BY location_title
        ", ARRAY_A);
        $locationListHTML = "";

        $validElementId = NRSValidator::getValidInteger($this->elementId, 0);
        foreach ($rows AS $row)
        {
            $selected = "";
            if($validElementId > 0)
            {
                $row2 = $this->internalWPDB->get_row("
                  SELECT *
                  FROM {$this->nrsPrefix}item_locations
                  WHERE item_id='{$validElementId}' AND location_type='{$validLocationType}' AND location_id='".intval($row['location_id'])."'
                ", ARRAY_A);
                if(!is_null($row2))
                {
                    $selected .= 'selected="selected"';
                }
            }

            $locationListHTML .= '<option value="'.$row['location_id'].'"'.$selected.'>'.$row['location_title'].' - '.$row['location_address'].'</option>';
        }

        return $locationListHTML;
    }

    /**
     * TODO - verify body types, manufacturers, transmission, fuel type
     */
    public function save()
    {
        // Input data
        $validItemId = NRSValidator::getValidInteger($this->elementId, 0);
        $validBodyTypeId = NRSValidator::isInteger($_POST['body_type_id']) ? intval($_POST['body_type_id']) : 0;
        $validFuelTypeId = NRSValidator::isInteger($_POST['fuel_type_id']) ? intval($_POST['fuel_type_id']) : 0;
        $validManufacturerId = NRSValidator::isInteger($_POST['manufacturer_id']) ? intval($_POST['manufacturer_id']) : 0;
        $sanitizedModelName = sanitize_text_field($_POST['model_name']);
        $validTransmissionTypeId = NRSValidator::isInteger($_POST['transmission_type_id']) ? intval($_POST['transmission_type_id']) : 0;
        $sanitizedMeasurementUnit = sanitize_text_field(esc_html($_POST['measurement_unit']));
        $validUnitsInStock = NRSValidator::isInteger($_POST['units_in_stock']) ? intval($_POST['units_in_stock']) : 1;
        $validMaxItemUnitsPerBooking = NRSValidator::isInteger($_POST['max_units_per_booking']) ? intval($_POST['max_units_per_booking']) : 1;
        $sanitizedFuelConsumption = sanitize_text_field($_POST['fuel_consumption']);
        $sanitizedEngineCapacity = sanitize_text_field($_POST['engine_capacity']);
        $validMaxPassengers = NRSValidator::getValidInteger($_POST['max_passengers'], 5);
        $validMaxLuggage = NRSValidator::getValidInteger($_POST['max_luggage'], 2);
        $validItemDoors = NRSValidator::getValidInteger($_POST['item_doors'], 5);
        $validMinDriverAge = NRSValidator::getValidInteger($_POST['min_driver_age'], 18);
        $sanitizedItemMileage = sanitize_text_field($_POST['item_mileage']);
        $validEnabled = (sanitize_text_field($_POST['enabled']) == "on" ? 1 : 0);
        $validDisplayInSlider = (sanitize_text_field($_POST['display_in_slider']) == "on" ? 1 : 0);
        $validDisplayInItemList = (sanitize_text_field($_POST['display_in_item_list']) == "on" ? 1 : 0);
        $validDisplayInPriceTable = (sanitize_text_field($_POST['display_in_price_table']) == "on" ? 1 : 0);
        $validDisplayInCalendar = (sanitize_text_field($_POST['display_in_calendar']) == "on" ? 1 : 0);
        $validOptionsDisplayMode = intval($_POST['options_display_mode']);

        $arr_POST_PickupLocationIds = $_POST['pickup_location_ids'];
        $arr_POST_DropoffLocationIds = $_POST['dropoff_location_ids'];

        //Verifications
        if($validUnitsInStock < 1)
        {
            // TODO: MOVE TO NRS ADMIN LANG FILE
            $_SESSION['msg'] = "Error: You can&#39;t have less than 1 car unit in garage";
        }
        if($validMaxItemUnitsPerBooking < 1)
        {
            // TODO: MOVE TO NRS ADMIN LANG FILE
            $_SESSION['msg'] = "Error: Your maximum car units per booking can&#39;t be less than 1 car";
        }
        if($validMaxItemUnitsPerBooking > $validUnitsInStock)
        {
            // TODO: MOVE TO NRS ADMIN LANG FILE
            $_SESSION['msg'] = "Error: You can&#39;t allow to book more items per one booking than you have in garage";
        }

        $itemEditData = NULL;
        if($validItemId > 0)
        {
            // We need to get car data first, before deleting image date or updating a car
            $itemEditData = $this->internalWPDB->get_row("
                SELECT * FROM {$this->nrsPrefix}items WHERE item_id='{$validItemId}'
            ", ARRAY_A);
            if(is_null($itemEditData))
            {
                // TODO: MOVE TO NRS ADMIN LANG FILE
                $_SESSION['msg'] = "Error: This car id do not depend to any existing car!";
            }
        }

        if($validItemId > 0 && !is_null($itemEditData) && !isset($_SESSION['msg']))
        {
            // If car data exist

            $validItemDescriptionPageId = NRSValidator::getValidInteger($_POST['item_description_page_id'], 0);

            for($imageCounter = 1; $imageCounter <= 3; $imageCounter++)
            {
                if(isset($_POST['delete_image_'.$imageCounter]) && $itemEditData['item_image_'.$imageCounter] != "")
                {
                    if($itemEditData['demo_image_'.$imageCounter] == 0)
                    {
                        // Unlink files only if it's not a demo image
                        unlink($GLOBALS['NRS_UPLOAD_PATH'].$itemEditData['item_image_1']);
                        unlink($GLOBALS['NRS_UPLOAD_PATH']."thumb_".$itemEditData['item_image_1']);
                        unlink($GLOBALS['NRS_UPLOAD_PATH']."big_thumb_".$itemEditData['item_image_1']);
                        unlink($GLOBALS['NRS_UPLOAD_PATH']."mini_thumb_".$itemEditData['item_image_1']);
                    }

                    // Update the sql
                    $this->internalWPDB->query("
                        UPDATE {$this->nrsPrefix}items SET
                        item_image_{$imageCounter}='', demo_image_{$imageCounter}='0'
                        WHERE item_id='{$validItemId}'
                     ");
                }

                $this->uploadImage($_FILES['item_image_'.$imageCounter], $imageCounter);
            }

            $updateQuery = "
                  UPDATE {$this->nrsPrefix}items set
                  item_description_page_id='".$validItemDescriptionPageId."',
                  body_type_id='{$validBodyTypeId}', fuel_type_id='{$validFuelTypeId}', transmission_type_id='{$validTransmissionTypeId}',
                  manufacturer_id ='{$validManufacturerId}', model_name='{$sanitizedModelName}',
                  measurement_unit='{$sanitizedMeasurementUnit}',
                  units_in_stock='{$validUnitsInStock}', max_units_per_booking='{$validMaxItemUnitsPerBooking}',
                  mileage='{$sanitizedItemMileage}', fuel_consumption='{$sanitizedFuelConsumption}', engine_capacity='{$sanitizedEngineCapacity}',
                  max_passengers='{$validMaxPassengers}', max_luggage='{$validMaxLuggage}', item_doors='{$validItemDoors}',
                  min_driver_age='{$validMinDriverAge}', enabled='{$validEnabled}',
                  display_in_slider='{$validDisplayInSlider}',
                  display_in_item_list='{$validDisplayInItemList}',
                  display_in_price_table='{$validDisplayInPriceTable}',
                  display_in_calendar='{$validDisplayInCalendar}',
                  options_display_mode='{$validOptionsDisplayMode}'
                  WHERE item_id='{$validItemId}'
            ";

            // TODO: MOVE TEXT TO LANG FILE
            $_SESSION['ok_msg'] = "Completed: Car details updated successfully!";

            //die(nl2br($updateQuery));
            $this->internalWPDB->query($updateQuery);

            $this->internalWPDB->query("DELETE FROM {$this->nrsPrefix}item_features WHERE item_id='{$validItemId}'");

            if(sizeof($_POST['feature']) > 0)
            {
                foreach($_POST['feature'] AS $POST_FeatureId)
                {
                    $validFeatureId = NRSValidator::getValidInteger($POST_FeatureId, 0);
                    $this->internalWPDB->query("
                    INSERT INTO {$this->nrsPrefix}item_features
                    (item_id, feature_id)
                    VALUES
                    ('{$validItemId}', '{$validFeatureId}')
                ");
                }
            }

            // Delete current car locations
            $this->internalWPDB->query("
                DELETE FROM {$this->nrsPrefix}item_locations
                WHERE item_id='{$validItemId}'
            ");

            if(sizeof($arr_POST_PickupLocationIds) > 0)
            {
                // Insert new car pickup locations
                foreach($arr_POST_PickupLocationIds AS $POST_pickupLocationId)
                {
                    $validPickupLocationId = NRSValidator::getValidInteger($POST_pickupLocationId, 0);
                    $this->internalWPDB->query("
                        INSERT INTO {$this->nrsPrefix}item_locations
                        VALUES
                        ('{$validItemId}', '{$validPickupLocationId}', 1)
                    ");
                }
            }

            if(sizeof($arr_POST_DropoffLocationIds) > 0)
            {
                // Insert new car dropoff locations
                foreach($arr_POST_DropoffLocationIds AS $POST_dropoffLocationId)
                {
                    $validDropoffLocationId = NRSValidator::getValidInteger($POST_dropoffLocationId, 0);
                    $this->internalWPDB->query("
                        INSERT INTO {$this->nrsPrefix}item_locations
                        VALUES
                        ('{$validItemId}', '{$validDropoffLocationId}', 2)
                    ");
                }
            }

        } else if(!isset($_SESSION['msg']))
        {
            // Add new car, if there is no errors

            /* *************************** WP POSTS PART: START ***************************  */
            $manufacturerRow = $this->internalWPDB->get_row("
                SELECT * FROM {$this->nrsPrefix}manufacturers WHERE manufacturer_id='".intval($validManufacturerId)."'
            ", ARRAY_A);
            // Create post object
            $nrsNewWPItemDescriptionPage = array(
                'post_title'    => $manufacturerRow['manufacturer_title']. ' '.$sanitizedModelName,
                'post_content'  => '',
                'post_status'   => 'publish',
                'post_type'     => $GLOBALS['NRS_EXTENSION'],
                /*'post_author'   => 1,*/ /*auto assign current user*/
                /*'post_category' => array(8,39)*/ /*no categories needed here*/
            );
            $nrsWPError = false;
            // Insert corresponding post as post type 'post'
            $newNRSDescriptionPageID = wp_insert_post( $nrsNewWPItemDescriptionPage, $nrsWPError );
            /* *************************** WP POSTS PART: END ***************************  */

            $itemInserted = $this->internalWPDB->query("
                INSERT INTO {$this->nrsPrefix}items
                (
                    item_description_page_id,
                    body_type_id, fuel_type_id, transmission_type_id,
                    manufacturer_id, model_name,
                    measurement_unit,
                    units_in_stock, max_units_per_booking,
                    mileage, fuel_consumption, engine_capacity,
                    max_passengers, max_luggage, item_doors,
                    min_driver_age,
                    enabled,
                    display_in_slider, display_in_item_list, display_in_price_table, display_in_calendar,
                    options_display_mode
                ) VALUES
                (
                    '{$newNRSDescriptionPageID}',
                    '{$validBodyTypeId}', '{$validFuelTypeId}', '{$validTransmissionTypeId}',
                    '{$validManufacturerId}', '{$sanitizedModelName}',
                    '{$sanitizedMeasurementUnit}',
                    '{$validUnitsInStock}', '{$validMaxItemUnitsPerBooking}',
                    '{$sanitizedItemMileage}', '{$sanitizedFuelConsumption}', '{$sanitizedEngineCapacity}',
                    '{$validMaxPassengers}', '{$validMaxLuggage}', '{$validItemDoors}',
                    '{$validMinDriverAge}',
                    '{$validEnabled}',
                    '{$validDisplayInSlider}', '{$validDisplayInItemList}', '{$validDisplayInPriceTable}', '{$validDisplayInCalendar}',
                    '{$validOptionsDisplayMode}'
                )
            ");
            $validInsertedNewItemId = NRSValidator::getValidInteger($this->internalWPDB->insert_id, 0);

            if($itemInserted === FALSE)
            {
                // TODO: MOVE TO NRS ADMIN LANG FILE
                $_SESSION['msg'] = "Error: New car data was not allowed to insert into database!";
            } else
            {
                // Update the core element id for future use
                $this->elementId = $validInsertedNewItemId;
                for($imageCounter = 1; $imageCounter <= 3; $imageCounter++)
                {
                    $this->uploadImage($_FILES['item_image_'.$imageCounter], $imageCounter);
                }

                // TODO: MOVE TEXT TO LANG FILE
                $_SESSION['ok_msg'] = "Completed: A new car added successfully!";

                /* *************************** WP POSTS PART: START ***************************  */
                // Create post object
                $nrsNewWPItemDescriptionPage = array(
                    'ID'            => $newNRSDescriptionPageID,
                    // content now will be updated and escaped securely
                    'post_content'  => wp_filter_kses('['.$GLOBALS['NRS_SHORTCODE'].' display="item" item="'.$validInsertedNewItemId.'"]
                ['.$GLOBALS['NRS_SHORTCODE'].' display="search" item="'.$validInsertedNewItemId.'"]'),
                );

                // Update corresponding post as post type 'post'
                wp_update_post( $nrsNewWPItemDescriptionPage );
                /* *************************** WP POSTS PART: END ***************************  */

                $this->internalWPDB->query("
                  INSERT INTO {$this->nrsPrefix}price_plans
                  (
                    item_id, start_timestamp, end_timestamp, price_type,
                    mon, tue, wed, thu, fri, sat, sun
                  ) VALUES
                  (
                    '{$validInsertedNewItemId}','0','0','1',
                    '0.00','0.00','0.00','0.00','0.00','0.00','0.00'
                  )
                ");

                $this->internalWPDB->query("
                  INSERT INTO {$this->nrsPrefix}price_plans
                  (
                    item_id, start_timestamp, end_timestamp, price_type,
                    mon, tue, wed, thu, fri, sat, sun
                  ) VALUES
                  (
                    '{$validInsertedNewItemId}','0','0','2',
                    '0.00','0.00','0.00','0.00','0.00','0.00','0.00'
                  )
                ");

                if(sizeof($_POST['feature']) > 0)
                {
                    foreach($_POST['feature'] as $POST_FeatureId)
                    {
                        $validFeatureId = NRSValidator::getValidInteger($POST_FeatureId);
                        $this->internalWPDB->query("
                              INSERT INTO {$this->nrsPrefix}item_features
                              (
                                item_id, feature_id
                              ) VALUES
                              (
                                '{$validInsertedNewItemId}', '{$validFeatureId}'
                              )
                        ");
                    }
                }


                if(sizeof($arr_POST_PickupLocationIds) > 0)
                {
                    foreach($arr_POST_PickupLocationIds AS $POST_pickupLocationId)
                    {
                        $validPickupLocationId = NRSValidator::getValidInteger($POST_pickupLocationId);
                        $this->internalWPDB->query("
                              INSERT INTO {$this->nrsPrefix}item_locations
                              (
                                  item_id, location_id, location_type
                              ) VALUES
                              (
                                '{$validInsertedNewItemId}', '{$validPickupLocationId}', '1'
                              )
                        ");
                    }

                }

                if(sizeof($arr_POST_DropoffLocationIds) > 0)
                {
                    foreach($arr_POST_DropoffLocationIds AS $POST_dropoffLocationId)
                    {
                        $validDropoffLocationId = NRSValidator::getValidInteger($POST_dropoffLocationId);
                        $this->internalWPDB->query("
                                INSERT INTO {$this->nrsPrefix}item_locations
                                (
                                  item_id, location_id, location_type
                                ) VALUES
                                (
                                  '{$validInsertedNewItemId}', '{$validDropoffLocationId}', '2'
                                )
                        ");
                    }
                }
            }
        }
    }

    public function delete()
    {
        $validItemId = NRSValidator::getValidInteger($this->elementId, 0);
        $itemExists = $this->internalWPDB->get_row("SELECT * FROM {$this->nrsPrefix}items WHERE item_id='{$validItemId}'", ARRAY_A);
        if (!is_null($itemExists))
        {
            if ($itemExists['demo_image_1'] == 0 && $itemExists['item_image_1'] != "")
            {
                unlink($GLOBALS['NRS_UPLOAD_PATH'].$itemExists['item_image_1']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."thumb_" . $itemExists['item_image_1']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."big_thumb_" . $itemExists['item_image_1']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."mini_thumb_" . $itemExists['item_image_1']);
            }

            if ($itemExists['demo_image_2'] == 0 && $itemExists['item_image_2'] != "")
            {
                unlink($GLOBALS['NRS_UPLOAD_PATH'].$itemExists['item_image_2']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."thumb_" . $itemExists['item_image_2']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."big_thumb_" . $itemExists['item_image_2']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."mini_thumb_" . $itemExists['item_image_2']);
            }

            if ($itemExists['demo_image_3'] == 0 && $itemExists['item_image_3'] != "")
            {
                unlink($GLOBALS['NRS_UPLOAD_PATH'].$itemExists['item_image_3']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."thumb_".$itemExists['item_image_3']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."big_thumb_".$itemExists['item_image_3']);
                unlink($GLOBALS['NRS_UPLOAD_PATH']."mini_thumb_" . $itemExists['item_image_3']);
            }

            /* ********* WORDPRESS PAGE DELETE: START *********** */
            $wpNRSForcePageDelete = true;
            wp_delete_post($itemExists['item_description_page_id'], $wpNRSForcePageDelete);
            /* ********* WORDPRESS PAGE DELETE: END ************ */

            // NOTE: WE DON'T WANT TO DELETE BOOKINGS IF ITEM WAS PICKED UP IN THE PAST
            $rows = $this->internalWPDB->get_results("
                SELECT booking_id
                FROM {$this->nrsPrefix}booking_options
                WHERE item_id='{$validItemId}'
                ", ARRAY_A);
            if (sizeof($rows) > 0)
            {
                foreach ($rows AS $row)
                {
                    $objMail = new NRSMail($this->internalWPDB, $this->nrsPrefix, $this->lang);
                    $objBooking = new NRSBooking($this->internalWPDB, $this->nrsPrefix, $this->lang, $objMail, "", $row['booking_id']);
                    $objInvoice = new NRSInvoice($this->internalWPDB, $this->nrsPrefix, $this->lang, $row['booking_id']);
                    $objBooking->deleteBooking(FALSE);
                    $objInvoice->deleteInvoice();
                }
            }
            $this->internalWPDB->query("DELETE FROM {$this->nrsPrefix}booking_options WHERE item_id='{$validItemId}'");
            $this->internalWPDB->query("DELETE FROM {$this->nrsPrefix}items WHERE item_id='{$validItemId}'");
            $this->internalWPDB->query("DELETE FROM {$this->nrsPrefix}price_plans WHERE item_id='{$validItemId}'");
            $this->internalWPDB->query("DELETE FROM {$this->nrsPrefix}item_features WHERE item_id='{$validItemId}'");

            $_SESSION['ok_msg'] = "Completed: Car deleted successfully!";
        } else
        {
            $_SESSION['msg'] = "Error: Selected car do not exist!";
        }
    }

    /*******************************************************************************/
    /************************* ELEMENT SPECIFIC FUNCTIONS **************************/
    /*******************************************************************************/

    /**
     * Get drop-down for car passengers
     * @param int $selectedPassengers - for edit mode
     * @return string passengers drop-down html
     */
    public function getPassengersDropDown($selectedPassengers = 0)
    {
        return $this->getAdminNumberDropDown("max_passengers", 0, 100, $selectedPassengers, TRUE, $this->lang->getText('NRS_DONT_DISPLAY_TEXT'));
    }

    /**
     * Get drop-down for luggage amount
     * @param int $selectedLuggage - for edit mode
     * @return string luggage drop-down html
     */
    public function getLuggageDropDown($selectedLuggage = 0)
    {
        return $this->getAdminNumberDropDown("max_luggage", 0, 100, $selectedLuggage, TRUE, $this->lang->getText('NRS_DONT_DISPLAY_TEXT'));
    }

    /**
     * Get drop-down for door amount
     * @param int $selectedDoors - for edit mode
     * @return string luggage drop-down html
     */
    public function getDoorsDropDown($selectedDoors = 0)
    {
        return $this->getAdminNumberDropDown("item_doors", 0, 10, $selectedDoors, TRUE, $this->lang->getText('NRS_DONT_DISPLAY_TEXT'));
    }

    /**
     * Get drop-down for driver age
     * @param int $selectedDriverAge - for edit mode
     * @return string driver age drop-down html
     */
    public function getDriverAgeDropDown($selectedDriverAge = 0)
    {
        return $this->getAdminNumberDropDown("min_driver_age", 0, 30, $selectedDriverAge, TRUE, $this->lang->getText('NRS_DONT_DISPLAY_TEXT'));
    }
}