<?php
/**
 * NRS Item Deposits Observer (no setup for single item)
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemDepositsObserver extends NRSDepositsObserver implements iNRSDepositsObserver
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang);
	}

	/**
	 * DIFFERENT DURATION DEPOSITS FOR DIFFERENT ITEMS
	 * DEPTH: 1
	 * @param bool $showRowNumbers
	 * @return string
	 */
	public function getAdminDifferentDepositDurationGroups($showRowNumbers = FALSE)
	{
		$depositList = '';

		$sqlQuery = "
          SELECT deposit_id, item_id, period_from, period_till, fixed_rental_deposit
          FROM {$this->nrsPrefix}deposits
          GROUP BY period_from, period_till
          ORDER BY period_from ASC, period_till ASC
        ";
		$rows = $this->internalWPDB->get_results($sqlQuery, ARRAY_A);

		$i = 0;
		foreach($rows AS $row)
		{
			$i++;
			$printDurationFrom = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $row['period_from']);
			$printDurationTill = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $row['period_till']);

			// HTML OUTPUT
			$depositList .= '<tr>';
			if($showRowNumbers)
			{
				$depositList .= '<td>'.sprintf('%02d', $i).'</td>';
			}
			$depositList .= '<td><strong>'.$printDurationFrom.'</strong></td>';
			$depositList .= '<td><strong>'.$printDurationTill.'</strong></td>';
			if($this->areDepositsEnabled())
			{
				$depositList .= $row['item_id'] > 0 ? '<td>&nbsp;</td>' : '<td>'.$this->currencySymbol.' '.$row['fixed_rental_deposit'].'</td>';
			}
			if($row['item_id'] == 0)
			{
				// Default deposit - applied for all items
				$depositList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-deposit&amp;deposit_id='.$row['deposit_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
				$depositList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-prices&amp;noheader=true&amp;delete_deposit='.$row['deposit_id']).'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a>';
				$depositList .= '</td>';
			} else
			{
				$depositList .= '<td>&nbsp;</td>';
			}
			$depositList .= '</tr>';
			if($row['item_id'] > 0)
			{
				$depositList .= $this->getAdminDurationDepositListByPeriodFromTo($row['period_from'], $row['period_till'], $showRowNumbers, sprintf('%02d', $i).".");
			}

		}
		return  $depositList;
	}

	/**
	 * DIFFERENT DURATION DEPOSITS FOR DIFFERENT ITEMS IN SPECIFIC PERIOD FROM-TO
	 * DEPTH: 2
	 * @param $paramPeriodFrom
	 * @param $paramPeriodTill
	 * @param bool $showRowNumbers
	 * @param string $rowNumbersPrefix
	 * @return string
	 */
	public function getAdminDurationDepositListByPeriodFromTo($paramPeriodFrom, $paramPeriodTill, $showRowNumbers = FALSE, $rowNumbersPrefix = "0.")
	{
		$depositList = '';
		$validPeriodFrom = NRSValidator::isInteger($paramPeriodFrom) ? intval($paramPeriodFrom) : 0;
		$validPeriodTill = NRSValidator::isInteger($paramPeriodTill) ? intval($paramPeriodTill) : 0;

		$rows = $this->internalWPDB->get_results("
          SELECT deposit_id, item_id, fixed_rental_deposit
          FROM {$this->nrsPrefix}deposits
          WHERE item_id!='0' AND period_from='{$validPeriodFrom}' AND period_till='{$validPeriodTill}'
          ORDER BY period_from ASC, period_till ASC
          ", ARRAY_A);
		if(sizeof($rows) > 0)
		{
			$i = 0;
			foreach($rows AS $row)
			{
				$i++;
				$objItem = new NRSItem($this->internalWPDB, $this->nrsPrefix, $this->lang, $row['item_id']);
				$itemDetails = $objItem->getFullDetails();
				$itemModelName = "";
				$manufacturerTitle = "";
				$bodyTypeTitle = "";
				$transmissionTypeTitle = "";
				if(!is_null($itemDetails))
				{
					$itemModelName = $itemDetails['model_name'];
					$manufacturerTitle = $itemDetails['manufacturer_title'];
					$bodyTypeTitle = $itemDetails['body_type_title'];
					$transmissionTypeTitle = $itemDetails['transmission_type_title'];
				}

                $printDurationFrom = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $validPeriodFrom);
                $printDurationTill = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $validPeriodTill);

				// HTML OUTPUT
				$depositList .= '<tr>';
				if($showRowNumbers)
				{
					$depositList .= '<td>'.$rowNumbersPrefix.sprintf('%02d', $i).'</td>';
				}
				$depositList .= '<td>'.$manufacturerTitle.' '.$itemModelName.'</td>';
				$depositList .= '<td>ID: '.$row['item_id'].', '.$bodyTypeTitle.', '.$transmissionTypeTitle.'</td>';
				if($this->areDepositsEnabled())
				{
					$depositList .= '<td>'.$this->currencySymbol.' '.$row['fixed_rental_deposit'].' ';
                    $depositList .= '<strong>('.$printDurationFrom.' - '.$printDurationTill.')</strong>';
                    $depositList .= '</td>';
				}
				$depositList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-deposit&amp;deposit_id='.$row['deposit_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
				$depositList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-prices&amp;noheader=true&amp;delete_deposit='.$row['deposit_id']).'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a>';
				$depositList .= '</td>';
				$depositList .= '</tr>';
			}
		}
		return  $depositList;
	}
}