<?php
/**
 * NRS Item Discount Manager (with setup for single item)
 * Abstract class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemDiscountManager extends NRSDiscountManager implements iNRSDiscountManager
{
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId, $paramOptionalConfig = array())
    {
        parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId, $paramOptionalConfig);
    }

    /*****************************************************************************************/
    /******************** DISCOUNT PERCENTAGE BY PERIOD: SECTION START ***********************/
    /*****************************************************************************************/


    /**
     * It's a total of two discounts - booking duration and booking in advance
     * @note - Appears that this method internal code is same for both - item and extra
     * @param int $paramPeriodUntilPickup
     * @param int $paramPeriod
     * @return int
     */
    public function getTotalDiscountPercentageByPeriod($paramPeriodUntilPickup, $paramPeriod)
    {
        $discountOnBookingInAdvancePercentage = $this->getDiscountPercentageForBookingInAdvanceByPeriod($paramPeriodUntilPickup);
        $discountOnDurationPercentage = $this->getDiscountPercentageForBookingDurationByPeriod($paramPeriod);

        $totalDiscountPercentage = $discountOnDurationPercentage + $discountOnBookingInAdvancePercentage;

        // Protect system from total discounts bigger than 100%
        if($totalDiscountPercentage > 100)
        {
            $totalDiscountPercentage = 100;
        }

        if($this->debugMode)
        {
            echo "<br />Period Until pickup: {$paramPeriodUntilPickup}, Reservation Period: {$paramPeriod}.";
            echo "<br />Discount on booking in advance: {$discountOnBookingInAdvancePercentage}, ";
            echo "Discount on duration: {$discountOnDurationPercentage}, Total discount: {$totalDiscountPercentage}";
        }

        return $totalDiscountPercentage;
    }

    /**
     * @param $paramPeriodUntilPickup
     * @return float
     */
    public function getDiscountPercentageForBookingInAdvanceByPeriod($paramPeriodUntilPickup)
    {
        return $this->getDiscountPercentage($this->elementId, 0, "ITEM_BOOKING_IN_ADVANCE", $paramPeriodUntilPickup);
    }

    /**
     * @param $paramPeriod
     * @return float
     */
    public function getDiscountPercentageForBookingDurationByPeriod($paramPeriod)
    {
        return $this->getDiscountPercentage($this->elementId, 0, "ITEM_BOOKING_DURATION", $paramPeriod);
    }

    /*****************************************************************************************/
    /************************ MAX DISCOUNT PERCENT: SECTION START ****************************/
    /*****************************************************************************************/

    /**
     * It's a total of two discounts - booking duration and booking in advance
     * @note - Appears that this method internal code is same for both - item and extra
     * @return int
     */
    public function getMaxTotalDiscountPercentage()
    {
        $maxDiscountOnBookingInAdvancePercentage = $this->getMaxDiscountPercentageForBookingInAdvance();
        $maxDiscountOnDurationPercentage = $this->getMaxDiscountPercentageForBookingDuration();

        $maxTotalDiscountPercentage = $maxDiscountOnDurationPercentage + $maxDiscountOnBookingInAdvancePercentage;

        // Protect system from max total discounts bigger than 100%
        if($maxTotalDiscountPercentage > 100)
        {
            $maxTotalDiscountPercentage = 100;
        }

        return $maxTotalDiscountPercentage;
    }

    /**
     * @return int
     */
    public function getMaxDiscountPercentageForBookingInAdvance()
    {
        return $this->getMaxDiscountOnDurationPercent($this->elementId, 0, "ITEM_BOOKING_IN_ADVANCE");
    }

    /**
     * @return int
     */
    public function getMaxDiscountPercentageForBookingDuration()
    {
        return $this->getMaxDiscountOnDurationPercent($this->elementId, 0, "ITEM_BOOKING_DURATION");
    }

}