<?php
/**
 * NRS Item Discounts Observer (no setup for single item)
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemDiscountsObserver extends NRSDiscountsObserver implements iNRSDiscountsObserver
{
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
    {
        parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang);
    }

    public function getDiscountPeriodsOnBookingDuration()
    {
        return $this->getDiscountPeriods("ITEM", "BOOKING_DURATION");
    }
    public function getDiscountPeriodsForBookingInAdvance()
    {
        return $this->getDiscountPeriods("ITEM", "BOOKING_IN_ADVANCE");
    }

    public function getAdminDifferentDiscountDurationGroups($showRowNumbers = FALSE)
    {
        return $this->getAdminDifferentDiscountGroups("BOOKING_DURATION", $showRowNumbers);
    }

    public function getAdminDifferentDiscountBookingInAdvanceGroups($showRowNumbers = FALSE)
    {
        return $this->getAdminDifferentDiscountGroups("BOOKING_IN_ADVANCE", $showRowNumbers);
    }

    /**
     * DIFFERENT DURATION DISCOUNTS FOR DIFFERENT ITEMS
     * DEPTH: 1
     * @param string $paramDiscountType - "BOOKING_DURATION" or "BOOKING_IN_ADVANCE"
     * @param bool $showRowNumbers
     * @return string
     */
    private function getAdminDifferentDiscountGroups($paramDiscountType = "BOOKING_DURATION", $showRowNumbers = FALSE)
    {
        $discountList = '';

        // Find out sorting and discount type values
        $SQLOrder = $paramDiscountType == "BOOKING_IN_ADVANCE" ? "DESC" : "ASC";
        $validDiscountType = $paramDiscountType == "BOOKING_IN_ADVANCE" ? 2 : 1;

        // item_id=0 with extra_id=0 situation is ok, meaning that default discounts would be applied for both
        $sqlQuery = "
          SELECT discount_id, item_id, period_from, period_till, discount_percentage
          FROM {$this->nrsPrefix}discounts
          WHERE discount_type='{$validDiscountType}' AND extra_id='0'
          GROUP BY period_from, period_till
          ORDER BY period_from {$SQLOrder}, period_till {$SQLOrder}
        ";
        $rows = $this->internalWPDB->get_results($sqlQuery, ARRAY_A);

        $i = 0;
        foreach($rows AS $row)
        {
            $i++;
            $printDurationFrom = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $row['period_from']);
            $printDurationTill = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $row['period_till']);

            // HTML OUTPUT
            $discountList .= '<tr>';
            if($showRowNumbers)
            {
                $discountList .= '<td>'.sprintf('%02d', $i).'</td>';
            }
            $discountList .= '<td><strong>'.$printDurationFrom.'</strong></td>';
            $discountList .= '<td><strong>'.$printDurationTill.'</strong></td>';
            if($this->areDiscountsEnabled())
            {
                $discountList .= $row['item_id'] > 0 ? '<td>&nbsp;</td>' : '<td>'.$row['discount_percentage'].' %</td>';
            }
            if($row['item_id'] == 0)
            {
                $discountList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-discount&amp;discount_type='.$validDiscountType.'&amp;discount_id='.$row['discount_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
                $discountList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-discount-manager&amp;discount_type='.$validDiscountType.'&amp;delete_discount='.$row['discount_id'].'&amp;noheader=true').'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a></td>';
            } else
            {
                $discountList .= '<td>&nbsp;</td>';
            }
            $discountList .= '</tr>';
            if($row['item_id'] > 0)
            {
                $discountList .= $this->getAdminDiscountElementListByPeriodFromTo(
                    $paramDiscountType, $row['period_from'], $row['period_till'], $showRowNumbers, sprintf('%02d', $i)."."
                );
            }
        }

        return  $discountList;
    }

    public function getAdminDurationDiscountListByPeriodFromTo($paramPeriodFrom, $paramPeriodTill)
    {
        return $this->getAdminDiscountElementListByPeriodFromTo("BOOKING_DURATION", $paramPeriodFrom, $paramPeriodTill, FALSE, "");
    }

    public function getAdminBookingInAdvanceDiscountListByPeriodFromTo($paramDurationFrom, $paramDurationTill)
    {
        return $this->getAdminDiscountElementListByPeriodFromTo("BOOKING_IN_ADVANCE", $paramDurationFrom, $paramDurationTill, FALSE, "");
    }

    /**
     * DIFFERENT DISCOUNTS FOR DIFFERENT ITEMS IN SPECIFIC PERIOD FROM-TO
     * DEPTH: 2
     * @param string $paramDiscountType - "BOOKING_DURATION" or "BOOKING_IN_ADVANCE"
     * @param int $paramPeriodFrom
     * @param int $paramPeriodTill
     * @param bool $showRowNumbers
     * @param string $rowNumbersPrefix
     * @return string
     */
    private function getAdminDiscountElementListByPeriodFromTo($paramDiscountType = "BOOKING_DURATION", $paramPeriodFrom, $paramPeriodTill, $showRowNumbers=FALSE, $rowNumbersPrefix="0.")
    {
        $discountList = '';
        $validPeriodFrom = NRSValidator::isInteger($paramPeriodFrom) ? intval($paramPeriodFrom) : 0;
        $validPeriodTill = NRSValidator::isInteger($paramPeriodTill) ? intval($paramPeriodTill) : 0;
        $validDiscountType = $paramDiscountType == "BOOKING_IN_ADVANCE" ? 2 : 1;

        $rows = $this->internalWPDB->get_results("
            SELECT d.discount_id, d.item_id, d.discount_percentage
            FROM {$this->nrsPrefix}discounts d
            LEFT JOIN {$this->nrsPrefix}items it ON it.item_id=d.item_id
            LEFT JOIN {$this->nrsPrefix}manufacturers mf ON mf.manufacturer_id=it.manufacturer_id
            WHERE d.period_from='{$validPeriodFrom}' AND d.period_till='{$validPeriodTill}' AND d.item_id!='0' AND d.extra_id='0'
            AND d.discount_type='{$validDiscountType}'
            ORDER BY mf.manufacturer_title, it.model_name ASC
        ", ARRAY_A);

        $i = 0;
        foreach($rows AS $row)
        {
            $i++;
            $objItem = new NRSItem($this->internalWPDB, $this->nrsPrefix, $this->lang, $row['item_id']);
            $itemDetails = $objItem->getFullDetails();
            $itemModelName = "";
            $manufacturerTitle = "";
            $bodyTypeTitle = "";
            $transmissionTypeTitle = "";
            if(!is_null($itemDetails))
            {
                $itemModelName = $itemDetails['model_name'];
                $manufacturerTitle = $itemDetails['manufacturer_title'];
                $bodyTypeTitle = $itemDetails['body_type_title'];
                $transmissionTypeTitle = $itemDetails['transmission_type_title'];
            }

            $printDurationFrom = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $validPeriodFrom);
            $printDurationTill = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $validPeriodTill);

            // HTML OUTPUT
            $discountList .= '<tr>';
            if($showRowNumbers)
            {
                $discountList .= '<td>'.$rowNumbersPrefix.sprintf('%02d', $i).'</td>';
            }
            $discountList .= '<td>'.$manufacturerTitle.' '.$itemModelName.'</td>';
            $discountList .= '<td>ID: '.$row['item_id'].', '.$bodyTypeTitle.', '.$transmissionTypeTitle.'</td>';
            if($this->areDiscountsEnabled())
            {
                $discountList .= '<td>'.$row['discount_percentage'].' % ';
                $discountList .= '<strong>('.$printDurationFrom.' - '.$printDurationTill.')</strong>';
                $discountList .= '</td>';
            }
            $discountList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-discount&amp;discount_type='.$validDiscountType.'&amp;discount_id='.$row['discount_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
            $discountList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-discount-manager&amp;discount_type='.$validDiscountType.'&amp;delete_discount='.$row['discount_id'].'&amp;noheader=true').'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a></td>';
            $discountList .= '</tr>';
        }

        return  $discountList;
    }
}