<?php
/**
 * Item Prepayment Manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemPrepaymentManager extends NRSPrepaymentManager implements iNRSPrepaymentManager
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramElementId, $paramOptionalConfig = array())
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId, $paramOptionalConfig);
	}

	/**
	 * Get deposit percent
	 * @param int $paramPeriodInSeconds
	 * @return int
	 */
	public function getPrepaymentPercentageByPeriod($paramPeriodInSeconds)
	{
		// 0 is OK to return. System has a great logic. There is no 'hacks' needed for that if we do it in the right way.
		$prepaymentPercentage = 0;
		if($this->prepaymentEnabled)
		{
			$validBookingDurationInSeconds = NRSValidator::getValidInteger($paramPeriodInSeconds, 0);
			// We use float here, because we want to have duration of hours and minutes, not just days. So day will be divided by 24 / 60

			$validItemId = NRSValidator::getValidInteger($this->elementId, 0);

			// SPEED OPTIMIZATION NOTE: it is IMPORTANT to keep the WHERE columns in period_from, period_till order to speed up SQL search,
			// because we have an INDEX in database called 'period (period_from, period_to)'.
			$sqlForZeroOrBiggerValue = "
			  	SELECT prepayment_percentage
			  	FROM {$this->nrsPrefix}prepayments
			  	WHERE item_id='{$validItemId}' AND '{$validBookingDurationInSeconds}' BETWEEN period_from AND period_till
			";
			$sqlForZeroValueOnly = "
			  	SELECT prepayment_percentage
			  	FROM {$this->nrsPrefix}prepayments
			  	WHERE item_id='0' AND '{$validBookingDurationInSeconds}' BETWEEN period_from AND period_till
			";

			if($this->debugMode == 2)
			{
				// Deep debug:
				echo "<br />";
				echo "<br /><strong>SQL</strong> Item prepayment for ZERO or bigger item id value: ".nl2br($sqlForZeroOrBiggerValue);
				echo "<br /><strong>SQL</strong> Item prepayment for ZERO item id ONLY: ".nl2br($sqlForZeroValueOnly);
			}

			$rowZeroOrBigger = $this->internalWPDB->get_row($sqlForZeroOrBiggerValue, ARRAY_A);
			if(!is_null($rowZeroOrBigger))
			{
				// Use different deposits for each item (unless 0 was passed, than it will return default here)
				$prepaymentPercentage = $rowZeroOrBigger['prepayment_percentage'];
			} else if($validItemId > 0)
			{
				// SPEED OPTIMIZATION NOTE: For better system speed - do not move the get_row line out of THIS ELSE SCOPE!
				$rowZeroOnly = $this->internalWPDB->get_row($sqlForZeroValueOnly, ARRAY_A);
				if(!is_null($rowZeroOnly))
				{
					// Use same deposits for all items
					$prepaymentPercentage = $rowZeroOnly['prepayment_percentage'];
				}
			}
		}

		return $prepaymentPercentage;
	}

	/**
	 * @return int
	 */
	public function getMinimalPrepaymentPercentage()
	{
		// For extras there are no min or max prepayment percentages - only one, which can be 0.00 or not
		$fixedRentalDeposit = 0;

		if($this->prepaymentEnabled)
		{
			$validItemId = NRSValidator::getValidInteger($this->elementId, 0);

			$sqlForZeroOrBiggerValue = "
			  	SELECT prepayment_percentage
			  	FROM {$this->nrsPrefix}prepayments
			  	WHERE item_id='{$validItemId}'
			  	ORDER BY prepayment_percentage ASC
			";
			$sqlForZeroValueOnly = "
			  	SELECT prepayment_percentage
			  	FROM {$this->nrsPrefix}prepayments
			  	WHERE item_id='0'
			  	ORDER BY prepayment_percentage ASC
			";

			$rowZeroOrBigger = $this->internalWPDB->get_row($sqlForZeroOrBiggerValue, ARRAY_A);
			if(!is_null($rowZeroOrBigger))
			{
				// Use different prepayment percentages for each item (unless 0 was passed, than it will return default here)
				$fixedRentalDeposit = $rowZeroOrBigger['prepayment_percentage'];
			} else if($validItemId > 0)
			{
				$rowZeroOnly = $this->internalWPDB->get_row($sqlForZeroValueOnly, ARRAY_A);
				if(!is_null($rowZeroOnly))
				{
					// Use same prepayment percentages for all items
					$fixedRentalDeposit = $rowZeroOnly['prepayment_percentage'];
				}
			}
		}

		return $fixedRentalDeposit;
	}
}
