<?php
/**
 * NRS Item Prepayments Observer (no setup for single item)
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemPrepaymentsObserver extends NRSPrepaymentsObserver implements iNRSPrepaymentsObserver
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang)
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang);
	}

	/**
	 * DIFFERENT PREPAYMENTS FOR DIFFERENT ITEMS
	 * DEPTH: 1
	 * @param bool $showRowNumbers
	 * @return string
	 */
	public function getAdminDifferentPrepaymentDurationGroups($showRowNumbers = FALSE)
	{
		$prepaymentList = '';

		$sqlQuery = "
          SELECT prepayment_id, item_id, period_from, period_till, prepayment_percentage
          FROM {$this->nrsPrefix}prepayments
          GROUP BY period_from, period_till
          ORDER BY period_from ASC, period_till ASC
        ";
		$rows = $this->internalWPDB->get_results($sqlQuery, ARRAY_A);

		if(sizeof($rows) > 0)
		{
			$i = 0;
			foreach($rows AS $row)
			{
				$i++;
				$printDurationFrom = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $row['period_from']);
				$printDurationTill = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $row['period_till']);

				// HTML OUTPUT
				$prepaymentList .= '<tr>';
				if($showRowNumbers)
				{
					$prepaymentList .= '<td>'.sprintf('%02d', $i).'</td>';
				}
				$prepaymentList .= '<td><strong>'.$printDurationFrom.'</strong></td>';
				$prepaymentList .= '<td><strong>'.$printDurationTill.'</strong></td>';
				if($this->arePrepaymentsEnabled())
				{
					$prepaymentList .= $row['item_id'] > 0 ? '<td>&nbsp;</td>' : '<td>'.$row['prepayment_percentage'].' %</td>';
				}
				if($row['item_id'] == 0)
				{
					// Default prepayment applied for all items
					$prepaymentList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-prepayment&amp;prepayment_id='.$row['prepayment_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
					$prepaymentList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-prices&amp;noheader=true&amp;delete_prepayment='.$row['prepayment_id']).'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a></td>';
				} else
				{
					$prepaymentList .= '<td>&nbsp;</td>';
				}
				$prepaymentList .= '</tr>';
				if($row['item_id'] > 0)
				{
					$prepaymentList .= $this->getAdminDurationPrepaymentListByPeriodFromTo($row['period_from'], $row['period_till'], $showRowNumbers, sprintf('%02d', $i).".");
				}
			}
		}
		return  $prepaymentList;
	}

	/**
	 * DIFFERENT PREPAYMENTS FOR DIFFERENT ITEMS IN SPECIFIC PERIOD FROM-TO
	 * DEPTH: 2
	 * @param $paramPeriodFrom
	 * @param $paramPeriodTill
	 * @param bool $showRowNumbers
	 * @param string $rowNumbersPrefix
	 * @return string
	 */
	public function getAdminDurationPrepaymentListByPeriodFromTo($paramPeriodFrom, $paramPeriodTill, $showRowNumbers=FALSE, $rowNumbersPrefix="0.")
	{
		$prepaymentList = '';
		$validPeriodFrom = NRSValidator::isInteger($paramPeriodFrom) ? intval($paramPeriodFrom) : 0;
		$validPeriodTill = NRSValidator::isInteger($paramPeriodTill) ? intval($paramPeriodTill) : 0;

		$rows = $this->internalWPDB->get_results("
          SELECT prepayment_id, item_id, prepayment_percentage
          FROM {$this->nrsPrefix}prepayments
          WHERE item_id!='0' AND period_from='{$validPeriodFrom}' AND period_till='{$validPeriodTill}'
          ORDER BY period_from ASC, period_till ASC
          ", ARRAY_A);
		if(sizeof($rows) > 0)
		{
			$i = 0;
			foreach($rows AS $row)
			{
				$i++;
				$objItem = new NRSItem($this->internalWPDB, $this->nrsPrefix, $this->lang, $row['item_id']);
				$itemDetails = $objItem->getFullDetails();
				$itemModelName = "";
				$manufacturerTitle = "";
				$bodyTypeTitle = "";
				$transmissionTypeTitle = "";
				if(!is_null($itemDetails))
				{
					$itemModelName = $itemDetails['model_name'];
					$manufacturerTitle = $itemDetails['manufacturer_title'];
					$bodyTypeTitle = $itemDetails['body_type_title'];
					$transmissionTypeTitle = $itemDetails['transmission_type_title'];
				}

                $printDurationFrom = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $validPeriodFrom);
                $printDurationTill = $this->lang->getPrintFloorDurationByPeriod($this->priceCalculationType, $validPeriodTill);

				// HTML OUTPUT
				$prepaymentList .= '<tr>';
				if($showRowNumbers)
				{
					$prepaymentList .= '<td>'.$rowNumbersPrefix.sprintf('%02d', $i).'</td>';
				}
				$prepaymentList .= '<td>'.$manufacturerTitle.' '.$itemModelName.'</td>';
				$prepaymentList .= '<td>ID: '.$row['item_id'].', '.$bodyTypeTitle.', '.$transmissionTypeTitle.'</td>';
				if($this->arePrepaymentsEnabled())
				{
					$prepaymentList .= '<td>'.$row['prepayment_percentage'].' % ';
                    $prepaymentList .= '<strong>('.$printDurationFrom.' - '.$printDurationTill.')</strong>';
                    $prepaymentList .= '</td>';
				}
				$prepaymentList .= '<td align="right"><a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-add-prepayment&amp;prepayment_id='.$row['prepayment_id']).'">'.$this->lang->getText('NRS_ADMIN_EDIT_TEXT').'</a> || ';
				$prepaymentList .= '<a href="'.admin_url('admin.php?page='.$GLOBALS['NRS_EXTENSION'].'-prices&amp;noheader=true&amp;delete_prepayment='.$row['prepayment_id']).'">'.$this->lang->getText('NRS_ADMIN_DELETE_TEXT').'</a></td>';
				$prepaymentList .= '</tr>';
			}
		}
		return  $prepaymentList;
	}
}