<?php
/**
 * Item Price Manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @uses NRSDepositManager, NRSDiscountManager, NRSPrepaymentManager
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemPriceManager extends NRSPriceManager implements iNRSPriceManager
{
	public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramConfig, $paramElementId)
	{
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramConfig, $paramElementId);
	}

	/**
	 * Get's a car price for specified period of time without any VAT, and without discounts applied
	 * Moved out from search result of single element
	 * @param int $paramPickupTimestamp
	 * @param int $paramDropoffTimestamp
	 * @return int
	 */
	public function getUnitPriceByInterval($paramPickupTimestamp, $paramDropoffTimestamp)
	{
		$totalPrice 			= 0;
		$validItemId 			= NRSValidator::getValidInteger($this->elementId, 0);
		$validPickupTimestamp	= NRSValidator::getValidInteger($paramPickupTimestamp, 0);
		$validDropoffTimestamp	= NRSValidator::getValidInteger($paramDropoffTimestamp, 0);

		if($this->priceCalculationType == 1)
		{
			// Price by days only
			$arrDateRangeTimestamps = NRSValidator::getDateRangeTimestampArray($validPickupTimestamp, $validDropoffTimestamp);
			foreach($arrDateRangeTimestamps AS $currentDateTimestamp)
			{
				$validCurrentDateTimestamp = NRSValidator::getValidInteger($currentDateTimestamp);
				$currentDayOfWeekSqlField = strtolower(date('D', $validCurrentDateTimestamp + get_option( 'gmt_offset' ) * 3600));

				// Seasonal price SQL
				$sqlSeasonalPrice ="
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='1' AND price_type='1'
						AND ('{$validCurrentDateTimestamp}' BETWEEN start_timestamp AND end_timestamp)
					";
				// Default price SQL
				$sqlRegularPrice = "
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='0' AND price_type='1'
					";

				// Query for seasonal prices
				$seasonalPriceData = $this->internalWPDB->get_row($sqlSeasonalPrice, ARRAY_A);

				if(!is_null($seasonalPriceData))
				{
					$totalPrice += $seasonalPriceData['price_today'];
				} else
                {
                    // SPEED OPTIMIZATION NOTE: For better system speed - do not move the get_row line out of THIS ELSE SCOPE!
                    $regularPriceData = $this->internalWPDB->get_row($sqlRegularPrice, ARRAY_A);
                    if(!is_null($regularPriceData))
                    {
                        // Query for regular prices
                        $totalPrice += $regularPriceData['price_today'];
                    }
                }

				if($this->debugMode)
				{
					echo "<br />-&gt;  Item Id: {$validItemId} , ";
					echo "Weekday: {$currentDayOfWeekSqlField}, ";
					echo "Local Date: ".date("Y-m-d", $currentDateTimestamp + get_option('gmt_offset') * 3600)." (Unix, GMT: {$currentDateTimestamp}), ";
					echo "Price w/o VAT (seasonal): ".(isset($seasonalPriceData['price_today']) ? $seasonalPriceData['price_today'] : "N/A").", ";
					echo "Price w/o VAT: ".(isset($regularPriceData['price_today']) ? $regularPriceData['price_today'] : "N/A");
				}
			}

		} elseif($this->priceCalculationType == 2)
		{
			// Price by hours
			$arrHourRangeTimestamps = NRSValidator::getHourRangeTimestampArray($validPickupTimestamp, $validDropoffTimestamp);
			foreach($arrHourRangeTimestamps AS $currentHourTimestamp)
			{
				$validCurrentHourTimestamp = NRSValidator::getValidInteger($currentHourTimestamp);
				$currentDayOfWeekSqlField = strtolower(date('D', $validCurrentHourTimestamp + get_option( 'gmt_offset' ) * 3600));

				// Seasonal price SQL
				$sqlSeasonalPrice ="
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='1' AND price_type='2'
						AND ('{$validCurrentHourTimestamp}' BETWEEN start_timestamp AND end_timestamp)
					";
				// Default price SQL
				$sqlRegularPrice = "
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='0' AND price_type='2'
					";

				// Query for seasonal prices
				$seasonalPriceData = $this->internalWPDB->get_row($sqlSeasonalPrice, ARRAY_A);
				// Query for regular prices
				$regularPriceData = $this->internalWPDB->get_row($sqlRegularPrice, ARRAY_A);
				if(!is_null($seasonalPriceData))
				{
					$totalPrice += $seasonalPriceData['price_today'];
				} else if(!is_null($regularPriceData))
				{
					$totalPrice += $regularPriceData['price_today'];
				}

				if($this->debugMode)
				{
					echo "-&gt;  Item Id: {$validItemId} , ";
					echo "Day of Week: {$currentDayOfWeekSqlField}, ";
					echo "Local Date/Hour: ".date("Y-m-d H:i:s", $validCurrentHourTimestamp + get_option( 'gmt_offset' ) * 3600)." (Unix, GMT: {$validCurrentHourTimestamp}), ";
					echo "Price w/o VAT (seasonal): ".(isset($seasonalPriceData['price_today']) ? $seasonalPriceData['price_today'] : "Not exist").", ";
					echo "Price w/o VAT (regular): ".(isset($regularPriceData['price_today']) ? $regularPriceData['price_today'] : "Not exist")."<br />";
				}
			}

		} elseif($this->priceCalculationType == 3)
		{
			// Combined - price by days & hours

			/************************************************************************************/
			// A - Count price for all days except last one
			$arrDateAndHourRangeTimestamps = NRSValidator::getDayRangeAndHourRangeTimestampArray($validPickupTimestamp, $validDropoffTimestamp);

			foreach($arrDateAndHourRangeTimestamps['days'] AS $currentDateTimestamp)
			{
				$validCurrentDateTimestamp = NRSValidator::getValidInteger($currentDateTimestamp);
				$currentDayOfWeekSqlField = strtolower(date('D', $validCurrentDateTimestamp + get_option( 'gmt_offset' ) * 3600));

				// Seasonal price SQL
				$sqlSeasonalPrice ="
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='1' AND price_type='1'
						AND ('{$validCurrentDateTimestamp}' BETWEEN start_timestamp AND end_timestamp)
					";
				// Default price SQL
				$sqlRegularPrice = "
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='0' AND price_type='1'
					";

				// Query for seasonal prices
				$seasonalPriceData = $this->internalWPDB->get_row($sqlSeasonalPrice, ARRAY_A);
				// Query for regular prices
				$regularPriceData = $this->internalWPDB->get_row($sqlRegularPrice, ARRAY_A);
				if(!is_null($seasonalPriceData))
				{
					$totalPrice += $seasonalPriceData['price_today'];
				} else if(!is_null($regularPriceData))
				{
					$totalPrice += $regularPriceData['price_today'];
				}

				if($this->debugMode)
				{
					echo "-&gt;  Item Id: {$validItemId} , ";
					echo "Day of Week: {$currentDayOfWeekSqlField}, ";
					echo "Local Date: ".date("Y-m-d", $currentDateTimestamp + get_option( 'gmt_offset' ) * 3600)." (Unix, GMT: {$currentDateTimestamp}), ";
					echo "Price w/o VAT (seasonal): ".(isset($seasonalPriceData['price_today']) ? $seasonalPriceData['price_today'] : "Not exist").", ";
					echo "Price w/o VAT (regular): ".(isset($regularPriceData['price_today']) ? $regularPriceData['price_today'] : "Not exist")."<br />";
				}
			}

			/************************************************************************************/
			// B - Count the whole day price for last day by using daily price (0th item is existing for sure)
			$totalPriceForLastDayByDailyPrice = 0;
			if(isset($arrDateAndHourRangeTimestamps['hours'][0]))
			{
				$validLastDateTimestamp = NRSValidator::getValidInteger($arrDateAndHourRangeTimestamps['hours'][0]);
				$lastDateDayOfWeekSqlField = strtolower(date('D', $validLastDateTimestamp + get_option( 'gmt_offset' ) * 3600));

				// Seasonal price SQL
				$sqlSeasonalPrice ="
						SELECT {$lastDateDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='1' AND price_type='1'
						AND ('{$validLastDateTimestamp}' BETWEEN start_timestamp AND end_timestamp)
					";
				// Default price SQL
				$sqlRegularPrice = "
						SELECT {$lastDateDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='0' AND price_type='1'
					";

				// Query for seasonal prices
				$seasonalPriceData = $this->internalWPDB->get_row($sqlSeasonalPrice, ARRAY_A);
				// Query for regular prices
				$regularPriceData = $this->internalWPDB->get_row($sqlRegularPrice, ARRAY_A);
				if(!is_null($seasonalPriceData))
				{
					$totalPriceForLastDayByDailyPrice = $seasonalPriceData['price_today'];
				} else if(!is_null($regularPriceData))
				{
					$totalPriceForLastDayByDailyPrice = $regularPriceData['price_today'];
				}
			}

			/************************************************************************************/
			// C - Count price for all hours on last day
			$totalPriceForLastDayByHourlyPrice = 0;
			foreach($arrDateAndHourRangeTimestamps['hours'] AS $currentHourTimestamp)
			{
				$validCurrentHourTimestamp = NRSValidator::getValidInteger($currentHourTimestamp);
				$currentDayOfWeekSqlField = strtolower(date('D', $validCurrentHourTimestamp + get_option( 'gmt_offset' ) * 3600));

				// Seasonal price SQL
				$sqlSeasonalPrice ="
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='1' AND price_type='2'
						AND ('{$validCurrentHourTimestamp}' BETWEEN start_timestamp AND end_timestamp)
					";
				// Default price SQL
				$sqlRegularPrice = "
						SELECT {$currentDayOfWeekSqlField} AS price_today
						FROM {$this->nrsPrefix}price_plans
						WHERE item_id='{$validItemId}' AND seasonal_price='0' AND price_type='2'
					";

				// Query for seasonal prices
				$seasonalPriceData = $this->internalWPDB->get_row($sqlSeasonalPrice, ARRAY_A);
				// Query for regular prices
				$regularPriceData = $this->internalWPDB->get_row($sqlRegularPrice, ARRAY_A);
				if(!is_null($seasonalPriceData))
				{
					$totalPriceForLastDayByHourlyPrice += $seasonalPriceData['price_today'];
				} else if(!is_null($regularPriceData))
				{
					$totalPriceForLastDayByHourlyPrice += $regularPriceData['price_today'];
				}

				if($this->debugMode)
				{
					echo "-&gt;  Item Id: {$validItemId} , ";
					echo "Day of Week: {$currentDayOfWeekSqlField}, ";
					echo "Local Date/Hour: ".date("Y-m-d H:i:s", $validCurrentHourTimestamp + get_option( 'gmt_offset' ) * 3600)." (Unix, GMT: {$validCurrentHourTimestamp}), ";
					echo "Price w/o VAT (seasonal): ".(isset($seasonalPriceData['price_today']) ? $seasonalPriceData['price_today'] : "Not exist").", ";
					echo "Price w/o VAT (regular): ".(isset($regularPriceData['price_today']) ? $regularPriceData['price_today'] : "Not exist")."<br />";
				}
			}

			/************************************************************************************/
			// D - Add either all hours price or all day price, whichever is cheaper
			if($totalPriceForLastDayByHourlyPrice > $totalPriceForLastDayByDailyPrice)
			{
				// Add whole day price
				$totalPrice += $totalPriceForLastDayByDailyPrice;
			} else
			{
				// Add hours price
				$totalPrice += $totalPriceForLastDayByHourlyPrice;
			}
		}

		return $totalPrice;
	}

	public function getUnitPriceDetailsByInterval($paramPickupTimestamp, $paramDropoffTimestamp)
	{
		return $this->getPriceDetails($paramPickupTimestamp, $paramDropoffTimestamp, 1, FALSE, FALSE);
	}

	public function getMultipliedPriceDetailsByInterval($paramPickupTimestamp, $paramDropoffTimestamp, $paramMultiplier)
	{
		return $this->getPriceDetails($paramPickupTimestamp, $paramDropoffTimestamp, $paramMultiplier, FALSE, FALSE);
	}

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getBasicWeekCheapestDayMinimalPriceDetails()
    {
        return $this->getWeekCheapestDayMinimalPriceDetails(TRUE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getFullWeekCheapestDayMinimalPriceDetails()
    {
        return $this->getWeekCheapestDayMinimalPriceDetails(FALSE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getBasicWeekPriciestDayMinimalPriceDetails()
    {
        return $this->getWeekPriciestDayMinimalPriceDetails(TRUE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     */
    public function getFullWeekPriciestDayMinimalPriceDetails()
    {
        return $this->getWeekPriciestDayMinimalPriceDetails(FALSE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     * SQL optimized method
     */
    public function getBasicWeekMinimalPriceDetails()
    {
        return $this->getWeekMinimalPriceDetails(TRUE);
    }

    /**
     * NOTE: FASTEST METHOD - does not include deposit and prepayment details
     * SQL optimized method
     */
    public function getFullWeekMinimalPriceDetails()
    {
        return $this->getWeekMinimalPriceDetails(FALSE);
    }

    /**
     * NOTE 1: FASTEST METHOD - does not include deposit and prepayment details
     * NOTE 2: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getWeekMinimalPriceDetails() method
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return mixed
     */
    private function getWeekCheapestDayMinimalPriceDetails($paramBasicDetails = FALSE)
	{
		$localPickupTimestamp = time() + get_option( 'gmt_offset' ) * 3600;
		$localDropoffTimestamp = ($this->priceCalculationType == "2" ? time()+3600 : time()+86400) + get_option( 'gmt_offset' ) * 3600;

        $arrPricesDetails = array(
          0 => $this->getPriceDetails($localPickupTimestamp, $localDropoffTimestamp, 1, TRUE, $paramBasicDetails),
          1 => $this->getPriceDetails($localPickupTimestamp + 86400*1, $localDropoffTimestamp + 86400*1, 1, TRUE, $paramBasicDetails),
          2 => $this->getPriceDetails($localPickupTimestamp + 86400*2, $localDropoffTimestamp + 86400*2, 1, TRUE, $paramBasicDetails),
          3 => $this->getPriceDetails($localPickupTimestamp + 86400*3, $localDropoffTimestamp + 86400*3, 1, TRUE, $paramBasicDetails),
          4 => $this->getPriceDetails($localPickupTimestamp + 86400*4, $localDropoffTimestamp + 86400*4, 1, TRUE, $paramBasicDetails),
          5 => $this->getPriceDetails($localPickupTimestamp + 86400*5, $localDropoffTimestamp + 86400*5, 1, TRUE, $paramBasicDetails),
          6 => $this->getPriceDetails($localPickupTimestamp + 86400*6, $localDropoffTimestamp + 86400*6, 1, TRUE, $paramBasicDetails),
        );

        $arrPrices = array(
            0 => $arrPricesDetails[0]['unit']['subtotal_price_dynamic'],
            1 => $arrPricesDetails[1]['unit']['subtotal_price_dynamic'],
            2 => $arrPricesDetails[2]['unit']['subtotal_price_dynamic'],
            3 => $arrPricesDetails[3]['unit']['subtotal_price_dynamic'],
            4 => $arrPricesDetails[4]['unit']['subtotal_price_dynamic'],
            5 => $arrPricesDetails[5]['unit']['subtotal_price_dynamic'],
            6 => $arrPricesDetails[6]['unit']['subtotal_price_dynamic'],
        );

        $minPriceIds = array_keys($arrPrices, min($arrPrices));
        $minPriceDetails = $arrPricesDetails[$minPriceIds[0]];

		return $minPriceDetails;
	}

    /**
     * NOTE 1: FASTEST METHOD - does not include deposit and prepayment details
     * NOTE 2: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getWeekMinimalPriceDetails() method
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return array
     */
    private function getWeekPriciestDayMinimalPriceDetails($paramBasicDetails = FALSE)
	{
		$localPickupTimestamp = time() + get_option( 'gmt_offset' ) * 3600;
		$localDropoffTimestamp = ($this->priceCalculationType == "2" ? time()+3600 : time()+86400) + get_option( 'gmt_offset' ) * 3600;

        $arrPricesDetails = array(
            0 => $this->getPriceDetails($localPickupTimestamp, $localDropoffTimestamp, 1, TRUE, $paramBasicDetails),
            1 => $this->getPriceDetails($localPickupTimestamp + 86400*1, $localDropoffTimestamp + 86400*1, 1, TRUE, $paramBasicDetails),
            2 => $this->getPriceDetails($localPickupTimestamp + 86400*2, $localDropoffTimestamp + 86400*2, 1, TRUE, $paramBasicDetails),
            3 => $this->getPriceDetails($localPickupTimestamp + 86400*3, $localDropoffTimestamp + 86400*3, 1, TRUE, $paramBasicDetails),
            4 => $this->getPriceDetails($localPickupTimestamp + 86400*4, $localDropoffTimestamp + 86400*4, 1, TRUE, $paramBasicDetails),
            5 => $this->getPriceDetails($localPickupTimestamp + 86400*5, $localDropoffTimestamp + 86400*5, 1, TRUE, $paramBasicDetails),
            6 => $this->getPriceDetails($localPickupTimestamp + 86400*6, $localDropoffTimestamp + 86400*6, 1, TRUE, $paramBasicDetails),
        );

        $arrPrices = array(
            0 => $arrPricesDetails[0]['unit']['subtotal_price_dynamic'],
            1 => $arrPricesDetails[1]['unit']['subtotal_price_dynamic'],
            2 => $arrPricesDetails[2]['unit']['subtotal_price_dynamic'],
            3 => $arrPricesDetails[3]['unit']['subtotal_price_dynamic'],
            4 => $arrPricesDetails[4]['unit']['subtotal_price_dynamic'],
            5 => $arrPricesDetails[5]['unit']['subtotal_price_dynamic'],
            6 => $arrPricesDetails[6]['unit']['subtotal_price_dynamic'],
        );

        $maxPriceIds = array_keys($arrPrices, max($arrPrices));
        $maxPriceDetails = $arrPricesDetails[$maxPriceIds[0]];

        return $maxPriceDetails;
	}

    /**
     * SQL optimized method
     * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
     * @return array
     */
    private function getWeekMinimalPriceDetails($paramBasicDetails = FALSE)
    {
        $localPickupTimestamp = time() + get_option( 'gmt_offset' ) * 3600;
        $localDropoffTimestamp = ($this->priceCalculationType == "2" ? time()+3600 : time()+86400) + get_option( 'gmt_offset' ) * 3600;

        $arrPricesDetails = array(
            0 => $this->getPriceDetails($localPickupTimestamp, $localDropoffTimestamp, 1, TRUE, $paramBasicDetails),
            1 => $this->getPriceDetails($localPickupTimestamp + 86400*1, $localDropoffTimestamp + 86400*1, 1, TRUE, $paramBasicDetails),
            2 => $this->getPriceDetails($localPickupTimestamp + 86400*2, $localDropoffTimestamp + 86400*2, 1, TRUE, $paramBasicDetails),
            3 => $this->getPriceDetails($localPickupTimestamp + 86400*3, $localDropoffTimestamp + 86400*3, 1, TRUE, $paramBasicDetails),
            4 => $this->getPriceDetails($localPickupTimestamp + 86400*4, $localDropoffTimestamp + 86400*4, 1, TRUE, $paramBasicDetails),
            5 => $this->getPriceDetails($localPickupTimestamp + 86400*5, $localDropoffTimestamp + 86400*5, 1, TRUE, $paramBasicDetails),
            6 => $this->getPriceDetails($localPickupTimestamp + 86400*6, $localDropoffTimestamp + 86400*6, 1, TRUE, $paramBasicDetails),
        );

        $arrPrices = array(
            0 => $arrPricesDetails[0]['unit']['subtotal_price_dynamic'],
            1 => $arrPricesDetails[1]['unit']['subtotal_price_dynamic'],
            2 => $arrPricesDetails[2]['unit']['subtotal_price_dynamic'],
            3 => $arrPricesDetails[3]['unit']['subtotal_price_dynamic'],
            4 => $arrPricesDetails[4]['unit']['subtotal_price_dynamic'],
            5 => $arrPricesDetails[5]['unit']['subtotal_price_dynamic'],
            6 => $arrPricesDetails[6]['unit']['subtotal_price_dynamic'],
        );

        $minPriceIds = array_keys($arrPrices, min($arrPrices));
        $minPriceDetails = $arrPricesDetails[$minPriceIds[0]];

        $maxPriceIds = array_keys($arrPrices, max($arrPrices));
        $maxPriceDetails = $arrPricesDetails[$maxPriceIds[0]];

        $minimalPriceDetails = array(
            "cheapest_day" => $minPriceDetails,
            "priciest_day" => $maxPriceDetails,
        );

        return $minimalPriceDetails;
    }


	/**
	 * Most advanced item pricing function EVER. Final
	 * @param int $paramPickupTimestamp
	 * @param int $paramDropoffTimestamp
	 * @param int $paramMultiplier - how many times multiply price for ['multiplied'] stack
	 * @param bool $paramMinimalPrice - should be use a minimal price instead of period
	 * @param bool $paramBasicDetails - for SQL optimization, do not include deposits and prepayments details when we don't need that
	 * @return array
	 */
	private function getPriceDetails($paramPickupTimestamp, $paramDropoffTimestamp, $paramMultiplier = 1, $paramMinimalPrice = FALSE, $paramBasicDetails = FALSE)
	{
		// 0. Car Id

		// 1: Single Car Subtotal (W/out VAT & w/out Discount)				= I.e. 100 EUR (4x25 EUR Daily Price)      / getPriceByPeriod()
		// --> 1A: Single Car Subtotal (With VAT)
		// --> 1B: Single Car Subtotal (Dynamic - with or w/out VAT)
		// 2: Single Car Discount Percentage      							= I.e. 10%                                 / getTotalDiscountPercentageByPeriod()
		// 3: Single Car Discount Amount (W/out VAT)	 					= I.e. 10 EUR (100 EUR * 10%)
		// --> 3A: Single Car Discount Amount (With VAT)
		// --> 3B: Single Car Discount Amount (Dynamic - with or w/out VAT)
		// 4: Single Car Discounted Total (W/out VAT)     					= I.e. 90 EUR (100 EUR - 10%)
		// --> 4A: Single Car Discounted Total (With VAT)					= I.e. 108.90 EUR (90 EUR + 18.90 EUR)
		// --> 4B: Single Car Discounted Total (Dynamic - with or w/out VAT)
		// 5: Single Car VAT Percentage (Tax)            					= I.e. 21%                                 / VARIABLE: this->vatPercentage
		// 6: Single Car Subtotal VAT Amount (Tax)          				= I.e. 21 EUR (100 EUR * VAT_PERCENTAGE)
		// 7: Single Car Discounted VAT Amount (Tax) 						= I.e. 18.90 EUR (90 EUR * VAT_PERCENTAGE)
		// 9: Single Car Prepayment Percentage              					= I.e. 100%                                / getPrepaymentPercentageByPeriod()
		// 10: Single Car Prepayment Amount (W/out VAT)        				= I.e. 90 EUR (90 EUR * PREPAYMENT_PERCENTAGE)
		// --> 10A: Single Car Prepayment Amount (With VAT)					= I.e. 108.90 EUR (108.90 EUR * PREPAYMENT_PERCENTAGE)
		// --> 10B: Single Car Prepayment Amount (Dynamic - with or w/out VAT)
		// 11: Single Car Fixed Deposit Amount (No VAT Exist)				= I.e. 250 EUR 						       / getFixedDepositAmountByPeriod()

        if($this->debugMode == 2)
        {
            echo "<br />---------------------------------------------------------------------------------------------------------";
        }

		// Part 1:  Valid Item Id
		$validItemId 						= NRSValidator::getValidInteger($this->elementId, 0);
		$validPickupTimestamp				= NRSValidator::getValidInteger($paramPickupTimestamp, 0);
		$validDropoffTimestamp				= NRSValidator::getValidInteger($paramDropoffTimestamp, 0);
        $validPeriodUntilPickup				= NRSValidator::getPeriod(time(), $validPickupTimestamp, FALSE);
        $validPeriod						= NRSValidator::getPeriod($validPickupTimestamp, $validDropoffTimestamp, FALSE);
        $validPeriodUntilPickupByPriceType  = 0;
        $validPeriodByPriceType             = 0;
		$validMultiplier					= NRSValidator::getValidInteger($paramMultiplier, 1);

        // Part 2: Periods by Price type
        // For period until pickup we need to floor days or hours depending on the mode
        // For Booking duration we need to ceil days or hours depending on the mode
        if($this->priceCalculationType == 1)
        {
            // Price by days
            $daysUntilPickup                = NRSValidator::getFloorDaysFromSeconds($validPeriodUntilPickup);
            $validPeriodUntilPickupByPriceType = $daysUntilPickup * 86400;

            $bookingDurationInDays          = NRSValidator::getCeilDaysFromSeconds($validPeriod);
            $validPeriodByPriceType         = $bookingDurationInDays * 86400;
        } else if($this->priceCalculationType == 2)
        {
            // Price by hours
            $hoursUntilPickup               = NRSValidator::getCeilHoursFromSeconds($validPeriodUntilPickup);
            $validPeriodUntilPickupByPriceType = $hoursUntilPickup * 3600;

            $bookingDurationInHours         = NRSValidator::getCeilHoursFromSeconds($validPeriod);
            $validPeriodByPriceType         = $bookingDurationInHours * 3600;
        } else if($this->priceCalculationType == 3)
        {
            // Mixed price by days and hours
            $daysAndHoursUntilPickup        = NRSValidator::getFloorDaysAndFloorHoursFromSeconds($validPeriodUntilPickup);
            $validPeriodUntilPickupByPriceType = $daysAndHoursUntilPickup['days'] * 86400 + $daysAndHoursUntilPickup['hours'] * 3600;

            $bookingDurationInDaysAndHours  = NRSValidator::getFloorDaysAndCeilHoursFromSeconds($validPeriod);
            $validPeriodByPriceType         = $bookingDurationInDaysAndHours['days'] * 86400 + $bookingDurationInDaysAndHours['hours'] * 3600;
        }


		// Part 3: Car Prices
		// 1, 1A, 1B - Single Car Subtotal (W/out VAT), (With VAT),(Dynamic - with or w/out VAT)
		$unitSubtotalPriceWithoutVAT  		= $this->getUnitPriceByInterval($validPickupTimestamp, $validDropoffTimestamp);
		$unitSubtotalPriceWithVAT 	 		= $unitSubtotalPriceWithoutVAT * (1 + $this->vatPercentage / 100);
		$unitSubtotalPriceDynamic 	 		= $this->showPricesWithVAT == "1" ? $unitSubtotalPriceWithVAT : $unitSubtotalPriceWithoutVAT;

		// 2 - Single Car Discount Percentage
		$objDiscountManager = new NRSItemDiscountManager($this->internalWPDB, $this->nrsPrefix, $this->lang, $validItemId, $this->savedConfig);
		if($paramMinimalPrice == TRUE)
		{
			$unitDiscountPercentage 		= $objDiscountManager->getMaxTotalDiscountPercentage();
		} else
		{
			$unitDiscountPercentage			= $objDiscountManager->getTotalDiscountPercentageByPeriod($validPeriodUntilPickupByPriceType, $validPeriodByPriceType);
		}

		// 3, 3A, 3B - Single Car Discount Amount (W/out VAT), (With VAT),(Dynamic - with or w/out VAT)
		$unitDiscountAmountWithoutVAT		= $unitSubtotalPriceWithoutVAT * ($unitDiscountPercentage / 100);
		$unitDiscountAmountWithVAT			= $unitDiscountAmountWithoutVAT + $unitDiscountAmountWithoutVAT * ($this->vatPercentage / 100);
		$unitDiscountAmountDynamic			= $this->showPricesWithVAT == "1" ? $unitDiscountAmountWithVAT : $unitDiscountAmountWithoutVAT;

		// 4, 4A, 4B - Single Car Discounted Total (W/out VAT), (With VAT),(Dynamic - with or w/out VAT)
		$unitDiscountedTotalWithoutVAT 		=  $unitSubtotalPriceWithoutVAT - $unitDiscountAmountWithoutVAT;
		$unitDiscountedTotalWithVAT    		=  $unitSubtotalPriceWithVAT - $unitDiscountAmountWithVAT;
		$unitDiscountedTotalDynamic			=  $unitSubtotalPriceDynamic - $unitDiscountAmountDynamic;

		// 5 - Single Car VAT Percentage (Tax)
		$unitVATPercentage 					= $this->vatPercentage;

		// 6 - Single Car Subtotal VAT Amount (Tax)
		$unitSubtotalVATAmount 	  			= $unitSubtotalPriceWithVAT - $unitSubtotalPriceWithoutVAT;

		// 7 - Single Car Discounted VAT Amount (Tax)
		$unitDiscountedVATAmount 			= $unitDiscountedTotalWithVAT - $unitDiscountedTotalWithoutVAT;

        // BASIC PRICE DETAILS
		$arrPriceDetails = array();
		$arrPriceDetails['element_id'] = $validItemId;
		$arrPriceDetails['element_type'] = "item";
		$arrPriceDetails['period'] = $validPeriod;
		$arrPriceDetails['unit'] = array(
			"subtotal_price" 			=> $unitSubtotalPriceWithoutVAT,
			"subtotal_price_with_vat" 	=> $unitSubtotalPriceWithVAT,
			"subtotal_price_dynamic" 	=> $unitSubtotalPriceDynamic,
			"discount_amount"			=> $unitDiscountAmountWithoutVAT,
			"discount_amount_with_vat"	=> $unitDiscountAmountWithVAT,
			"discount_amount_dynamic"	=> $unitDiscountAmountDynamic,
			"discounted_total"			=> $unitDiscountedTotalWithoutVAT,
			"discounted_total_with_vat" => $unitDiscountedTotalWithVAT,
			"discounted_total_dynamic"	=> $unitDiscountedTotalDynamic,
			"subtotal_vat_amount" 		=> $unitSubtotalVATAmount,
			"discounted_vat_amount" 	=> $unitDiscountedVATAmount,
		);
        $arrPriceDetails['percentage'] = array(
            "discount"					=> $unitDiscountPercentage,
            "vat" 						=> $unitVATPercentage,
        );

        if($paramBasicDetails == FALSE)
        {
            // FULL PRICE DETAILS: BASIC AND ADDITIONAL PRICE DETAILS
            // 9 - Single Car Prepayment Percentage
            $objPrepaymentManager = new NRSItemPrepaymentManager($this->internalWPDB, $this->nrsPrefix, $this->lang, $validItemId, $this->savedConfig);
            if($paramMinimalPrice == TRUE)
            {
                $unitPrepaymentPercentage 		= $objPrepaymentManager->getMinimalPrepaymentPercentage();
            } else
            {
                $unitPrepaymentPercentage 		= $objPrepaymentManager->getPrepaymentPercentageByPeriod($validPeriodByPriceType);
            }

            // 10 - Single Car Prepayment Amount (W/out VAT), (With VAT), (Dynamic - with or w/out VAT)
            $unitPrepaymentAmountWithoutVAT		= $unitDiscountedTotalWithoutVAT * ($unitPrepaymentPercentage / 100);
            $unitPrepaymentAmountWithVAT	    = $unitDiscountedTotalWithVAT * ($unitPrepaymentPercentage / 100);
            $unitPrepaymentAmountDynamic		= $this->showPricesWithVAT == "1" ? $unitPrepaymentAmountWithVAT : $unitPrepaymentAmountWithoutVAT;

            // 11 - Single Car Fixed Deposit Amount (VAT for deposit do not exist)
            $objDepositManager = new NRSItemDepositManager($this->internalWPDB, $this->nrsPrefix, $this->lang, $this->savedConfig, $validItemId);
            if($paramMinimalPrice == TRUE)
            {
                $unitFixedDepositAmount 		= $objDepositManager->getMinimalFixedDepositAmount();
            } else
            {
                $unitFixedDepositAmount 		= $objDepositManager->getFixedDepositAmountByPeriod($validPeriodByPriceType);
            }

            $arrPriceDetails['unit']['prepayment_amount']           = $unitPrepaymentAmountWithoutVAT;
            $arrPriceDetails['unit']['prepayment_amount_with_vat']  = $unitPrepaymentAmountWithVAT;
            $arrPriceDetails['unit']['prepayment_amount_dynamic']   = $unitPrepaymentAmountDynamic;
            $arrPriceDetails['unit']['fixed_deposit_amount']        = $unitFixedDepositAmount;

            $arrPriceDetails['percentage']['prepayment'] 			= $unitPrepaymentPercentage;
        } else
        {
            $unitPrepaymentPercentage = 0;
            $unitFixedDepositAmount = 0;
        }

        // Multiplied prices
        $arrPriceDetails['multiplier'] = $validMultiplier;
        $arrPriceDetails['multiplied'] = NRSFormatter::getMultipliedNumberArray($arrPriceDetails['unit'], $validMultiplier);

        if($this->debugMode == 2)
        {
            // We want to do a debug here to avoid mess with printed data
            $pickupTMZStamp = $validPickupTimestamp + get_option( 'gmt_offset' ) * 3600;
            $dropoffTMZStamp = $validDropoffTimestamp + get_option( 'gmt_offset' ) * 3600;
            $printPickupDate = date_i18n( get_option( 'date_format' ).' '.get_option( 'time_format' ), $pickupTMZStamp, TRUE);
            $printDropoffDate = date_i18n( get_option( 'date_format' ).' '.get_option( 'time_format' ), $dropoffTMZStamp, TRUE);
            // Deep debug
            echo "<br /><strong>Returned price details for Item Id={$validItemId}:</strong>";
            echo "<br />Minimal price only: "; var_dump($paramMinimalPrice);
            echo "<br />Only basic details: "; var_dump($paramBasicDetails);
            echo "<br />Dates: {$printPickupDate} - {$printDropoffDate}";
            echo "<br />UNIX, GMT period: {$validPickupTimestamp} - {$validDropoffTimestamp}";
            echo "<br />Price calculation type: {$this->priceCalculationType}";
            echo "<br />Period by price type {$validPeriodByPriceType}";
            echo "<br />Unit discount percentage: {$unitDiscountPercentage}";
            echo "<br />Unit prepayment percentage: {$unitPrepaymentPercentage}";
            echo "<br />Unit fixed deposit amount: {$unitFixedDepositAmount}";
            echo '<div style="font-size:12px;line-height:18px;color:navy;">'.nl2br(print_r($arrPriceDetails, TRUE)).'</div>';
            echo "---------------------------------------------------------------------------------------------------------";
            echo "<br /><br />";
        }

        // Unit prints
		$arrPriceDetails['unit_tiny_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "tiny");
		$arrPriceDetails['unit_tiny_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "tiny_without_fraction");
		$arrPriceDetails['unit_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "regular");
		$arrPriceDetails['unit_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "regular_without_fraction");
		$arrPriceDetails['unit_long_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "long");
		$arrPriceDetails['unit_long_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "long_without_fraction");

		// Multiplied prints
		$arrPriceDetails['multiplied_tiny_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "tiny");
		$arrPriceDetails['multiplied_tiny_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "tiny_without_fraction");
		$arrPriceDetails['multiplied_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "regular");
		$arrPriceDetails['multiplied_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "regular_without_fraction");
		$arrPriceDetails['multiplied_long_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "long");
		$arrPriceDetails['multiplied_long_without_fraction_print'] = $this->getFormattedPriceArray($arrPriceDetails['multiplied'], "long_without_fraction");

		// Word prints
		$arrPriceDetails['word_print'] = $this->getFormattedPriceArray($arrPriceDetails['unit'], "word");
		$arrPriceDetails['time_extension_print'] = $this->getPricePeriodText("SHORT");
		$arrPriceDetails['time_extension_long_print'] = $this->getPricePeriodText("LONG");

		// Percentage prints
		$arrPriceDetails['percentage_print'] = NRSFormatter::getFormattedPercentageArray($arrPriceDetails['percentage'], "regular");

		return $arrPriceDetails;
	}

	/**
	 * @param string $paramType - SHORT OR LONG
	 * @return string
	 */
	public function getPricePeriodText($paramType = "LONG")
	{
		if ($this->isPriceDisplayedByDays())
		{
			$text = $paramType == "LONG" ? $this->lang->getText('NRS_PER_DAY_TEXT') : $this->lang->getText('NRS_PER_DAY_SHORT_TEXT');
		} else
		{
			$text = $paramType == "LONG" ? $this->lang->getText('NRS_PER_HOUR_TEXT') : $this->lang->getText('NRS_PER_HOUR_SHORT_TEXT');
		}

		return $text;
	}
}
