<?php
/**
 * NRS Item Units Manager
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSItemUnitManager extends NRSUnitManager implements iNRSUnitsManager
{
	public function __construct(
        wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang,
        $paramElementId, $paramTimestampFrom, $paramTimestampTo, $paramOptionalConfig = array()
    ) {
		parent::__construct($paramWPDB, $paramNRSPrefix, $paramNRSLang, $paramElementId, $paramTimestampFrom, $paramTimestampTo, $paramOptionalConfig);
	}

    /**
     * SQL optimized method
     * Supports units
     * @param int $paramLocationId (DEFAULT = 0, when it is applied to any location)
     * @param int $paramIgnoreFromBookingId (DEFAULT = 0, when it will not exclude any booking from calculation any booking)
     * @return int
     */
    public function getTotalUnits($paramLocationId = 0, $paramIgnoreFromBookingId = 0)
    {
        $unitsInStock = $this->getTotalUnitsInStock();
        $unitsBooked = $this->getTotalUnitsBookedByType("ITEM", $paramLocationId, $paramIgnoreFromBookingId);
        if($unitsBooked == -1)
        {
            // All item units are blocked by site administrator, no units available
            $unitsAvailable = 0;
        } else
        {
            $unitsAvailable = ($unitsInStock > $unitsBooked) ? ($unitsInStock - $unitsBooked) : 0;
        }

        $arrUnits = array(
            "units_in_stock" => $unitsInStock,
            "units_booked" => $unitsBooked,
            "units_available" => $unitsAvailable,
        );

        return $arrUnits;
    }

    /**
     * Supports units
     * NOTE: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getTotalUnits() method
     * @param int $paramLocationId (DEFAULT = 0, when it is applied to any location)
     * @param int $paramIgnoreFromBookingId (DEFAULT = 0, when it will not exclude any booking from calculation any booking)
     * @return int
     */
    public function getTotalUnitsBooked($paramLocationId = 0, $paramIgnoreFromBookingId = 0)
    {
        return $this->getTotalUnitsBookedByType("ITEM", $paramLocationId, $paramIgnoreFromBookingId);
    }

    /**
     * NOTE: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getTotalUnits() method
     * @param int $paramLocationId
     * @param int $paramIgnoreFromBookingId
     * @return int|null|string
     */
	public function getTotalUnitsAvailable($paramLocationId = 0, $paramIgnoreFromBookingId = 0)
	{
		$unitsInStock = $this->getTotalUnitsInStock();
		$unitsBooked = $this->getTotalUnitsBookedByType("ITEM", $paramLocationId, $paramIgnoreFromBookingId);
        if($unitsBooked == -1)
        {
            // All item units are blocked by site administrator, no units available
            $unitsAvailable = 0;
        } else
        {
            $unitsAvailable = ($unitsInStock > $unitsBooked) ? ($unitsInStock - $unitsBooked) : 0;
        }

		return $unitsAvailable;
	}

    /**
     * NOTE: Use with CAUSE! If you need both - priciest and cheapest days of the week,
     * please use other - getTotalUnits() method
     * @return int|null|string
     */
    public function getTotalUnitsInStock()
    {
		$searchSQL = "
            SELECT units_in_stock
            FROM {$this->nrsPrefix}items
            WHERE item_id='{$this->elementId}'
		";

		//echo "<br />".$searchSQL."<br />"; //die;

		$dbTotalUnitsInStock = $this->internalWPDB->get_var($searchSQL);

		$totalUnitsInStock = !is_null($dbTotalUnitsInStock) ? $dbTotalUnitsInStock : 0;

		return $totalUnitsInStock;
    }

	/**
	 * Item has no minimum limit on booking. It can be booked, if chosen, or not, if other item is chosen
	 * @return int
	 */
	public function getMinUnitsPerBooking()
	{
		return 0;
	}

	public function getMaxUnitsPerBooking()
    {
		$searchSQL = "
            SELECT max_units_per_booking
            FROM {$this->nrsPrefix}items
            WHERE item_id='{$this->elementId}'
		";

		//echo "<br />".$searchSQL."<br />"; //die;

		$dbMaxUnitsPerBooking = $this->internalWPDB->get_var($searchSQL);

		$maxUnitsPerBooking = !is_null($dbMaxUnitsPerBooking) ? $dbMaxUnitsPerBooking : 0;

		return $maxUnitsPerBooking;
    }

	/**
	 * This function appears to be same for both classes
	 * @param int $paramLocationId (DEFAULT = 0)
     * @param int $paramIgnoreFromBookingId (DEFAULT = 0)
	 * @return mixed
	 */
	public function getMaxAllowedUnitsForBooking($paramLocationId = 0, $paramIgnoreFromBookingId = 0)
	{
		$totalUnitsInStock = $this->getTotalUnitsInStock();
		$maxUnitsPerBooking = $this->getMaxUnitsPerBooking();
		$bookedItems = $this->getTotalUnitsBooked($paramLocationId, $paramIgnoreFromBookingId);

		// Hope that auto type casting works well here from string to int
		$totalAvailableUnits = $totalUnitsInStock - $bookedItems;
		if($maxUnitsPerBooking > $totalAvailableUnits)
		{
			$maxAllowedUnitsForBooking = $totalAvailableUnits;
		} else
		{
			$maxAllowedUnitsForBooking = $maxUnitsPerBooking;
		}

		return $maxAllowedUnitsForBooking;
	}
}