<?php
/**
 * Option Processor
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @uses NRSDepositManager, NRSDiscountManager, NRSPrepaymentManager
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSOption
{
    protected $internalWPDB 		= NULL;
    protected $nrsPrefix 			= "";
    protected $lang 				= NULL;
    protected $debugMode 			= 0;

    protected $optionId			    = 0;

    /**
     * @param $paramWPDB
     * @param $paramNRSPrefix
     * @param NRSLanguage &$paramNRSLang - Language
     * @param $paramOptionId
     */
    public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $paramOptionId)
    {
        // Set class settings
        $this->internalWPDB = $paramWPDB;
        $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
        // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
        $this->lang = $paramNRSLang;

        $this->optionId = NRSValidator::getValidValue($paramOptionId, "intval", 0);
    }

    public function inDebug()
    {
        return ($this->debugMode >= 1 ? TRUE : FALSE);
    }

    public function getId()
    {
        return $this->optionId;
    }

    /**
     * @param $paramOptionId
     * @return mixed
     */
    private function getDataFromDatabaseById($paramOptionId)
    {
        $row = $this->internalWPDB->get_row("
            SELECT *
            FROM {$this->nrsPrefix}options
            WHERE option_id='".intval($paramOptionId)."'
        ", ARRAY_A);

        return $row;
    }

    /**
     * @return array
     */
    public function getDetails()
    {
        $extraData = $this->getDataFromDatabaseById($this->optionId);

        return $extraData;
    }

    public function save($itemId, $extraId, $optionName)
    {
        $validOptionId = NRSValidator::getValidInteger($this->optionId, 0);
        $validItemId = NRSValidator::getValidInteger($itemId, 0);
        $validExtraId = NRSValidator::getValidInteger($extraId, 0);
        $sanitizedOptionName = sanitize_text_field($optionName);

        $existQuery = "
            SELECT option_id
            FROM {$this->nrsPrefix}options
            WHERE option_name='{$sanitizedOptionName}'
            AND item_id='{$validItemId}' AND extra_id='{$validExtraId}' AND option_id!='{$validOptionId}'
        ";
        $exist = $this->internalWPDB->get_row($existQuery, ARRAY_A);

        if(!is_null($exist))
        {
            if($validExtraId > 0)
            {
                $_SESSION['msg'] = "Error: Option with chosen name already existing for this extra!";
            } else
            {
                $_SESSION['msg'] = "Error: Option with chosen name already existing for this car!";
            }
        }

        if(!isset($_SESSION['msg']))
        {
            //TODO: Add check for the same name
            if ($validOptionId > 0)
            {
                $this->internalWPDB->query("
                    UPDATE {$this->nrsPrefix}options SET
                    item_id='{$validItemId}', extra_id='{$validExtraId}',
                    option_name='{$sanitizedOptionName}'
                    WHERE option_id='{$validOptionId}'
                ");
                $_SESSION['ok_msg'] = "Completed: Option updated successfully!";
            } else
            {
                $this->internalWPDB->query("
                    INSERT INTO {$this->nrsPrefix}options
                    (
                        item_id, extra_id, option_name
                    ) VALUES
                    (
                        '{$validItemId}', '{$validExtraId}', '{$sanitizedOptionName}'
                    )
                ");
                $_SESSION['ok_msg'] = "Completed: New option added successfully!";
            }
        }
    }

    public function delete()
    {
        $this->internalWPDB->query("
            DELETE FROM {$this->nrsPrefix}options
            WHERE option_id='".intval($this->optionId)."'
        ");
    }
}