<?php
/**
 * PayPal process class
 * Final class cannot be inherited anymore. We use them when creating new instances
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

final class NRSPayPal extends NRSPayPalIpnListener
{
   protected $internalWPDB = NULL;
   protected $nrsPrefix    = "";
   protected $lang 		   = NULL;
   private $fields         = array();              // array holds the fields to submit to paypal

   /**
    * @param wpdb $paramWPDB
    * @param $paramNRSPrefix
    * @param NRSLanguage $paramNRSLang
    * @param int $sandboxMode - use live server (0), or paypal sandbox test server (1)
    */
   public function __construct(wpdb &$paramWPDB, $paramNRSPrefix, NRSLanguage &$paramNRSLang, $sandboxMode = 0)
   {
      $this->internalWPDB = $paramWPDB;
      $this->nrsPrefix = sanitize_text_field($paramNRSPrefix);
      // Already sanitized before in it's constructor. Too much sanitation will kill the system speed
      $this->lang = $paramNRSLang;

      if($sandboxMode == 1)
      {
         $this->use_sandbox = TRUE;
      } else
      {
         $this->use_sandbox = FALSE;
      }

      // populate $fields array with a few default values.  See the paypal
      // documentation for a list of fields and their data types. These default
      // values can be overwritten by the calling script.
      $this->addField('rm','2');           // Return method = POST
      $this->addField('cmd','_xclick');
   }

   public function addField($field, $value)
   {
      // adds a key=>value pair to the fields array, which is what will be 
      // sent to paypal as POST variables.  If the value is already in the 
      // array, it will be overwritten.      
      $this->fields["$field"] = $value;
   }

   /**
    * Special method (more short version of 'submitPayPalPost') for Native rental system
    */
   public function getPayPalFormFields()
   {
      $ret = "";
      foreach ($this->fields as $name => $value)
      {
         $ret .= "<input type=\"hidden\" name=\"$name\" value=\"$value\">";
      }

      return $ret;
   }

   /**
    * Special method for Native rental system
    */
   public function getPayPalSubmitURL()
   {
      if ($this->use_ssl)
      {
         $uri = 'https://'.$this->getPayPalHost().'/cgi-bin/webscr';
      } else
      {
         $uri = 'http://'.$this->getPayPalHost().'/cgi-bin/webscr';
      }
      return $uri;
   }
}
 
