<?php
/**
 * Search must-have interface
 * Interface purpose is describe all public methods used available in the class and enforce to use them
 * @package NRS
 * @author Kestutis Matuliauskas
 * @copyright Kestutis Matuliauskas
 * See Licensing/README_License.txt for copyright notices and details.
 */

interface iNRSSearch {
    // System methods
    public function inDebug();
    public function isValidSearch();
    public function getPrintErrors();

    // Time & Date methods for printing to the user screen (Applies formatting, localization and GMT zone adjustment
    public function getPrintPickupDate();
    public function getPrintPickupTime();
    public function getPrintDropoffDate();
    public function getPrintDropoffTime();
    public function getPrintShortPickupDate();
    public function getPrintShortPickupTime();
    public function getPrintShortDropoffDate();
    public function getPrintShortDropoffTime();
    public function getPrintBookingDuration();

    // Time & Date methods for system use
    public function getLocalPickupDate();
    public function getLocalPickupTime();
    public function getLocalDropoffDate();
    public function getLocalDropoffTime();
    public function getLocalPickupDayOfWeek();
    public function getLocalDropoffDayOfWeek();
    public function getBookingPeriod();
    public function getPickupTimestamp();
    public function getDropoffTimestamp();
    public function getReCaptchaSiteKey();
    public function getReCaptchaLanguage();

    // Methods to retrieve booking location, item, customer and booking details
    public function areMultiMode();
    public function useReCaptcha();
    public function isNewBooking();
    public function getBookingCode();
    public function getPickupLocationId();
    public function getDropoffLocationId();
    public function getBodyTypeId();
    public function getTransmissionTypeId();
    public function getFuelTypeId();
    public function getPaymentMethodCode();
    public function getSearchInputDataArray();
    public function getCustomerEmail();
    public function getCustomerInputDataArray();

    // Advanced methods
    public function getSelectedItemIdsForType($limitType);
    public function getAvailableItemIdsForType($limitType);
    public function getSelectedItemIds();
    public function getAvailableItemIds();
    public function getSelectedItemUnits();
    public function getSelectedItemOptions();
    public function getSelectedExtraIds();
    public function getAvailableExtraIds();
    public function getSelectedExtraUnits();
    public function getSelectedExtraOptions();
    public function isPaymentRequired();
}